/* Autogen header for Unicorn Engine - DONOT MODIFY */
#ifndef UNICORN_AUTOGEN_aarch64_H
#define UNICORN_AUTOGEN_aarch64_H
#ifndef UNICORN_ARCH_POSTFIX
#define UNICORN_ARCH_POSTFIX _aarch64
#endif
#define gen_helper_check_exit_request gen_helper_check_exit_request_aarch64
#define unicorn_fill_tlb unicorn_fill_tlb_aarch64
#define reg_read reg_read_aarch64
#define reg_write reg_write_aarch64
#define uc_init uc_init_aarch64
#define uc_add_inline_hook uc_add_inline_hook_aarch64
#define uc_del_inline_hook uc_del_inline_hook_aarch64
#define tb_invalidate_phys_range tb_invalidate_phys_range_aarch64
#define use_idiv_instructions use_idiv_instructions_aarch64
#define arm_arch arm_arch_aarch64
#define tb_target_set_jmp_target tb_target_set_jmp_target_aarch64
#define have_bmi1 have_bmi1_aarch64
#define have_popcnt have_popcnt_aarch64
#define have_avx1 have_avx1_aarch64
#define have_avx2 have_avx2_aarch64
#define have_isa have_isa_aarch64
#define have_altivec have_altivec_aarch64
#define have_vsx have_vsx_aarch64
#define flush_icache_range flush_icache_range_aarch64
#define s390_facilities s390_facilities_aarch64
#define tcg_dump_op tcg_dump_op_aarch64
#define tcg_dump_ops tcg_dump_ops_aarch64
#define tcg_gen_and_i64 tcg_gen_and_i64_aarch64
#define tcg_gen_discard_i64 tcg_gen_discard_i64_aarch64
#define tcg_gen_ld16s_i64 tcg_gen_ld16s_i64_aarch64
#define tcg_gen_ld16u_i64 tcg_gen_ld16u_i64_aarch64
#define tcg_gen_ld32s_i64 tcg_gen_ld32s_i64_aarch64
#define tcg_gen_ld32u_i64 tcg_gen_ld32u_i64_aarch64
#define tcg_gen_ld8s_i64 tcg_gen_ld8s_i64_aarch64
#define tcg_gen_ld8u_i64 tcg_gen_ld8u_i64_aarch64
#define tcg_gen_ld_i64 tcg_gen_ld_i64_aarch64
#define tcg_gen_mov_i64 tcg_gen_mov_i64_aarch64
#define tcg_gen_movi_i64 tcg_gen_movi_i64_aarch64
#define tcg_gen_mul_i64 tcg_gen_mul_i64_aarch64
#define tcg_gen_or_i64 tcg_gen_or_i64_aarch64
#define tcg_gen_sar_i64 tcg_gen_sar_i64_aarch64
#define tcg_gen_shl_i64 tcg_gen_shl_i64_aarch64
#define tcg_gen_shr_i64 tcg_gen_shr_i64_aarch64
#define tcg_gen_st_i64 tcg_gen_st_i64_aarch64
#define tcg_gen_xor_i64 tcg_gen_xor_i64_aarch64
#define cpu_icount_to_ns cpu_icount_to_ns_aarch64
#define cpu_is_stopped cpu_is_stopped_aarch64
#define cpu_get_ticks cpu_get_ticks_aarch64
#define cpu_get_clock cpu_get_clock_aarch64
#define cpu_resume cpu_resume_aarch64
#define qemu_init_vcpu qemu_init_vcpu_aarch64
#define cpu_stop_current cpu_stop_current_aarch64
#define resume_all_vcpus resume_all_vcpus_aarch64
#define vm_start vm_start_aarch64
#define address_space_dispatch_compact address_space_dispatch_compact_aarch64
#define flatview_translate flatview_translate_aarch64
#define flatview_copy flatview_copy_aarch64
#define address_space_translate_for_iotlb address_space_translate_for_iotlb_aarch64
#define qemu_get_cpu qemu_get_cpu_aarch64
#define cpu_address_space_init cpu_address_space_init_aarch64
#define cpu_get_address_space cpu_get_address_space_aarch64
#define cpu_exec_unrealizefn cpu_exec_unrealizefn_aarch64
#define cpu_exec_initfn cpu_exec_initfn_aarch64
#define cpu_exec_realizefn cpu_exec_realizefn_aarch64
#define tb_invalidate_phys_addr tb_invalidate_phys_addr_aarch64
#define cpu_watchpoint_insert cpu_watchpoint_insert_aarch64
#define cpu_watchpoint_remove_by_ref cpu_watchpoint_remove_by_ref_aarch64
#define cpu_watchpoint_remove_all cpu_watchpoint_remove_all_aarch64
#define cpu_watchpoint_address_matches cpu_watchpoint_address_matches_aarch64
#define cpu_breakpoint_insert cpu_breakpoint_insert_aarch64
#define cpu_breakpoint_remove cpu_breakpoint_remove_aarch64
#define cpu_breakpoint_remove_by_ref cpu_breakpoint_remove_by_ref_aarch64
#define cpu_breakpoint_remove_all cpu_breakpoint_remove_all_aarch64
#define cpu_abort cpu_abort_aarch64
#define cpu_physical_memory_test_and_clear_dirty cpu_physical_memory_test_and_clear_dirty_aarch64
#define memory_region_section_get_iotlb memory_region_section_get_iotlb_aarch64
#define flatview_add_to_dispatch flatview_add_to_dispatch_aarch64
#define qemu_ram_get_host_addr qemu_ram_get_host_addr_aarch64
#define qemu_ram_get_offset qemu_ram_get_offset_aarch64
#define qemu_ram_get_used_length qemu_ram_get_used_length_aarch64
#define qemu_ram_is_shared qemu_ram_is_shared_aarch64
#define qemu_ram_pagesize qemu_ram_pagesize_aarch64
#define qemu_ram_alloc_from_ptr qemu_ram_alloc_from_ptr_aarch64
#define qemu_ram_alloc qemu_ram_alloc_aarch64
#define qemu_ram_free qemu_ram_free_aarch64
#define qemu_map_ram_ptr qemu_map_ram_ptr_aarch64
#define qemu_ram_block_host_offset qemu_ram_block_host_offset_aarch64
#define qemu_ram_block_from_host qemu_ram_block_from_host_aarch64
#define qemu_ram_addr_from_host qemu_ram_addr_from_host_aarch64
#define cpu_check_watchpoint cpu_check_watchpoint_aarch64
#define iotlb_to_section iotlb_to_section_aarch64
#define address_space_dispatch_new address_space_dispatch_new_aarch64
#define address_space_dispatch_free address_space_dispatch_free_aarch64
#define address_space_dispatch_clear address_space_dispatch_clear_aarch64
#define flatview_read_continue flatview_read_continue_aarch64
#define address_space_read_full address_space_read_full_aarch64
#define address_space_write address_space_write_aarch64
#define address_space_rw address_space_rw_aarch64
#define cpu_physical_memory_rw cpu_physical_memory_rw_aarch64
#define address_space_write_rom address_space_write_rom_aarch64
#define cpu_flush_icache_range cpu_flush_icache_range_aarch64
#define cpu_exec_init_all cpu_exec_init_all_aarch64
#define address_space_access_valid address_space_access_valid_aarch64
#define address_space_map address_space_map_aarch64
#define address_space_unmap address_space_unmap_aarch64
#define cpu_physical_memory_map cpu_physical_memory_map_aarch64
#define cpu_physical_memory_unmap cpu_physical_memory_unmap_aarch64
#define cpu_memory_rw_debug cpu_memory_rw_debug_aarch64
#define qemu_target_page_size qemu_target_page_size_aarch64
#define qemu_target_page_bits qemu_target_page_bits_aarch64
#define qemu_target_page_bits_min qemu_target_page_bits_min_aarch64
#define target_words_bigendian target_words_bigendian_aarch64
#define cpu_physical_memory_is_io cpu_physical_memory_is_io_aarch64
#define ram_block_discard_range ram_block_discard_range_aarch64
#define ramblock_is_pmem ramblock_is_pmem_aarch64
#define page_size_init page_size_init_aarch64
#define set_preferred_target_page_bits set_preferred_target_page_bits_aarch64
#define finalize_target_page_bits finalize_target_page_bits_aarch64
#define cpu_outb cpu_outb_aarch64
#define cpu_outw cpu_outw_aarch64
#define cpu_outl cpu_outl_aarch64
#define cpu_inb cpu_inb_aarch64
#define cpu_inw cpu_inw_aarch64
#define cpu_inl cpu_inl_aarch64
#define memory_map memory_map_aarch64
#define memory_map_io memory_map_io_aarch64
#define memory_map_ptr memory_map_ptr_aarch64
#define memory_cow memory_cow_aarch64
#define memory_unmap memory_unmap_aarch64
#define memory_moveout memory_moveout_aarch64
#define memory_movein memory_movein_aarch64
#define memory_free memory_free_aarch64
#define flatview_unref flatview_unref_aarch64
#define address_space_get_flatview address_space_get_flatview_aarch64
#define memory_region_transaction_begin memory_region_transaction_begin_aarch64
#define memory_region_transaction_commit memory_region_transaction_commit_aarch64
#define memory_region_init memory_region_init_aarch64
#define memory_region_access_valid memory_region_access_valid_aarch64
#define memory_region_dispatch_read memory_region_dispatch_read_aarch64
#define memory_region_dispatch_write memory_region_dispatch_write_aarch64
#define memory_region_init_io memory_region_init_io_aarch64
#define memory_region_init_ram_ptr memory_region_init_ram_ptr_aarch64
#define memory_region_size memory_region_size_aarch64
#define memory_region_set_readonly memory_region_set_readonly_aarch64
#define memory_region_get_ram_ptr memory_region_get_ram_ptr_aarch64
#define memory_region_from_host memory_region_from_host_aarch64
#define memory_region_get_ram_addr memory_region_get_ram_addr_aarch64
#define memory_region_add_subregion memory_region_add_subregion_aarch64
#define memory_region_del_subregion memory_region_del_subregion_aarch64
#define memory_region_add_subregion_overlap memory_region_add_subregion_overlap_aarch64
#define memory_region_find memory_region_find_aarch64
#define memory_region_filter_subregions memory_region_filter_subregions_aarch64
#define memory_listener_register memory_listener_register_aarch64
#define memory_listener_unregister memory_listener_unregister_aarch64
#define address_space_remove_listeners address_space_remove_listeners_aarch64
#define address_space_init address_space_init_aarch64
#define address_space_destroy address_space_destroy_aarch64
#define memory_region_init_ram memory_region_init_ram_aarch64
#define memory_mapping_list_add_merge_sorted memory_mapping_list_add_merge_sorted_aarch64
#define find_memory_mapping find_memory_mapping_aarch64
#define exec_inline_op exec_inline_op_aarch64
#define floatx80_default_nan floatx80_default_nan_aarch64
#define float_raise float_raise_aarch64
#define float16_is_quiet_nan float16_is_quiet_nan_aarch64
#define float16_is_signaling_nan float16_is_signaling_nan_aarch64
#define float32_is_quiet_nan float32_is_quiet_nan_aarch64
#define float32_is_signaling_nan float32_is_signaling_nan_aarch64
#define float64_is_quiet_nan float64_is_quiet_nan_aarch64
#define float64_is_signaling_nan float64_is_signaling_nan_aarch64
#define floatx80_is_quiet_nan floatx80_is_quiet_nan_aarch64
#define floatx80_is_signaling_nan floatx80_is_signaling_nan_aarch64
#define floatx80_silence_nan floatx80_silence_nan_aarch64
#define propagateFloatx80NaN propagateFloatx80NaN_aarch64
#define float128_is_quiet_nan float128_is_quiet_nan_aarch64
#define float128_is_signaling_nan float128_is_signaling_nan_aarch64
#define float128_silence_nan float128_silence_nan_aarch64
#define float16_add float16_add_aarch64
#define float16_sub float16_sub_aarch64
#define float32_add float32_add_aarch64
#define float32_sub float32_sub_aarch64
#define float64_add float64_add_aarch64
#define float64_sub float64_sub_aarch64
#define float16_mul float16_mul_aarch64
#define float32_mul float32_mul_aarch64
#define float64_mul float64_mul_aarch64
#define float16_muladd float16_muladd_aarch64
#define float32_muladd float32_muladd_aarch64
#define float64_muladd float64_muladd_aarch64
#define float16_div float16_div_aarch64
#define float32_div float32_div_aarch64
#define float64_div float64_div_aarch64
#define float16_to_float32 float16_to_float32_aarch64
#define float16_to_float64 float16_to_float64_aarch64
#define float32_to_float16 float32_to_float16_aarch64
#define float32_to_float64 float32_to_float64_aarch64
#define float64_to_float16 float64_to_float16_aarch64
#define float64_to_float32 float64_to_float32_aarch64
#define float16_round_to_int float16_round_to_int_aarch64
#define float32_round_to_int float32_round_to_int_aarch64
#define float64_round_to_int float64_round_to_int_aarch64
#define float16_to_int16_scalbn float16_to_int16_scalbn_aarch64
#define float16_to_int32_scalbn float16_to_int32_scalbn_aarch64
#define float16_to_int64_scalbn float16_to_int64_scalbn_aarch64
#define float32_to_int16_scalbn float32_to_int16_scalbn_aarch64
#define float32_to_int32_scalbn float32_to_int32_scalbn_aarch64
#define float32_to_int64_scalbn float32_to_int64_scalbn_aarch64
#define float64_to_int16_scalbn float64_to_int16_scalbn_aarch64
#define float64_to_int32_scalbn float64_to_int32_scalbn_aarch64
#define float64_to_int64_scalbn float64_to_int64_scalbn_aarch64
#define float16_to_int16 float16_to_int16_aarch64
#define float16_to_int32 float16_to_int32_aarch64
#define float16_to_int64 float16_to_int64_aarch64
#define float32_to_int16 float32_to_int16_aarch64
#define float32_to_int32 float32_to_int32_aarch64
#define float32_to_int64 float32_to_int64_aarch64
#define float64_to_int16 float64_to_int16_aarch64
#define float64_to_int32 float64_to_int32_aarch64
#define float64_to_int64 float64_to_int64_aarch64
#define float16_to_int16_round_to_zero float16_to_int16_round_to_zero_aarch64
#define float16_to_int32_round_to_zero float16_to_int32_round_to_zero_aarch64
#define float16_to_int64_round_to_zero float16_to_int64_round_to_zero_aarch64
#define float32_to_int16_round_to_zero float32_to_int16_round_to_zero_aarch64
#define float32_to_int32_round_to_zero float32_to_int32_round_to_zero_aarch64
#define float32_to_int64_round_to_zero float32_to_int64_round_to_zero_aarch64
#define float64_to_int16_round_to_zero float64_to_int16_round_to_zero_aarch64
#define float64_to_int32_round_to_zero float64_to_int32_round_to_zero_aarch64
#define float64_to_int64_round_to_zero float64_to_int64_round_to_zero_aarch64
#define float16_to_uint16_scalbn float16_to_uint16_scalbn_aarch64
#define float16_to_uint32_scalbn float16_to_uint32_scalbn_aarch64
#define float16_to_uint64_scalbn float16_to_uint64_scalbn_aarch64
#define float32_to_uint16_scalbn float32_to_uint16_scalbn_aarch64
#define float32_to_uint32_scalbn float32_to_uint32_scalbn_aarch64
#define float32_to_uint64_scalbn float32_to_uint64_scalbn_aarch64
#define float64_to_uint16_scalbn float64_to_uint16_scalbn_aarch64
#define float64_to_uint32_scalbn float64_to_uint32_scalbn_aarch64
#define float64_to_uint64_scalbn float64_to_uint64_scalbn_aarch64
#define float16_to_uint16 float16_to_uint16_aarch64
#define float16_to_uint32 float16_to_uint32_aarch64
#define float16_to_uint64 float16_to_uint64_aarch64
#define float32_to_uint16 float32_to_uint16_aarch64
#define float32_to_uint32 float32_to_uint32_aarch64
#define float32_to_uint64 float32_to_uint64_aarch64
#define float64_to_uint16 float64_to_uint16_aarch64
#define float64_to_uint32 float64_to_uint32_aarch64
#define float64_to_uint64 float64_to_uint64_aarch64
#define float16_to_uint16_round_to_zero float16_to_uint16_round_to_zero_aarch64
#define float16_to_uint32_round_to_zero float16_to_uint32_round_to_zero_aarch64
#define float16_to_uint64_round_to_zero float16_to_uint64_round_to_zero_aarch64
#define float32_to_uint16_round_to_zero float32_to_uint16_round_to_zero_aarch64
#define float32_to_uint32_round_to_zero float32_to_uint32_round_to_zero_aarch64
#define float32_to_uint64_round_to_zero float32_to_uint64_round_to_zero_aarch64
#define float64_to_uint16_round_to_zero float64_to_uint16_round_to_zero_aarch64
#define float64_to_uint32_round_to_zero float64_to_uint32_round_to_zero_aarch64
#define float64_to_uint64_round_to_zero float64_to_uint64_round_to_zero_aarch64
#define int64_to_float16_scalbn int64_to_float16_scalbn_aarch64
#define int32_to_float16_scalbn int32_to_float16_scalbn_aarch64
#define int16_to_float16_scalbn int16_to_float16_scalbn_aarch64
#define int64_to_float16 int64_to_float16_aarch64
#define int32_to_float16 int32_to_float16_aarch64
#define int16_to_float16 int16_to_float16_aarch64
#define int64_to_float32_scalbn int64_to_float32_scalbn_aarch64
#define int32_to_float32_scalbn int32_to_float32_scalbn_aarch64
#define int16_to_float32_scalbn int16_to_float32_scalbn_aarch64
#define int64_to_float32 int64_to_float32_aarch64
#define int32_to_float32 int32_to_float32_aarch64
#define int16_to_float32 int16_to_float32_aarch64
#define int64_to_float64_scalbn int64_to_float64_scalbn_aarch64
#define int32_to_float64_scalbn int32_to_float64_scalbn_aarch64
#define int16_to_float64_scalbn int16_to_float64_scalbn_aarch64
#define int64_to_float64 int64_to_float64_aarch64
#define int32_to_float64 int32_to_float64_aarch64
#define int16_to_float64 int16_to_float64_aarch64
#define uint64_to_float16_scalbn uint64_to_float16_scalbn_aarch64
#define uint32_to_float16_scalbn uint32_to_float16_scalbn_aarch64
#define uint16_to_float16_scalbn uint16_to_float16_scalbn_aarch64
#define uint64_to_float16 uint64_to_float16_aarch64
#define uint32_to_float16 uint32_to_float16_aarch64
#define uint16_to_float16 uint16_to_float16_aarch64
#define uint64_to_float32_scalbn uint64_to_float32_scalbn_aarch64
#define uint32_to_float32_scalbn uint32_to_float32_scalbn_aarch64
#define uint16_to_float32_scalbn uint16_to_float32_scalbn_aarch64
#define uint64_to_float32 uint64_to_float32_aarch64
#define uint32_to_float32 uint32_to_float32_aarch64
#define uint16_to_float32 uint16_to_float32_aarch64
#define uint64_to_float64_scalbn uint64_to_float64_scalbn_aarch64
#define uint32_to_float64_scalbn uint32_to_float64_scalbn_aarch64
#define uint16_to_float64_scalbn uint16_to_float64_scalbn_aarch64
#define uint64_to_float64 uint64_to_float64_aarch64
#define uint32_to_float64 uint32_to_float64_aarch64
#define uint16_to_float64 uint16_to_float64_aarch64
#define float16_min float16_min_aarch64
#define float16_minnum float16_minnum_aarch64
#define float16_minnummag float16_minnummag_aarch64
#define float16_max float16_max_aarch64
#define float16_maxnum float16_maxnum_aarch64
#define float16_maxnummag float16_maxnummag_aarch64
#define float32_min float32_min_aarch64
#define float32_minnum float32_minnum_aarch64
#define float32_minnummag float32_minnummag_aarch64
#define float32_max float32_max_aarch64
#define float32_maxnum float32_maxnum_aarch64
#define float32_maxnummag float32_maxnummag_aarch64
#define float64_min float64_min_aarch64
#define float64_minnum float64_minnum_aarch64
#define float64_minnummag float64_minnummag_aarch64
#define float64_max float64_max_aarch64
#define float64_maxnum float64_maxnum_aarch64
#define float64_maxnummag float64_maxnummag_aarch64
#define float16_compare float16_compare_aarch64
#define float16_compare_quiet float16_compare_quiet_aarch64
#define float32_compare float32_compare_aarch64
#define float32_compare_quiet float32_compare_quiet_aarch64
#define float64_compare float64_compare_aarch64
#define float64_compare_quiet float64_compare_quiet_aarch64
#define float16_scalbn float16_scalbn_aarch64
#define float32_scalbn float32_scalbn_aarch64
#define float64_scalbn float64_scalbn_aarch64
#define float16_sqrt float16_sqrt_aarch64
#define float32_sqrt float32_sqrt_aarch64
#define float64_sqrt float64_sqrt_aarch64
#define float16_default_nan float16_default_nan_aarch64
#define float32_default_nan float32_default_nan_aarch64
#define float64_default_nan float64_default_nan_aarch64
#define float128_default_nan float128_default_nan_aarch64
#define float16_silence_nan float16_silence_nan_aarch64
#define float32_silence_nan float32_silence_nan_aarch64
#define float64_silence_nan float64_silence_nan_aarch64
#define float16_squash_input_denormal float16_squash_input_denormal_aarch64
#define float32_squash_input_denormal float32_squash_input_denormal_aarch64
#define float64_squash_input_denormal float64_squash_input_denormal_aarch64
#define normalizeFloatx80Subnormal normalizeFloatx80Subnormal_aarch64
#define roundAndPackFloatx80 roundAndPackFloatx80_aarch64
#define normalizeRoundAndPackFloatx80 normalizeRoundAndPackFloatx80_aarch64
#define int32_to_floatx80 int32_to_floatx80_aarch64
#define int32_to_float128 int32_to_float128_aarch64
#define int64_to_floatx80 int64_to_floatx80_aarch64
#define int64_to_float128 int64_to_float128_aarch64
#define uint64_to_float128 uint64_to_float128_aarch64
#define float32_to_floatx80 float32_to_floatx80_aarch64
#define float32_to_float128 float32_to_float128_aarch64
#define float32_rem float32_rem_aarch64
#define float32_exp2 float32_exp2_aarch64
#define float32_log2 float32_log2_aarch64
#define float32_eq float32_eq_aarch64
#define float32_le float32_le_aarch64
#define float32_lt float32_lt_aarch64
#define float32_unordered float32_unordered_aarch64
#define float32_eq_quiet float32_eq_quiet_aarch64
#define float32_le_quiet float32_le_quiet_aarch64
#define float32_lt_quiet float32_lt_quiet_aarch64
#define float32_unordered_quiet float32_unordered_quiet_aarch64
#define float64_to_floatx80 float64_to_floatx80_aarch64
#define float64_to_float128 float64_to_float128_aarch64
#define float64_rem float64_rem_aarch64
#define float64_log2 float64_log2_aarch64
#define float64_eq float64_eq_aarch64
#define float64_le float64_le_aarch64
#define float64_lt float64_lt_aarch64
#define float64_unordered float64_unordered_aarch64
#define float64_eq_quiet float64_eq_quiet_aarch64
#define float64_le_quiet float64_le_quiet_aarch64
#define float64_lt_quiet float64_lt_quiet_aarch64
#define float64_unordered_quiet float64_unordered_quiet_aarch64
#define floatx80_to_int32 floatx80_to_int32_aarch64
#define floatx80_to_int32_round_to_zero floatx80_to_int32_round_to_zero_aarch64
#define floatx80_to_int64 floatx80_to_int64_aarch64
#define floatx80_to_int64_round_to_zero floatx80_to_int64_round_to_zero_aarch64
#define floatx80_to_float32 floatx80_to_float32_aarch64
#define floatx80_to_float64 floatx80_to_float64_aarch64
#define floatx80_to_float128 floatx80_to_float128_aarch64
#define floatx80_round floatx80_round_aarch64
#define floatx80_round_to_int floatx80_round_to_int_aarch64
#define floatx80_add floatx80_add_aarch64
#define floatx80_sub floatx80_sub_aarch64
#define floatx80_mul floatx80_mul_aarch64
#define floatx80_div floatx80_div_aarch64
#define floatx80_rem floatx80_rem_aarch64
#define floatx80_sqrt floatx80_sqrt_aarch64
#define floatx80_eq floatx80_eq_aarch64
#define floatx80_le floatx80_le_aarch64
#define floatx80_lt floatx80_lt_aarch64
#define floatx80_unordered floatx80_unordered_aarch64
#define floatx80_eq_quiet floatx80_eq_quiet_aarch64
#define floatx80_le_quiet floatx80_le_quiet_aarch64
#define floatx80_lt_quiet floatx80_lt_quiet_aarch64
#define floatx80_unordered_quiet floatx80_unordered_quiet_aarch64
#define float128_to_int32 float128_to_int32_aarch64
#define float128_to_int32_round_to_zero float128_to_int32_round_to_zero_aarch64
#define float128_to_int64 float128_to_int64_aarch64
#define float128_to_int64_round_to_zero float128_to_int64_round_to_zero_aarch64
#define float128_to_uint64 float128_to_uint64_aarch64
#define float128_to_uint64_round_to_zero float128_to_uint64_round_to_zero_aarch64
#define float128_to_uint32_round_to_zero float128_to_uint32_round_to_zero_aarch64
#define float128_to_uint32 float128_to_uint32_aarch64
#define float128_to_float32 float128_to_float32_aarch64
#define float128_to_float64 float128_to_float64_aarch64
#define float128_to_floatx80 float128_to_floatx80_aarch64
#define float128_round_to_int float128_round_to_int_aarch64
#define float128_add float128_add_aarch64
#define float128_sub float128_sub_aarch64
#define float128_mul float128_mul_aarch64
#define float128_div float128_div_aarch64
#define float128_rem float128_rem_aarch64
#define float128_sqrt float128_sqrt_aarch64
#define float128_eq float128_eq_aarch64
#define float128_le float128_le_aarch64
#define float128_lt float128_lt_aarch64
#define float128_unordered float128_unordered_aarch64
#define float128_eq_quiet float128_eq_quiet_aarch64
#define float128_le_quiet float128_le_quiet_aarch64
#define float128_lt_quiet float128_lt_quiet_aarch64
#define float128_unordered_quiet float128_unordered_quiet_aarch64
#define floatx80_compare floatx80_compare_aarch64
#define floatx80_compare_quiet floatx80_compare_quiet_aarch64
#define float128_compare float128_compare_aarch64
#define float128_compare_quiet float128_compare_quiet_aarch64
#define floatx80_scalbn floatx80_scalbn_aarch64
#define float128_scalbn float128_scalbn_aarch64
#define softfloat_init softfloat_init_aarch64
#define tcg_optimize tcg_optimize_aarch64
#define gen_new_label gen_new_label_aarch64
#define tcg_can_emit_vec_op tcg_can_emit_vec_op_aarch64
#define tcg_expand_vec_op tcg_expand_vec_op_aarch64
#define tcg_register_jit tcg_register_jit_aarch64
#define tcg_tb_insert tcg_tb_insert_aarch64
#define tcg_tb_remove tcg_tb_remove_aarch64
#define tcg_tb_lookup tcg_tb_lookup_aarch64
#define tcg_tb_foreach tcg_tb_foreach_aarch64
#define tcg_nb_tbs tcg_nb_tbs_aarch64
#define tcg_region_reset_all tcg_region_reset_all_aarch64
#define tcg_region_init tcg_region_init_aarch64
#define tcg_code_size tcg_code_size_aarch64
#define tcg_code_capacity tcg_code_capacity_aarch64
#define tcg_tb_phys_invalidate_count tcg_tb_phys_invalidate_count_aarch64
#define tcg_malloc_internal tcg_malloc_internal_aarch64
#define tcg_pool_reset tcg_pool_reset_aarch64
#define tcg_context_init tcg_context_init_aarch64
#define tcg_tb_alloc tcg_tb_alloc_aarch64
#define tcg_prologue_init tcg_prologue_init_aarch64
#define tcg_func_start tcg_func_start_aarch64
#define tcg_set_frame tcg_set_frame_aarch64
#define tcg_global_mem_new_internal tcg_global_mem_new_internal_aarch64
#define tcg_temp_new_internal tcg_temp_new_internal_aarch64
#define tcg_temp_new_vec tcg_temp_new_vec_aarch64
#define tcg_temp_new_vec_matching tcg_temp_new_vec_matching_aarch64
#define tcg_temp_free_internal tcg_temp_free_internal_aarch64
#define tcg_const_i32 tcg_const_i32_aarch64
#define tcg_const_i64 tcg_const_i64_aarch64
#define tcg_const_local_i32 tcg_const_local_i32_aarch64
#define tcg_const_local_i64 tcg_const_local_i64_aarch64
#define tcg_op_supported tcg_op_supported_aarch64
#define tcg_gen_callN tcg_gen_callN_aarch64
#define tcg_op_remove tcg_op_remove_aarch64
#define tcg_emit_op tcg_emit_op_aarch64
#define tcg_op_insert_before tcg_op_insert_before_aarch64
#define tcg_op_insert_after tcg_op_insert_after_aarch64
#define tcg_cpu_exec_time tcg_cpu_exec_time_aarch64
#define tcg_gen_code tcg_gen_code_aarch64
#define tcg_gen_op1 tcg_gen_op1_aarch64
#define tcg_gen_op2 tcg_gen_op2_aarch64
#define tcg_gen_op3 tcg_gen_op3_aarch64
#define tcg_gen_op4 tcg_gen_op4_aarch64
#define tcg_gen_op5 tcg_gen_op5_aarch64
#define tcg_gen_op6 tcg_gen_op6_aarch64
#define tcg_gen_mb tcg_gen_mb_aarch64
#define tcg_gen_addi_i32 tcg_gen_addi_i32_aarch64
#define tcg_gen_subfi_i32 tcg_gen_subfi_i32_aarch64
#define tcg_gen_subi_i32 tcg_gen_subi_i32_aarch64
#define tcg_gen_andi_i32 tcg_gen_andi_i32_aarch64
#define tcg_gen_ori_i32 tcg_gen_ori_i32_aarch64
#define tcg_gen_xori_i32 tcg_gen_xori_i32_aarch64
#define tcg_gen_shli_i32 tcg_gen_shli_i32_aarch64
#define tcg_gen_shri_i32 tcg_gen_shri_i32_aarch64
#define tcg_gen_sari_i32 tcg_gen_sari_i32_aarch64
#define tcg_gen_brcond_i32 tcg_gen_brcond_i32_aarch64
#define tcg_gen_brcondi_i32 tcg_gen_brcondi_i32_aarch64
#define tcg_gen_setcond_i32 tcg_gen_setcond_i32_aarch64
#define tcg_gen_setcondi_i32 tcg_gen_setcondi_i32_aarch64
#define tcg_gen_muli_i32 tcg_gen_muli_i32_aarch64
#define tcg_gen_div_i32 tcg_gen_div_i32_aarch64
#define tcg_gen_rem_i32 tcg_gen_rem_i32_aarch64
#define tcg_gen_divu_i32 tcg_gen_divu_i32_aarch64
#define tcg_gen_remu_i32 tcg_gen_remu_i32_aarch64
#define tcg_gen_andc_i32 tcg_gen_andc_i32_aarch64
#define tcg_gen_eqv_i32 tcg_gen_eqv_i32_aarch64
#define tcg_gen_nand_i32 tcg_gen_nand_i32_aarch64
#define tcg_gen_nor_i32 tcg_gen_nor_i32_aarch64
#define tcg_gen_orc_i32 tcg_gen_orc_i32_aarch64
#define tcg_gen_clz_i32 tcg_gen_clz_i32_aarch64
#define tcg_gen_clzi_i32 tcg_gen_clzi_i32_aarch64
#define tcg_gen_ctz_i32 tcg_gen_ctz_i32_aarch64
#define tcg_gen_ctzi_i32 tcg_gen_ctzi_i32_aarch64
#define tcg_gen_clrsb_i32 tcg_gen_clrsb_i32_aarch64
#define tcg_gen_ctpop_i32 tcg_gen_ctpop_i32_aarch64
#define tcg_gen_rotl_i32 tcg_gen_rotl_i32_aarch64
#define tcg_gen_rotli_i32 tcg_gen_rotli_i32_aarch64
#define tcg_gen_rotr_i32 tcg_gen_rotr_i32_aarch64
#define tcg_gen_rotri_i32 tcg_gen_rotri_i32_aarch64
#define tcg_gen_deposit_i32 tcg_gen_deposit_i32_aarch64
#define tcg_gen_deposit_z_i32 tcg_gen_deposit_z_i32_aarch64
#define tcg_gen_extract_i32 tcg_gen_extract_i32_aarch64
#define tcg_gen_sextract_i32 tcg_gen_sextract_i32_aarch64
#define tcg_gen_extract2_i32 tcg_gen_extract2_i32_aarch64
#define tcg_gen_movcond_i32 tcg_gen_movcond_i32_aarch64
#define tcg_gen_add2_i32 tcg_gen_add2_i32_aarch64
#define tcg_gen_sub2_i32 tcg_gen_sub2_i32_aarch64
#define tcg_gen_mulu2_i32 tcg_gen_mulu2_i32_aarch64
#define tcg_gen_muls2_i32 tcg_gen_muls2_i32_aarch64
#define tcg_gen_mulsu2_i32 tcg_gen_mulsu2_i32_aarch64
#define tcg_gen_ext8s_i32 tcg_gen_ext8s_i32_aarch64
#define tcg_gen_ext16s_i32 tcg_gen_ext16s_i32_aarch64
#define tcg_gen_ext8u_i32 tcg_gen_ext8u_i32_aarch64
#define tcg_gen_ext16u_i32 tcg_gen_ext16u_i32_aarch64
#define tcg_gen_bswap16_i32 tcg_gen_bswap16_i32_aarch64
#define tcg_gen_bswap32_i32 tcg_gen_bswap32_i32_aarch64
#define tcg_gen_smin_i32 tcg_gen_smin_i32_aarch64
#define tcg_gen_umin_i32 tcg_gen_umin_i32_aarch64
#define tcg_gen_smax_i32 tcg_gen_smax_i32_aarch64
#define tcg_gen_umax_i32 tcg_gen_umax_i32_aarch64
#define tcg_gen_abs_i32 tcg_gen_abs_i32_aarch64
#define tcg_gen_addi_i64 tcg_gen_addi_i64_aarch64
#define tcg_gen_subfi_i64 tcg_gen_subfi_i64_aarch64
#define tcg_gen_subi_i64 tcg_gen_subi_i64_aarch64
#define tcg_gen_andi_i64 tcg_gen_andi_i64_aarch64
#define tcg_gen_ori_i64 tcg_gen_ori_i64_aarch64
#define tcg_gen_xori_i64 tcg_gen_xori_i64_aarch64
#define tcg_gen_shli_i64 tcg_gen_shli_i64_aarch64
#define tcg_gen_shri_i64 tcg_gen_shri_i64_aarch64
#define tcg_gen_sari_i64 tcg_gen_sari_i64_aarch64
#define tcg_gen_brcond_i64 tcg_gen_brcond_i64_aarch64
#define tcg_gen_brcondi_i64 tcg_gen_brcondi_i64_aarch64
#define tcg_gen_setcond_i64 tcg_gen_setcond_i64_aarch64
#define tcg_gen_setcondi_i64 tcg_gen_setcondi_i64_aarch64
#define tcg_gen_muli_i64 tcg_gen_muli_i64_aarch64
#define tcg_gen_div_i64 tcg_gen_div_i64_aarch64
#define tcg_gen_rem_i64 tcg_gen_rem_i64_aarch64
#define tcg_gen_divu_i64 tcg_gen_divu_i64_aarch64
#define tcg_gen_remu_i64 tcg_gen_remu_i64_aarch64
#define tcg_gen_ext8s_i64 tcg_gen_ext8s_i64_aarch64
#define tcg_gen_ext16s_i64 tcg_gen_ext16s_i64_aarch64
#define tcg_gen_ext32s_i64 tcg_gen_ext32s_i64_aarch64
#define tcg_gen_ext8u_i64 tcg_gen_ext8u_i64_aarch64
#define tcg_gen_ext16u_i64 tcg_gen_ext16u_i64_aarch64
#define tcg_gen_ext32u_i64 tcg_gen_ext32u_i64_aarch64
#define tcg_gen_bswap16_i64 tcg_gen_bswap16_i64_aarch64
#define tcg_gen_bswap32_i64 tcg_gen_bswap32_i64_aarch64
#define tcg_gen_bswap64_i64 tcg_gen_bswap64_i64_aarch64
#define tcg_gen_not_i64 tcg_gen_not_i64_aarch64
#define tcg_gen_andc_i64 tcg_gen_andc_i64_aarch64
#define tcg_gen_eqv_i64 tcg_gen_eqv_i64_aarch64
#define tcg_gen_nand_i64 tcg_gen_nand_i64_aarch64
#define tcg_gen_nor_i64 tcg_gen_nor_i64_aarch64
#define tcg_gen_orc_i64 tcg_gen_orc_i64_aarch64
#define tcg_gen_clz_i64 tcg_gen_clz_i64_aarch64
#define tcg_gen_clzi_i64 tcg_gen_clzi_i64_aarch64
#define tcg_gen_ctz_i64 tcg_gen_ctz_i64_aarch64
#define tcg_gen_ctzi_i64 tcg_gen_ctzi_i64_aarch64
#define tcg_gen_clrsb_i64 tcg_gen_clrsb_i64_aarch64
#define tcg_gen_ctpop_i64 tcg_gen_ctpop_i64_aarch64
#define tcg_gen_rotl_i64 tcg_gen_rotl_i64_aarch64
#define tcg_gen_rotli_i64 tcg_gen_rotli_i64_aarch64
#define tcg_gen_rotr_i64 tcg_gen_rotr_i64_aarch64
#define tcg_gen_rotri_i64 tcg_gen_rotri_i64_aarch64
#define tcg_gen_deposit_i64 tcg_gen_deposit_i64_aarch64
#define tcg_gen_deposit_z_i64 tcg_gen_deposit_z_i64_aarch64
#define tcg_gen_extract_i64 tcg_gen_extract_i64_aarch64
#define tcg_gen_sextract_i64 tcg_gen_sextract_i64_aarch64
#define tcg_gen_extract2_i64 tcg_gen_extract2_i64_aarch64
#define tcg_gen_movcond_i64 tcg_gen_movcond_i64_aarch64
#define tcg_gen_add2_i64 tcg_gen_add2_i64_aarch64
#define tcg_gen_sub2_i64 tcg_gen_sub2_i64_aarch64
#define tcg_gen_mulu2_i64 tcg_gen_mulu2_i64_aarch64
#define tcg_gen_muls2_i64 tcg_gen_muls2_i64_aarch64
#define tcg_gen_mulsu2_i64 tcg_gen_mulsu2_i64_aarch64
#define tcg_gen_smin_i64 tcg_gen_smin_i64_aarch64
#define tcg_gen_umin_i64 tcg_gen_umin_i64_aarch64
#define tcg_gen_smax_i64 tcg_gen_smax_i64_aarch64
#define tcg_gen_umax_i64 tcg_gen_umax_i64_aarch64
#define tcg_gen_abs_i64 tcg_gen_abs_i64_aarch64
#define tcg_gen_extrl_i64_i32 tcg_gen_extrl_i64_i32_aarch64
#define tcg_gen_extrh_i64_i32 tcg_gen_extrh_i64_i32_aarch64
#define tcg_gen_extu_i32_i64 tcg_gen_extu_i32_i64_aarch64
#define tcg_gen_ext_i32_i64 tcg_gen_ext_i32_i64_aarch64
#define tcg_gen_concat_i32_i64 tcg_gen_concat_i32_i64_aarch64
#define tcg_gen_extr_i64_i32 tcg_gen_extr_i64_i32_aarch64
#define tcg_gen_extr32_i64 tcg_gen_extr32_i64_aarch64
#define tcg_gen_exit_tb tcg_gen_exit_tb_aarch64
#define tcg_gen_goto_tb tcg_gen_goto_tb_aarch64
#define tcg_gen_lookup_and_goto_ptr tcg_gen_lookup_and_goto_ptr_aarch64
#define check_exit_request check_exit_request_aarch64
#define tcg_gen_qemu_ld_i32 tcg_gen_qemu_ld_i32_aarch64
#define tcg_gen_qemu_st_i32 tcg_gen_qemu_st_i32_aarch64
#define tcg_gen_qemu_ld_i64 tcg_gen_qemu_ld_i64_aarch64
#define tcg_gen_qemu_st_i64 tcg_gen_qemu_st_i64_aarch64
#define tcg_gen_atomic_cmpxchg_i32 tcg_gen_atomic_cmpxchg_i32_aarch64
#define tcg_gen_atomic_cmpxchg_i64 tcg_gen_atomic_cmpxchg_i64_aarch64
#define tcg_gen_atomic_fetch_add_i32 tcg_gen_atomic_fetch_add_i32_aarch64
#define tcg_gen_atomic_fetch_add_i64 tcg_gen_atomic_fetch_add_i64_aarch64
#define tcg_gen_atomic_fetch_and_i32 tcg_gen_atomic_fetch_and_i32_aarch64
#define tcg_gen_atomic_fetch_and_i64 tcg_gen_atomic_fetch_and_i64_aarch64
#define tcg_gen_atomic_fetch_or_i32 tcg_gen_atomic_fetch_or_i32_aarch64
#define tcg_gen_atomic_fetch_or_i64 tcg_gen_atomic_fetch_or_i64_aarch64
#define tcg_gen_atomic_fetch_xor_i32 tcg_gen_atomic_fetch_xor_i32_aarch64
#define tcg_gen_atomic_fetch_xor_i64 tcg_gen_atomic_fetch_xor_i64_aarch64
#define tcg_gen_atomic_fetch_smin_i32 tcg_gen_atomic_fetch_smin_i32_aarch64
#define tcg_gen_atomic_fetch_smin_i64 tcg_gen_atomic_fetch_smin_i64_aarch64
#define tcg_gen_atomic_fetch_umin_i32 tcg_gen_atomic_fetch_umin_i32_aarch64
#define tcg_gen_atomic_fetch_umin_i64 tcg_gen_atomic_fetch_umin_i64_aarch64
#define tcg_gen_atomic_fetch_smax_i32 tcg_gen_atomic_fetch_smax_i32_aarch64
#define tcg_gen_atomic_fetch_smax_i64 tcg_gen_atomic_fetch_smax_i64_aarch64
#define tcg_gen_atomic_fetch_umax_i32 tcg_gen_atomic_fetch_umax_i32_aarch64
#define tcg_gen_atomic_fetch_umax_i64 tcg_gen_atomic_fetch_umax_i64_aarch64
#define tcg_gen_atomic_add_fetch_i32 tcg_gen_atomic_add_fetch_i32_aarch64
#define tcg_gen_atomic_add_fetch_i64 tcg_gen_atomic_add_fetch_i64_aarch64
#define tcg_gen_atomic_and_fetch_i32 tcg_gen_atomic_and_fetch_i32_aarch64
#define tcg_gen_atomic_and_fetch_i64 tcg_gen_atomic_and_fetch_i64_aarch64
#define tcg_gen_atomic_or_fetch_i32 tcg_gen_atomic_or_fetch_i32_aarch64
#define tcg_gen_atomic_or_fetch_i64 tcg_gen_atomic_or_fetch_i64_aarch64
#define tcg_gen_atomic_xor_fetch_i32 tcg_gen_atomic_xor_fetch_i32_aarch64
#define tcg_gen_atomic_xor_fetch_i64 tcg_gen_atomic_xor_fetch_i64_aarch64
#define tcg_gen_atomic_smin_fetch_i32 tcg_gen_atomic_smin_fetch_i32_aarch64
#define tcg_gen_atomic_smin_fetch_i64 tcg_gen_atomic_smin_fetch_i64_aarch64
#define tcg_gen_atomic_umin_fetch_i32 tcg_gen_atomic_umin_fetch_i32_aarch64
#define tcg_gen_atomic_umin_fetch_i64 tcg_gen_atomic_umin_fetch_i64_aarch64
#define tcg_gen_atomic_smax_fetch_i32 tcg_gen_atomic_smax_fetch_i32_aarch64
#define tcg_gen_atomic_smax_fetch_i64 tcg_gen_atomic_smax_fetch_i64_aarch64
#define tcg_gen_atomic_umax_fetch_i32 tcg_gen_atomic_umax_fetch_i32_aarch64
#define tcg_gen_atomic_umax_fetch_i64 tcg_gen_atomic_umax_fetch_i64_aarch64
#define tcg_gen_atomic_xchg_i32 tcg_gen_atomic_xchg_i32_aarch64
#define tcg_gen_atomic_xchg_i64 tcg_gen_atomic_xchg_i64_aarch64
#define simd_desc simd_desc_aarch64
#define tcg_gen_gvec_2_ool tcg_gen_gvec_2_ool_aarch64
#define tcg_gen_gvec_2i_ool tcg_gen_gvec_2i_ool_aarch64
#define tcg_gen_gvec_3_ool tcg_gen_gvec_3_ool_aarch64
#define tcg_gen_gvec_4_ool tcg_gen_gvec_4_ool_aarch64
#define tcg_gen_gvec_5_ool tcg_gen_gvec_5_ool_aarch64
#define tcg_gen_gvec_2_ptr tcg_gen_gvec_2_ptr_aarch64
#define tcg_gen_gvec_3_ptr tcg_gen_gvec_3_ptr_aarch64
#define tcg_gen_gvec_4_ptr tcg_gen_gvec_4_ptr_aarch64
#define tcg_gen_gvec_5_ptr tcg_gen_gvec_5_ptr_aarch64
#define tcg_gen_gvec_2 tcg_gen_gvec_2_aarch64
#define tcg_gen_gvec_2i tcg_gen_gvec_2i_aarch64
#define tcg_gen_gvec_2s tcg_gen_gvec_2s_aarch64
#define tcg_gen_gvec_3 tcg_gen_gvec_3_aarch64
#define tcg_gen_gvec_3i tcg_gen_gvec_3i_aarch64
#define tcg_gen_gvec_4 tcg_gen_gvec_4_aarch64
#define tcg_gen_gvec_mov tcg_gen_gvec_mov_aarch64
#define tcg_gen_gvec_dup_i32 tcg_gen_gvec_dup_i32_aarch64
#define tcg_gen_gvec_dup_i64 tcg_gen_gvec_dup_i64_aarch64
#define tcg_gen_gvec_dup_mem tcg_gen_gvec_dup_mem_aarch64
#define tcg_gen_gvec_dup64i tcg_gen_gvec_dup64i_aarch64
#define tcg_gen_gvec_dup32i tcg_gen_gvec_dup32i_aarch64
#define tcg_gen_gvec_dup16i tcg_gen_gvec_dup16i_aarch64
#define tcg_gen_gvec_dup8i tcg_gen_gvec_dup8i_aarch64
#define tcg_gen_gvec_not tcg_gen_gvec_not_aarch64
#define tcg_gen_vec_add8_i64 tcg_gen_vec_add8_i64_aarch64
#define tcg_gen_vec_add16_i64 tcg_gen_vec_add16_i64_aarch64
#define tcg_gen_vec_add32_i64 tcg_gen_vec_add32_i64_aarch64
#define tcg_gen_gvec_add tcg_gen_gvec_add_aarch64
#define tcg_gen_gvec_adds tcg_gen_gvec_adds_aarch64
#define tcg_gen_gvec_addi tcg_gen_gvec_addi_aarch64
#define tcg_gen_gvec_subs tcg_gen_gvec_subs_aarch64
#define tcg_gen_vec_sub8_i64 tcg_gen_vec_sub8_i64_aarch64
#define tcg_gen_vec_sub16_i64 tcg_gen_vec_sub16_i64_aarch64
#define tcg_gen_vec_sub32_i64 tcg_gen_vec_sub32_i64_aarch64
#define tcg_gen_gvec_sub tcg_gen_gvec_sub_aarch64
#define tcg_gen_gvec_mul tcg_gen_gvec_mul_aarch64
#define tcg_gen_gvec_muls tcg_gen_gvec_muls_aarch64
#define tcg_gen_gvec_muli tcg_gen_gvec_muli_aarch64
#define tcg_gen_gvec_ssadd tcg_gen_gvec_ssadd_aarch64
#define tcg_gen_gvec_sssub tcg_gen_gvec_sssub_aarch64
#define tcg_gen_gvec_usadd tcg_gen_gvec_usadd_aarch64
#define tcg_gen_gvec_ussub tcg_gen_gvec_ussub_aarch64
#define tcg_gen_gvec_smin tcg_gen_gvec_smin_aarch64
#define tcg_gen_gvec_umin tcg_gen_gvec_umin_aarch64
#define tcg_gen_gvec_smax tcg_gen_gvec_smax_aarch64
#define tcg_gen_gvec_umax tcg_gen_gvec_umax_aarch64
#define tcg_gen_vec_neg8_i64 tcg_gen_vec_neg8_i64_aarch64
#define tcg_gen_vec_neg16_i64 tcg_gen_vec_neg16_i64_aarch64
#define tcg_gen_vec_neg32_i64 tcg_gen_vec_neg32_i64_aarch64
#define tcg_gen_gvec_neg tcg_gen_gvec_neg_aarch64
#define tcg_gen_gvec_abs tcg_gen_gvec_abs_aarch64
#define tcg_gen_gvec_and tcg_gen_gvec_and_aarch64
#define tcg_gen_gvec_or tcg_gen_gvec_or_aarch64
#define tcg_gen_gvec_xor tcg_gen_gvec_xor_aarch64
#define tcg_gen_gvec_andc tcg_gen_gvec_andc_aarch64
#define tcg_gen_gvec_orc tcg_gen_gvec_orc_aarch64
#define tcg_gen_gvec_nand tcg_gen_gvec_nand_aarch64
#define tcg_gen_gvec_nor tcg_gen_gvec_nor_aarch64
#define tcg_gen_gvec_eqv tcg_gen_gvec_eqv_aarch64
#define tcg_gen_gvec_ands tcg_gen_gvec_ands_aarch64
#define tcg_gen_gvec_andi tcg_gen_gvec_andi_aarch64
#define tcg_gen_gvec_xors tcg_gen_gvec_xors_aarch64
#define tcg_gen_gvec_xori tcg_gen_gvec_xori_aarch64
#define tcg_gen_gvec_ors tcg_gen_gvec_ors_aarch64
#define tcg_gen_gvec_ori tcg_gen_gvec_ori_aarch64
#define tcg_gen_vec_shl8i_i64 tcg_gen_vec_shl8i_i64_aarch64
#define tcg_gen_vec_shl16i_i64 tcg_gen_vec_shl16i_i64_aarch64
#define tcg_gen_gvec_shli tcg_gen_gvec_shli_aarch64
#define tcg_gen_vec_shr8i_i64 tcg_gen_vec_shr8i_i64_aarch64
#define tcg_gen_vec_shr16i_i64 tcg_gen_vec_shr16i_i64_aarch64
#define tcg_gen_gvec_shri tcg_gen_gvec_shri_aarch64
#define tcg_gen_vec_sar8i_i64 tcg_gen_vec_sar8i_i64_aarch64
#define tcg_gen_vec_sar16i_i64 tcg_gen_vec_sar16i_i64_aarch64
#define tcg_gen_gvec_sari tcg_gen_gvec_sari_aarch64
#define tcg_gen_gvec_shls tcg_gen_gvec_shls_aarch64
#define tcg_gen_gvec_shrs tcg_gen_gvec_shrs_aarch64
#define tcg_gen_gvec_sars tcg_gen_gvec_sars_aarch64
#define tcg_gen_gvec_shlv tcg_gen_gvec_shlv_aarch64
#define tcg_gen_gvec_shrv tcg_gen_gvec_shrv_aarch64
#define tcg_gen_gvec_sarv tcg_gen_gvec_sarv_aarch64
#define tcg_gen_gvec_cmp tcg_gen_gvec_cmp_aarch64
#define tcg_gen_gvec_bitsel tcg_gen_gvec_bitsel_aarch64
#define tcg_can_emit_vecop_list tcg_can_emit_vecop_list_aarch64
#define vec_gen_2 vec_gen_2_aarch64
#define vec_gen_3 vec_gen_3_aarch64
#define vec_gen_4 vec_gen_4_aarch64
#define tcg_gen_mov_vec tcg_gen_mov_vec_aarch64
#define tcg_const_zeros_vec tcg_const_zeros_vec_aarch64
#define tcg_const_ones_vec tcg_const_ones_vec_aarch64
#define tcg_const_zeros_vec_matching tcg_const_zeros_vec_matching_aarch64
#define tcg_const_ones_vec_matching tcg_const_ones_vec_matching_aarch64
#define tcg_gen_dup64i_vec tcg_gen_dup64i_vec_aarch64
#define tcg_gen_dup32i_vec tcg_gen_dup32i_vec_aarch64
#define tcg_gen_dup16i_vec tcg_gen_dup16i_vec_aarch64
#define tcg_gen_dup8i_vec tcg_gen_dup8i_vec_aarch64
#define tcg_gen_dupi_vec tcg_gen_dupi_vec_aarch64
#define tcg_gen_dup_i64_vec tcg_gen_dup_i64_vec_aarch64
#define tcg_gen_dup_i32_vec tcg_gen_dup_i32_vec_aarch64
#define tcg_gen_dup_mem_vec tcg_gen_dup_mem_vec_aarch64
#define tcg_gen_ld_vec tcg_gen_ld_vec_aarch64
#define tcg_gen_st_vec tcg_gen_st_vec_aarch64
#define tcg_gen_stl_vec tcg_gen_stl_vec_aarch64
#define tcg_gen_and_vec tcg_gen_and_vec_aarch64
#define tcg_gen_or_vec tcg_gen_or_vec_aarch64
#define tcg_gen_xor_vec tcg_gen_xor_vec_aarch64
#define tcg_gen_andc_vec tcg_gen_andc_vec_aarch64
#define tcg_gen_orc_vec tcg_gen_orc_vec_aarch64
#define tcg_gen_nand_vec tcg_gen_nand_vec_aarch64
#define tcg_gen_nor_vec tcg_gen_nor_vec_aarch64
#define tcg_gen_eqv_vec tcg_gen_eqv_vec_aarch64
#define tcg_gen_not_vec tcg_gen_not_vec_aarch64
#define tcg_gen_neg_vec tcg_gen_neg_vec_aarch64
#define tcg_gen_abs_vec tcg_gen_abs_vec_aarch64
#define tcg_gen_shli_vec tcg_gen_shli_vec_aarch64
#define tcg_gen_shri_vec tcg_gen_shri_vec_aarch64
#define tcg_gen_sari_vec tcg_gen_sari_vec_aarch64
#define tcg_gen_cmp_vec tcg_gen_cmp_vec_aarch64
#define tcg_gen_add_vec tcg_gen_add_vec_aarch64
#define tcg_gen_sub_vec tcg_gen_sub_vec_aarch64
#define tcg_gen_mul_vec tcg_gen_mul_vec_aarch64
#define tcg_gen_ssadd_vec tcg_gen_ssadd_vec_aarch64
#define tcg_gen_usadd_vec tcg_gen_usadd_vec_aarch64
#define tcg_gen_sssub_vec tcg_gen_sssub_vec_aarch64
#define tcg_gen_ussub_vec tcg_gen_ussub_vec_aarch64
#define tcg_gen_smin_vec tcg_gen_smin_vec_aarch64
#define tcg_gen_umin_vec tcg_gen_umin_vec_aarch64
#define tcg_gen_smax_vec tcg_gen_smax_vec_aarch64
#define tcg_gen_umax_vec tcg_gen_umax_vec_aarch64
#define tcg_gen_shlv_vec tcg_gen_shlv_vec_aarch64
#define tcg_gen_shrv_vec tcg_gen_shrv_vec_aarch64
#define tcg_gen_sarv_vec tcg_gen_sarv_vec_aarch64
#define tcg_gen_shls_vec tcg_gen_shls_vec_aarch64
#define tcg_gen_shrs_vec tcg_gen_shrs_vec_aarch64
#define tcg_gen_sars_vec tcg_gen_sars_vec_aarch64
#define tcg_gen_bitsel_vec tcg_gen_bitsel_vec_aarch64
#define tcg_gen_cmpsel_vec tcg_gen_cmpsel_vec_aarch64
#define tb_htable_lookup tb_htable_lookup_aarch64
#define tb_set_jmp_target tb_set_jmp_target_aarch64
#define cpu_exec cpu_exec_aarch64
#define cpu_loop_exit_noexc cpu_loop_exit_noexc_aarch64
#define cpu_reloading_memory_map cpu_reloading_memory_map_aarch64
#define cpu_loop_exit cpu_loop_exit_aarch64
#define cpu_loop_exit_restore cpu_loop_exit_restore_aarch64
#define cpu_loop_exit_atomic cpu_loop_exit_atomic_aarch64
#define tlb_init tlb_init_aarch64
#define tlb_flush_by_mmuidx tlb_flush_by_mmuidx_aarch64
#define tlb_flush tlb_flush_aarch64
#define tlb_flush_by_mmuidx_all_cpus tlb_flush_by_mmuidx_all_cpus_aarch64
#define tlb_flush_all_cpus tlb_flush_all_cpus_aarch64
#define tlb_flush_by_mmuidx_all_cpus_synced tlb_flush_by_mmuidx_all_cpus_synced_aarch64
#define tlb_flush_all_cpus_synced tlb_flush_all_cpus_synced_aarch64
#define tlb_flush_page_by_mmuidx tlb_flush_page_by_mmuidx_aarch64
#define tlb_flush_page tlb_flush_page_aarch64
#define tlb_flush_page_by_mmuidx_all_cpus tlb_flush_page_by_mmuidx_all_cpus_aarch64
#define tlb_flush_page_all_cpus tlb_flush_page_all_cpus_aarch64
#define tlb_flush_page_by_mmuidx_all_cpus_synced tlb_flush_page_by_mmuidx_all_cpus_synced_aarch64
#define tlb_flush_page_all_cpus_synced tlb_flush_page_all_cpus_synced_aarch64
#define tlb_protect_code tlb_protect_code_aarch64
#define tlb_unprotect_code tlb_unprotect_code_aarch64
#define tlb_reset_dirty tlb_reset_dirty_aarch64
#define tlb_set_dirty tlb_set_dirty_aarch64
#define tlb_set_page_with_attrs tlb_set_page_with_attrs_aarch64
#define tlb_set_page tlb_set_page_aarch64
#define get_page_addr_code_hostp get_page_addr_code_hostp_aarch64
#define get_page_addr_code get_page_addr_code_aarch64
#define probe_access probe_access_aarch64
#define tlb_vaddr_to_host tlb_vaddr_to_host_aarch64
#define tlb_vaddr_to_paddr tlb_vaddr_to_paddr_aarch64
#define helper_ret_ldub_mmu helper_ret_ldub_mmu_aarch64
#define helper_le_lduw_mmu helper_le_lduw_mmu_aarch64
#define helper_be_lduw_mmu helper_be_lduw_mmu_aarch64
#define helper_le_ldul_mmu helper_le_ldul_mmu_aarch64
#define helper_be_ldul_mmu helper_be_ldul_mmu_aarch64
#define helper_le_ldq_mmu helper_le_ldq_mmu_aarch64
#define helper_be_ldq_mmu helper_be_ldq_mmu_aarch64
#define helper_ret_ldsb_mmu helper_ret_ldsb_mmu_aarch64
#define helper_le_ldsw_mmu helper_le_ldsw_mmu_aarch64
#define helper_be_ldsw_mmu helper_be_ldsw_mmu_aarch64
#define helper_le_ldsl_mmu helper_le_ldsl_mmu_aarch64
#define helper_be_ldsl_mmu helper_be_ldsl_mmu_aarch64
#define cpu_ldub_mmuidx_ra cpu_ldub_mmuidx_ra_aarch64
#define cpu_ldsb_mmuidx_ra cpu_ldsb_mmuidx_ra_aarch64
#define cpu_lduw_mmuidx_ra cpu_lduw_mmuidx_ra_aarch64
#define cpu_ldsw_mmuidx_ra cpu_ldsw_mmuidx_ra_aarch64
#define cpu_ldl_mmuidx_ra cpu_ldl_mmuidx_ra_aarch64
#define cpu_ldq_mmuidx_ra cpu_ldq_mmuidx_ra_aarch64
#define cpu_ldub_data_ra cpu_ldub_data_ra_aarch64
#define cpu_ldsb_data_ra cpu_ldsb_data_ra_aarch64
#define cpu_lduw_data_ra cpu_lduw_data_ra_aarch64
#define cpu_ldsw_data_ra cpu_ldsw_data_ra_aarch64
#define cpu_ldl_data_ra cpu_ldl_data_ra_aarch64
#define cpu_ldq_data_ra cpu_ldq_data_ra_aarch64
#define cpu_ldub_data cpu_ldub_data_aarch64
#define cpu_ldsb_data cpu_ldsb_data_aarch64
#define cpu_lduw_data cpu_lduw_data_aarch64
#define cpu_ldsw_data cpu_ldsw_data_aarch64
#define cpu_ldl_data cpu_ldl_data_aarch64
#define cpu_ldq_data cpu_ldq_data_aarch64
#define helper_ret_stb_mmu helper_ret_stb_mmu_aarch64
#define helper_le_stw_mmu helper_le_stw_mmu_aarch64
#define helper_be_stw_mmu helper_be_stw_mmu_aarch64
#define helper_le_stl_mmu helper_le_stl_mmu_aarch64
#define helper_be_stl_mmu helper_be_stl_mmu_aarch64
#define helper_le_stq_mmu helper_le_stq_mmu_aarch64
#define helper_be_stq_mmu helper_be_stq_mmu_aarch64
#define cpu_stb_mmuidx_ra cpu_stb_mmuidx_ra_aarch64
#define cpu_stw_mmuidx_ra cpu_stw_mmuidx_ra_aarch64
#define cpu_stl_mmuidx_ra cpu_stl_mmuidx_ra_aarch64
#define cpu_stq_mmuidx_ra cpu_stq_mmuidx_ra_aarch64
#define cpu_stb_data_ra cpu_stb_data_ra_aarch64
#define cpu_stw_data_ra cpu_stw_data_ra_aarch64
#define cpu_stl_data_ra cpu_stl_data_ra_aarch64
#define cpu_stq_data_ra cpu_stq_data_ra_aarch64
#define cpu_stb_data cpu_stb_data_aarch64
#define cpu_stw_data cpu_stw_data_aarch64
#define cpu_stl_data cpu_stl_data_aarch64
#define cpu_stq_data cpu_stq_data_aarch64
#define helper_atomic_cmpxchgb_mmu helper_atomic_cmpxchgb_mmu_aarch64
#define helper_atomic_xchgb_mmu helper_atomic_xchgb_mmu_aarch64
#define helper_atomic_fetch_addb_mmu helper_atomic_fetch_addb_mmu_aarch64
#define helper_atomic_fetch_andb_mmu helper_atomic_fetch_andb_mmu_aarch64
#define helper_atomic_fetch_orb_mmu helper_atomic_fetch_orb_mmu_aarch64
#define helper_atomic_fetch_xorb_mmu helper_atomic_fetch_xorb_mmu_aarch64
#define helper_atomic_add_fetchb_mmu helper_atomic_add_fetchb_mmu_aarch64
#define helper_atomic_and_fetchb_mmu helper_atomic_and_fetchb_mmu_aarch64
#define helper_atomic_or_fetchb_mmu helper_atomic_or_fetchb_mmu_aarch64
#define helper_atomic_xor_fetchb_mmu helper_atomic_xor_fetchb_mmu_aarch64
#define helper_atomic_fetch_sminb_mmu helper_atomic_fetch_sminb_mmu_aarch64
#define helper_atomic_fetch_uminb_mmu helper_atomic_fetch_uminb_mmu_aarch64
#define helper_atomic_fetch_smaxb_mmu helper_atomic_fetch_smaxb_mmu_aarch64
#define helper_atomic_fetch_umaxb_mmu helper_atomic_fetch_umaxb_mmu_aarch64
#define helper_atomic_smin_fetchb_mmu helper_atomic_smin_fetchb_mmu_aarch64
#define helper_atomic_umin_fetchb_mmu helper_atomic_umin_fetchb_mmu_aarch64
#define helper_atomic_smax_fetchb_mmu helper_atomic_smax_fetchb_mmu_aarch64
#define helper_atomic_umax_fetchb_mmu helper_atomic_umax_fetchb_mmu_aarch64
#define helper_atomic_cmpxchgw_le_mmu helper_atomic_cmpxchgw_le_mmu_aarch64
#define helper_atomic_xchgw_le_mmu helper_atomic_xchgw_le_mmu_aarch64
#define helper_atomic_fetch_addw_le_mmu helper_atomic_fetch_addw_le_mmu_aarch64
#define helper_atomic_fetch_andw_le_mmu helper_atomic_fetch_andw_le_mmu_aarch64
#define helper_atomic_fetch_orw_le_mmu helper_atomic_fetch_orw_le_mmu_aarch64
#define helper_atomic_fetch_xorw_le_mmu helper_atomic_fetch_xorw_le_mmu_aarch64
#define helper_atomic_add_fetchw_le_mmu helper_atomic_add_fetchw_le_mmu_aarch64
#define helper_atomic_and_fetchw_le_mmu helper_atomic_and_fetchw_le_mmu_aarch64
#define helper_atomic_or_fetchw_le_mmu helper_atomic_or_fetchw_le_mmu_aarch64
#define helper_atomic_xor_fetchw_le_mmu helper_atomic_xor_fetchw_le_mmu_aarch64
#define helper_atomic_fetch_sminw_le_mmu helper_atomic_fetch_sminw_le_mmu_aarch64
#define helper_atomic_fetch_uminw_le_mmu helper_atomic_fetch_uminw_le_mmu_aarch64
#define helper_atomic_fetch_smaxw_le_mmu helper_atomic_fetch_smaxw_le_mmu_aarch64
#define helper_atomic_fetch_umaxw_le_mmu helper_atomic_fetch_umaxw_le_mmu_aarch64
#define helper_atomic_smin_fetchw_le_mmu helper_atomic_smin_fetchw_le_mmu_aarch64
#define helper_atomic_umin_fetchw_le_mmu helper_atomic_umin_fetchw_le_mmu_aarch64
#define helper_atomic_smax_fetchw_le_mmu helper_atomic_smax_fetchw_le_mmu_aarch64
#define helper_atomic_umax_fetchw_le_mmu helper_atomic_umax_fetchw_le_mmu_aarch64
#define helper_atomic_cmpxchgw_be_mmu helper_atomic_cmpxchgw_be_mmu_aarch64
#define helper_atomic_xchgw_be_mmu helper_atomic_xchgw_be_mmu_aarch64
#define helper_atomic_fetch_andw_be_mmu helper_atomic_fetch_andw_be_mmu_aarch64
#define helper_atomic_fetch_orw_be_mmu helper_atomic_fetch_orw_be_mmu_aarch64
#define helper_atomic_fetch_xorw_be_mmu helper_atomic_fetch_xorw_be_mmu_aarch64
#define helper_atomic_and_fetchw_be_mmu helper_atomic_and_fetchw_be_mmu_aarch64
#define helper_atomic_or_fetchw_be_mmu helper_atomic_or_fetchw_be_mmu_aarch64
#define helper_atomic_xor_fetchw_be_mmu helper_atomic_xor_fetchw_be_mmu_aarch64
#define helper_atomic_fetch_sminw_be_mmu helper_atomic_fetch_sminw_be_mmu_aarch64
#define helper_atomic_fetch_uminw_be_mmu helper_atomic_fetch_uminw_be_mmu_aarch64
#define helper_atomic_fetch_smaxw_be_mmu helper_atomic_fetch_smaxw_be_mmu_aarch64
#define helper_atomic_fetch_umaxw_be_mmu helper_atomic_fetch_umaxw_be_mmu_aarch64
#define helper_atomic_smin_fetchw_be_mmu helper_atomic_smin_fetchw_be_mmu_aarch64
#define helper_atomic_umin_fetchw_be_mmu helper_atomic_umin_fetchw_be_mmu_aarch64
#define helper_atomic_smax_fetchw_be_mmu helper_atomic_smax_fetchw_be_mmu_aarch64
#define helper_atomic_umax_fetchw_be_mmu helper_atomic_umax_fetchw_be_mmu_aarch64
#define helper_atomic_fetch_addw_be_mmu helper_atomic_fetch_addw_be_mmu_aarch64
#define helper_atomic_add_fetchw_be_mmu helper_atomic_add_fetchw_be_mmu_aarch64
#define helper_atomic_cmpxchgl_le_mmu helper_atomic_cmpxchgl_le_mmu_aarch64
#define helper_atomic_xchgl_le_mmu helper_atomic_xchgl_le_mmu_aarch64
#define helper_atomic_fetch_addl_le_mmu helper_atomic_fetch_addl_le_mmu_aarch64
#define helper_atomic_fetch_andl_le_mmu helper_atomic_fetch_andl_le_mmu_aarch64
#define helper_atomic_fetch_orl_le_mmu helper_atomic_fetch_orl_le_mmu_aarch64
#define helper_atomic_fetch_xorl_le_mmu helper_atomic_fetch_xorl_le_mmu_aarch64
#define helper_atomic_add_fetchl_le_mmu helper_atomic_add_fetchl_le_mmu_aarch64
#define helper_atomic_and_fetchl_le_mmu helper_atomic_and_fetchl_le_mmu_aarch64
#define helper_atomic_or_fetchl_le_mmu helper_atomic_or_fetchl_le_mmu_aarch64
#define helper_atomic_xor_fetchl_le_mmu helper_atomic_xor_fetchl_le_mmu_aarch64
#define helper_atomic_fetch_sminl_le_mmu helper_atomic_fetch_sminl_le_mmu_aarch64
#define helper_atomic_fetch_uminl_le_mmu helper_atomic_fetch_uminl_le_mmu_aarch64
#define helper_atomic_fetch_smaxl_le_mmu helper_atomic_fetch_smaxl_le_mmu_aarch64
#define helper_atomic_fetch_umaxl_le_mmu helper_atomic_fetch_umaxl_le_mmu_aarch64
#define helper_atomic_smin_fetchl_le_mmu helper_atomic_smin_fetchl_le_mmu_aarch64
#define helper_atomic_umin_fetchl_le_mmu helper_atomic_umin_fetchl_le_mmu_aarch64
#define helper_atomic_smax_fetchl_le_mmu helper_atomic_smax_fetchl_le_mmu_aarch64
#define helper_atomic_umax_fetchl_le_mmu helper_atomic_umax_fetchl_le_mmu_aarch64
#define helper_atomic_cmpxchgl_be_mmu helper_atomic_cmpxchgl_be_mmu_aarch64
#define helper_atomic_xchgl_be_mmu helper_atomic_xchgl_be_mmu_aarch64
#define helper_atomic_fetch_andl_be_mmu helper_atomic_fetch_andl_be_mmu_aarch64
#define helper_atomic_fetch_orl_be_mmu helper_atomic_fetch_orl_be_mmu_aarch64
#define helper_atomic_fetch_xorl_be_mmu helper_atomic_fetch_xorl_be_mmu_aarch64
#define helper_atomic_and_fetchl_be_mmu helper_atomic_and_fetchl_be_mmu_aarch64
#define helper_atomic_or_fetchl_be_mmu helper_atomic_or_fetchl_be_mmu_aarch64
#define helper_atomic_xor_fetchl_be_mmu helper_atomic_xor_fetchl_be_mmu_aarch64
#define helper_atomic_fetch_sminl_be_mmu helper_atomic_fetch_sminl_be_mmu_aarch64
#define helper_atomic_fetch_uminl_be_mmu helper_atomic_fetch_uminl_be_mmu_aarch64
#define helper_atomic_fetch_smaxl_be_mmu helper_atomic_fetch_smaxl_be_mmu_aarch64
#define helper_atomic_fetch_umaxl_be_mmu helper_atomic_fetch_umaxl_be_mmu_aarch64
#define helper_atomic_smin_fetchl_be_mmu helper_atomic_smin_fetchl_be_mmu_aarch64
#define helper_atomic_umin_fetchl_be_mmu helper_atomic_umin_fetchl_be_mmu_aarch64
#define helper_atomic_smax_fetchl_be_mmu helper_atomic_smax_fetchl_be_mmu_aarch64
#define helper_atomic_umax_fetchl_be_mmu helper_atomic_umax_fetchl_be_mmu_aarch64
#define helper_atomic_fetch_addl_be_mmu helper_atomic_fetch_addl_be_mmu_aarch64
#define helper_atomic_add_fetchl_be_mmu helper_atomic_add_fetchl_be_mmu_aarch64
#define helper_atomic_cmpxchgq_le_mmu helper_atomic_cmpxchgq_le_mmu_aarch64
#define helper_atomic_xchgq_le_mmu helper_atomic_xchgq_le_mmu_aarch64
#define helper_atomic_fetch_addq_le_mmu helper_atomic_fetch_addq_le_mmu_aarch64
#define helper_atomic_fetch_andq_le_mmu helper_atomic_fetch_andq_le_mmu_aarch64
#define helper_atomic_fetch_orq_le_mmu helper_atomic_fetch_orq_le_mmu_aarch64
#define helper_atomic_fetch_xorq_le_mmu helper_atomic_fetch_xorq_le_mmu_aarch64
#define helper_atomic_add_fetchq_le_mmu helper_atomic_add_fetchq_le_mmu_aarch64
#define helper_atomic_and_fetchq_le_mmu helper_atomic_and_fetchq_le_mmu_aarch64
#define helper_atomic_or_fetchq_le_mmu helper_atomic_or_fetchq_le_mmu_aarch64
#define helper_atomic_xor_fetchq_le_mmu helper_atomic_xor_fetchq_le_mmu_aarch64
#define helper_atomic_fetch_sminq_le_mmu helper_atomic_fetch_sminq_le_mmu_aarch64
#define helper_atomic_fetch_uminq_le_mmu helper_atomic_fetch_uminq_le_mmu_aarch64
#define helper_atomic_fetch_smaxq_le_mmu helper_atomic_fetch_smaxq_le_mmu_aarch64
#define helper_atomic_fetch_umaxq_le_mmu helper_atomic_fetch_umaxq_le_mmu_aarch64
#define helper_atomic_smin_fetchq_le_mmu helper_atomic_smin_fetchq_le_mmu_aarch64
#define helper_atomic_umin_fetchq_le_mmu helper_atomic_umin_fetchq_le_mmu_aarch64
#define helper_atomic_smax_fetchq_le_mmu helper_atomic_smax_fetchq_le_mmu_aarch64
#define helper_atomic_umax_fetchq_le_mmu helper_atomic_umax_fetchq_le_mmu_aarch64
#define helper_atomic_cmpxchgq_be_mmu helper_atomic_cmpxchgq_be_mmu_aarch64
#define helper_atomic_xchgq_be_mmu helper_atomic_xchgq_be_mmu_aarch64
#define helper_atomic_fetch_andq_be_mmu helper_atomic_fetch_andq_be_mmu_aarch64
#define helper_atomic_fetch_orq_be_mmu helper_atomic_fetch_orq_be_mmu_aarch64
#define helper_atomic_fetch_xorq_be_mmu helper_atomic_fetch_xorq_be_mmu_aarch64
#define helper_atomic_and_fetchq_be_mmu helper_atomic_and_fetchq_be_mmu_aarch64
#define helper_atomic_or_fetchq_be_mmu helper_atomic_or_fetchq_be_mmu_aarch64
#define helper_atomic_xor_fetchq_be_mmu helper_atomic_xor_fetchq_be_mmu_aarch64
#define helper_atomic_fetch_sminq_be_mmu helper_atomic_fetch_sminq_be_mmu_aarch64
#define helper_atomic_fetch_uminq_be_mmu helper_atomic_fetch_uminq_be_mmu_aarch64
#define helper_atomic_fetch_smaxq_be_mmu helper_atomic_fetch_smaxq_be_mmu_aarch64
#define helper_atomic_fetch_umaxq_be_mmu helper_atomic_fetch_umaxq_be_mmu_aarch64
#define helper_atomic_smin_fetchq_be_mmu helper_atomic_smin_fetchq_be_mmu_aarch64
#define helper_atomic_umin_fetchq_be_mmu helper_atomic_umin_fetchq_be_mmu_aarch64
#define helper_atomic_smax_fetchq_be_mmu helper_atomic_smax_fetchq_be_mmu_aarch64
#define helper_atomic_umax_fetchq_be_mmu helper_atomic_umax_fetchq_be_mmu_aarch64
#define helper_atomic_fetch_addq_be_mmu helper_atomic_fetch_addq_be_mmu_aarch64
#define helper_atomic_add_fetchq_be_mmu helper_atomic_add_fetchq_be_mmu_aarch64
#define helper_atomic_cmpxchgb helper_atomic_cmpxchgb_aarch64
#define helper_atomic_xchgb helper_atomic_xchgb_aarch64
#define helper_atomic_fetch_addb helper_atomic_fetch_addb_aarch64
#define helper_atomic_fetch_andb helper_atomic_fetch_andb_aarch64
#define helper_atomic_fetch_orb helper_atomic_fetch_orb_aarch64
#define helper_atomic_fetch_xorb helper_atomic_fetch_xorb_aarch64
#define helper_atomic_add_fetchb helper_atomic_add_fetchb_aarch64
#define helper_atomic_and_fetchb helper_atomic_and_fetchb_aarch64
#define helper_atomic_or_fetchb helper_atomic_or_fetchb_aarch64
#define helper_atomic_xor_fetchb helper_atomic_xor_fetchb_aarch64
#define helper_atomic_fetch_sminb helper_atomic_fetch_sminb_aarch64
#define helper_atomic_fetch_uminb helper_atomic_fetch_uminb_aarch64
#define helper_atomic_fetch_smaxb helper_atomic_fetch_smaxb_aarch64
#define helper_atomic_fetch_umaxb helper_atomic_fetch_umaxb_aarch64
#define helper_atomic_smin_fetchb helper_atomic_smin_fetchb_aarch64
#define helper_atomic_umin_fetchb helper_atomic_umin_fetchb_aarch64
#define helper_atomic_smax_fetchb helper_atomic_smax_fetchb_aarch64
#define helper_atomic_umax_fetchb helper_atomic_umax_fetchb_aarch64
#define helper_atomic_cmpxchgw_le helper_atomic_cmpxchgw_le_aarch64
#define helper_atomic_xchgw_le helper_atomic_xchgw_le_aarch64
#define helper_atomic_fetch_addw_le helper_atomic_fetch_addw_le_aarch64
#define helper_atomic_fetch_andw_le helper_atomic_fetch_andw_le_aarch64
#define helper_atomic_fetch_orw_le helper_atomic_fetch_orw_le_aarch64
#define helper_atomic_fetch_xorw_le helper_atomic_fetch_xorw_le_aarch64
#define helper_atomic_add_fetchw_le helper_atomic_add_fetchw_le_aarch64
#define helper_atomic_and_fetchw_le helper_atomic_and_fetchw_le_aarch64
#define helper_atomic_or_fetchw_le helper_atomic_or_fetchw_le_aarch64
#define helper_atomic_xor_fetchw_le helper_atomic_xor_fetchw_le_aarch64
#define helper_atomic_fetch_sminw_le helper_atomic_fetch_sminw_le_aarch64
#define helper_atomic_fetch_uminw_le helper_atomic_fetch_uminw_le_aarch64
#define helper_atomic_fetch_smaxw_le helper_atomic_fetch_smaxw_le_aarch64
#define helper_atomic_fetch_umaxw_le helper_atomic_fetch_umaxw_le_aarch64
#define helper_atomic_smin_fetchw_le helper_atomic_smin_fetchw_le_aarch64
#define helper_atomic_umin_fetchw_le helper_atomic_umin_fetchw_le_aarch64
#define helper_atomic_smax_fetchw_le helper_atomic_smax_fetchw_le_aarch64
#define helper_atomic_umax_fetchw_le helper_atomic_umax_fetchw_le_aarch64
#define helper_atomic_cmpxchgw_be helper_atomic_cmpxchgw_be_aarch64
#define helper_atomic_xchgw_be helper_atomic_xchgw_be_aarch64
#define helper_atomic_fetch_andw_be helper_atomic_fetch_andw_be_aarch64
#define helper_atomic_fetch_orw_be helper_atomic_fetch_orw_be_aarch64
#define helper_atomic_fetch_xorw_be helper_atomic_fetch_xorw_be_aarch64
#define helper_atomic_and_fetchw_be helper_atomic_and_fetchw_be_aarch64
#define helper_atomic_or_fetchw_be helper_atomic_or_fetchw_be_aarch64
#define helper_atomic_xor_fetchw_be helper_atomic_xor_fetchw_be_aarch64
#define helper_atomic_fetch_sminw_be helper_atomic_fetch_sminw_be_aarch64
#define helper_atomic_fetch_uminw_be helper_atomic_fetch_uminw_be_aarch64
#define helper_atomic_fetch_smaxw_be helper_atomic_fetch_smaxw_be_aarch64
#define helper_atomic_fetch_umaxw_be helper_atomic_fetch_umaxw_be_aarch64
#define helper_atomic_smin_fetchw_be helper_atomic_smin_fetchw_be_aarch64
#define helper_atomic_umin_fetchw_be helper_atomic_umin_fetchw_be_aarch64
#define helper_atomic_smax_fetchw_be helper_atomic_smax_fetchw_be_aarch64
#define helper_atomic_umax_fetchw_be helper_atomic_umax_fetchw_be_aarch64
#define helper_atomic_fetch_addw_be helper_atomic_fetch_addw_be_aarch64
#define helper_atomic_add_fetchw_be helper_atomic_add_fetchw_be_aarch64
#define helper_atomic_cmpxchgl_le helper_atomic_cmpxchgl_le_aarch64
#define helper_atomic_xchgl_le helper_atomic_xchgl_le_aarch64
#define helper_atomic_fetch_addl_le helper_atomic_fetch_addl_le_aarch64
#define helper_atomic_fetch_andl_le helper_atomic_fetch_andl_le_aarch64
#define helper_atomic_fetch_orl_le helper_atomic_fetch_orl_le_aarch64
#define helper_atomic_fetch_xorl_le helper_atomic_fetch_xorl_le_aarch64
#define helper_atomic_add_fetchl_le helper_atomic_add_fetchl_le_aarch64
#define helper_atomic_and_fetchl_le helper_atomic_and_fetchl_le_aarch64
#define helper_atomic_or_fetchl_le helper_atomic_or_fetchl_le_aarch64
#define helper_atomic_xor_fetchl_le helper_atomic_xor_fetchl_le_aarch64
#define helper_atomic_fetch_sminl_le helper_atomic_fetch_sminl_le_aarch64
#define helper_atomic_fetch_uminl_le helper_atomic_fetch_uminl_le_aarch64
#define helper_atomic_fetch_smaxl_le helper_atomic_fetch_smaxl_le_aarch64
#define helper_atomic_fetch_umaxl_le helper_atomic_fetch_umaxl_le_aarch64
#define helper_atomic_smin_fetchl_le helper_atomic_smin_fetchl_le_aarch64
#define helper_atomic_umin_fetchl_le helper_atomic_umin_fetchl_le_aarch64
#define helper_atomic_smax_fetchl_le helper_atomic_smax_fetchl_le_aarch64
#define helper_atomic_umax_fetchl_le helper_atomic_umax_fetchl_le_aarch64
#define helper_atomic_cmpxchgl_be helper_atomic_cmpxchgl_be_aarch64
#define helper_atomic_xchgl_be helper_atomic_xchgl_be_aarch64
#define helper_atomic_fetch_andl_be helper_atomic_fetch_andl_be_aarch64
#define helper_atomic_fetch_orl_be helper_atomic_fetch_orl_be_aarch64
#define helper_atomic_fetch_xorl_be helper_atomic_fetch_xorl_be_aarch64
#define helper_atomic_and_fetchl_be helper_atomic_and_fetchl_be_aarch64
#define helper_atomic_or_fetchl_be helper_atomic_or_fetchl_be_aarch64
#define helper_atomic_xor_fetchl_be helper_atomic_xor_fetchl_be_aarch64
#define helper_atomic_fetch_sminl_be helper_atomic_fetch_sminl_be_aarch64
#define helper_atomic_fetch_uminl_be helper_atomic_fetch_uminl_be_aarch64
#define helper_atomic_fetch_smaxl_be helper_atomic_fetch_smaxl_be_aarch64
#define helper_atomic_fetch_umaxl_be helper_atomic_fetch_umaxl_be_aarch64
#define helper_atomic_smin_fetchl_be helper_atomic_smin_fetchl_be_aarch64
#define helper_atomic_umin_fetchl_be helper_atomic_umin_fetchl_be_aarch64
#define helper_atomic_smax_fetchl_be helper_atomic_smax_fetchl_be_aarch64
#define helper_atomic_umax_fetchl_be helper_atomic_umax_fetchl_be_aarch64
#define helper_atomic_fetch_addl_be helper_atomic_fetch_addl_be_aarch64
#define helper_atomic_add_fetchl_be helper_atomic_add_fetchl_be_aarch64
#define helper_atomic_cmpxchgq_le helper_atomic_cmpxchgq_le_aarch64
#define helper_atomic_xchgq_le helper_atomic_xchgq_le_aarch64
#define helper_atomic_fetch_addq_le helper_atomic_fetch_addq_le_aarch64
#define helper_atomic_fetch_andq_le helper_atomic_fetch_andq_le_aarch64
#define helper_atomic_fetch_orq_le helper_atomic_fetch_orq_le_aarch64
#define helper_atomic_fetch_xorq_le helper_atomic_fetch_xorq_le_aarch64
#define helper_atomic_add_fetchq_le helper_atomic_add_fetchq_le_aarch64
#define helper_atomic_and_fetchq_le helper_atomic_and_fetchq_le_aarch64
#define helper_atomic_or_fetchq_le helper_atomic_or_fetchq_le_aarch64
#define helper_atomic_xor_fetchq_le helper_atomic_xor_fetchq_le_aarch64
#define helper_atomic_fetch_sminq_le helper_atomic_fetch_sminq_le_aarch64
#define helper_atomic_fetch_uminq_le helper_atomic_fetch_uminq_le_aarch64
#define helper_atomic_fetch_smaxq_le helper_atomic_fetch_smaxq_le_aarch64
#define helper_atomic_fetch_umaxq_le helper_atomic_fetch_umaxq_le_aarch64
#define helper_atomic_smin_fetchq_le helper_atomic_smin_fetchq_le_aarch64
#define helper_atomic_umin_fetchq_le helper_atomic_umin_fetchq_le_aarch64
#define helper_atomic_smax_fetchq_le helper_atomic_smax_fetchq_le_aarch64
#define helper_atomic_umax_fetchq_le helper_atomic_umax_fetchq_le_aarch64
#define helper_atomic_cmpxchgq_be helper_atomic_cmpxchgq_be_aarch64
#define helper_atomic_xchgq_be helper_atomic_xchgq_be_aarch64
#define helper_atomic_fetch_andq_be helper_atomic_fetch_andq_be_aarch64
#define helper_atomic_fetch_orq_be helper_atomic_fetch_orq_be_aarch64
#define helper_atomic_fetch_xorq_be helper_atomic_fetch_xorq_be_aarch64
#define helper_atomic_and_fetchq_be helper_atomic_and_fetchq_be_aarch64
#define helper_atomic_or_fetchq_be helper_atomic_or_fetchq_be_aarch64
#define helper_atomic_xor_fetchq_be helper_atomic_xor_fetchq_be_aarch64
#define helper_atomic_fetch_sminq_be helper_atomic_fetch_sminq_be_aarch64
#define helper_atomic_fetch_uminq_be helper_atomic_fetch_uminq_be_aarch64
#define helper_atomic_fetch_smaxq_be helper_atomic_fetch_smaxq_be_aarch64
#define helper_atomic_fetch_umaxq_be helper_atomic_fetch_umaxq_be_aarch64
#define helper_atomic_smin_fetchq_be helper_atomic_smin_fetchq_be_aarch64
#define helper_atomic_umin_fetchq_be helper_atomic_umin_fetchq_be_aarch64
#define helper_atomic_smax_fetchq_be helper_atomic_smax_fetchq_be_aarch64
#define helper_atomic_umax_fetchq_be helper_atomic_umax_fetchq_be_aarch64
#define helper_atomic_fetch_addq_be helper_atomic_fetch_addq_be_aarch64
#define helper_atomic_add_fetchq_be helper_atomic_add_fetchq_be_aarch64
#define cpu_ldub_code cpu_ldub_code_aarch64
#define cpu_lduw_code cpu_lduw_code_aarch64
#define cpu_ldl_code cpu_ldl_code_aarch64
#define cpu_ldq_code cpu_ldq_code_aarch64
#define helper_div_i32 helper_div_i32_aarch64
#define helper_rem_i32 helper_rem_i32_aarch64
#define helper_divu_i32 helper_divu_i32_aarch64
#define helper_remu_i32 helper_remu_i32_aarch64
#define helper_shl_i64 helper_shl_i64_aarch64
#define helper_shr_i64 helper_shr_i64_aarch64
#define helper_sar_i64 helper_sar_i64_aarch64
#define helper_div_i64 helper_div_i64_aarch64
#define helper_rem_i64 helper_rem_i64_aarch64
#define helper_divu_i64 helper_divu_i64_aarch64
#define helper_remu_i64 helper_remu_i64_aarch64
#define helper_muluh_i64 helper_muluh_i64_aarch64
#define helper_mulsh_i64 helper_mulsh_i64_aarch64
#define helper_clz_i32 helper_clz_i32_aarch64
#define helper_ctz_i32 helper_ctz_i32_aarch64
#define helper_clz_i64 helper_clz_i64_aarch64
#define helper_ctz_i64 helper_ctz_i64_aarch64
#define helper_clrsb_i32 helper_clrsb_i32_aarch64
#define helper_clrsb_i64 helper_clrsb_i64_aarch64
#define helper_ctpop_i32 helper_ctpop_i32_aarch64
#define helper_ctpop_i64 helper_ctpop_i64_aarch64
#define helper_lookup_tb_ptr helper_lookup_tb_ptr_aarch64
#define helper_exit_atomic helper_exit_atomic_aarch64
#define helper_gvec_add8 helper_gvec_add8_aarch64
#define helper_gvec_add16 helper_gvec_add16_aarch64
#define helper_gvec_add32 helper_gvec_add32_aarch64
#define helper_gvec_add64 helper_gvec_add64_aarch64
#define helper_gvec_adds8 helper_gvec_adds8_aarch64
#define helper_gvec_adds16 helper_gvec_adds16_aarch64
#define helper_gvec_adds32 helper_gvec_adds32_aarch64
#define helper_gvec_adds64 helper_gvec_adds64_aarch64
#define helper_gvec_sub8 helper_gvec_sub8_aarch64
#define helper_gvec_sub16 helper_gvec_sub16_aarch64
#define helper_gvec_sub32 helper_gvec_sub32_aarch64
#define helper_gvec_sub64 helper_gvec_sub64_aarch64
#define helper_gvec_subs8 helper_gvec_subs8_aarch64
#define helper_gvec_subs16 helper_gvec_subs16_aarch64
#define helper_gvec_subs32 helper_gvec_subs32_aarch64
#define helper_gvec_subs64 helper_gvec_subs64_aarch64
#define helper_gvec_mul8 helper_gvec_mul8_aarch64
#define helper_gvec_mul16 helper_gvec_mul16_aarch64
#define helper_gvec_mul32 helper_gvec_mul32_aarch64
#define helper_gvec_mul64 helper_gvec_mul64_aarch64
#define helper_gvec_muls8 helper_gvec_muls8_aarch64
#define helper_gvec_muls16 helper_gvec_muls16_aarch64
#define helper_gvec_muls32 helper_gvec_muls32_aarch64
#define helper_gvec_muls64 helper_gvec_muls64_aarch64
#define helper_gvec_neg8 helper_gvec_neg8_aarch64
#define helper_gvec_neg16 helper_gvec_neg16_aarch64
#define helper_gvec_neg32 helper_gvec_neg32_aarch64
#define helper_gvec_neg64 helper_gvec_neg64_aarch64
#define helper_gvec_abs8 helper_gvec_abs8_aarch64
#define helper_gvec_abs16 helper_gvec_abs16_aarch64
#define helper_gvec_abs32 helper_gvec_abs32_aarch64
#define helper_gvec_abs64 helper_gvec_abs64_aarch64
#define helper_gvec_mov helper_gvec_mov_aarch64
#define helper_gvec_dup64 helper_gvec_dup64_aarch64
#define helper_gvec_dup32 helper_gvec_dup32_aarch64
#define helper_gvec_dup16 helper_gvec_dup16_aarch64
#define helper_gvec_dup8 helper_gvec_dup8_aarch64
#define helper_gvec_not helper_gvec_not_aarch64
#define helper_gvec_and helper_gvec_and_aarch64
#define helper_gvec_or helper_gvec_or_aarch64
#define helper_gvec_xor helper_gvec_xor_aarch64
#define helper_gvec_andc helper_gvec_andc_aarch64
#define helper_gvec_orc helper_gvec_orc_aarch64
#define helper_gvec_nand helper_gvec_nand_aarch64
#define helper_gvec_nor helper_gvec_nor_aarch64
#define helper_gvec_eqv helper_gvec_eqv_aarch64
#define helper_gvec_ands helper_gvec_ands_aarch64
#define helper_gvec_xors helper_gvec_xors_aarch64
#define helper_gvec_ors helper_gvec_ors_aarch64
#define helper_gvec_shl8i helper_gvec_shl8i_aarch64
#define helper_gvec_shl16i helper_gvec_shl16i_aarch64
#define helper_gvec_shl32i helper_gvec_shl32i_aarch64
#define helper_gvec_shl64i helper_gvec_shl64i_aarch64
#define helper_gvec_shr8i helper_gvec_shr8i_aarch64
#define helper_gvec_shr16i helper_gvec_shr16i_aarch64
#define helper_gvec_shr32i helper_gvec_shr32i_aarch64
#define helper_gvec_shr64i helper_gvec_shr64i_aarch64
#define helper_gvec_sar8i helper_gvec_sar8i_aarch64
#define helper_gvec_sar16i helper_gvec_sar16i_aarch64
#define helper_gvec_sar32i helper_gvec_sar32i_aarch64
#define helper_gvec_sar64i helper_gvec_sar64i_aarch64
#define helper_gvec_shl8v helper_gvec_shl8v_aarch64
#define helper_gvec_shl16v helper_gvec_shl16v_aarch64
#define helper_gvec_shl32v helper_gvec_shl32v_aarch64
#define helper_gvec_shl64v helper_gvec_shl64v_aarch64
#define helper_gvec_shr8v helper_gvec_shr8v_aarch64
#define helper_gvec_shr16v helper_gvec_shr16v_aarch64
#define helper_gvec_shr32v helper_gvec_shr32v_aarch64
#define helper_gvec_shr64v helper_gvec_shr64v_aarch64
#define helper_gvec_sar8v helper_gvec_sar8v_aarch64
#define helper_gvec_sar16v helper_gvec_sar16v_aarch64
#define helper_gvec_sar32v helper_gvec_sar32v_aarch64
#define helper_gvec_sar64v helper_gvec_sar64v_aarch64
#define helper_gvec_eq8 helper_gvec_eq8_aarch64
#define helper_gvec_ne8 helper_gvec_ne8_aarch64
#define helper_gvec_lt8 helper_gvec_lt8_aarch64
#define helper_gvec_le8 helper_gvec_le8_aarch64
#define helper_gvec_ltu8 helper_gvec_ltu8_aarch64
#define helper_gvec_leu8 helper_gvec_leu8_aarch64
#define helper_gvec_eq16 helper_gvec_eq16_aarch64
#define helper_gvec_ne16 helper_gvec_ne16_aarch64
#define helper_gvec_lt16 helper_gvec_lt16_aarch64
#define helper_gvec_le16 helper_gvec_le16_aarch64
#define helper_gvec_ltu16 helper_gvec_ltu16_aarch64
#define helper_gvec_leu16 helper_gvec_leu16_aarch64
#define helper_gvec_eq32 helper_gvec_eq32_aarch64
#define helper_gvec_ne32 helper_gvec_ne32_aarch64
#define helper_gvec_lt32 helper_gvec_lt32_aarch64
#define helper_gvec_le32 helper_gvec_le32_aarch64
#define helper_gvec_ltu32 helper_gvec_ltu32_aarch64
#define helper_gvec_leu32 helper_gvec_leu32_aarch64
#define helper_gvec_eq64 helper_gvec_eq64_aarch64
#define helper_gvec_ne64 helper_gvec_ne64_aarch64
#define helper_gvec_lt64 helper_gvec_lt64_aarch64
#define helper_gvec_le64 helper_gvec_le64_aarch64
#define helper_gvec_ltu64 helper_gvec_ltu64_aarch64
#define helper_gvec_leu64 helper_gvec_leu64_aarch64
#define helper_gvec_ssadd8 helper_gvec_ssadd8_aarch64
#define helper_gvec_ssadd16 helper_gvec_ssadd16_aarch64
#define helper_gvec_ssadd32 helper_gvec_ssadd32_aarch64
#define helper_gvec_ssadd64 helper_gvec_ssadd64_aarch64
#define helper_gvec_sssub8 helper_gvec_sssub8_aarch64
#define helper_gvec_sssub16 helper_gvec_sssub16_aarch64
#define helper_gvec_sssub32 helper_gvec_sssub32_aarch64
#define helper_gvec_sssub64 helper_gvec_sssub64_aarch64
#define helper_gvec_usadd8 helper_gvec_usadd8_aarch64
#define helper_gvec_usadd16 helper_gvec_usadd16_aarch64
#define helper_gvec_usadd32 helper_gvec_usadd32_aarch64
#define helper_gvec_usadd64 helper_gvec_usadd64_aarch64
#define helper_gvec_ussub8 helper_gvec_ussub8_aarch64
#define helper_gvec_ussub16 helper_gvec_ussub16_aarch64
#define helper_gvec_ussub32 helper_gvec_ussub32_aarch64
#define helper_gvec_ussub64 helper_gvec_ussub64_aarch64
#define helper_gvec_smin8 helper_gvec_smin8_aarch64
#define helper_gvec_smin16 helper_gvec_smin16_aarch64
#define helper_gvec_smin32 helper_gvec_smin32_aarch64
#define helper_gvec_smin64 helper_gvec_smin64_aarch64
#define helper_gvec_smax8 helper_gvec_smax8_aarch64
#define helper_gvec_smax16 helper_gvec_smax16_aarch64
#define helper_gvec_smax32 helper_gvec_smax32_aarch64
#define helper_gvec_smax64 helper_gvec_smax64_aarch64
#define helper_gvec_umin8 helper_gvec_umin8_aarch64
#define helper_gvec_umin16 helper_gvec_umin16_aarch64
#define helper_gvec_umin32 helper_gvec_umin32_aarch64
#define helper_gvec_umin64 helper_gvec_umin64_aarch64
#define helper_gvec_umax8 helper_gvec_umax8_aarch64
#define helper_gvec_umax16 helper_gvec_umax16_aarch64
#define helper_gvec_umax32 helper_gvec_umax32_aarch64
#define helper_gvec_umax64 helper_gvec_umax64_aarch64
#define helper_gvec_bitsel helper_gvec_bitsel_aarch64
#define cpu_restore_state cpu_restore_state_aarch64
#define page_collection_lock page_collection_lock_aarch64
#define page_collection_unlock page_collection_unlock_aarch64
#define free_code_gen_buffer free_code_gen_buffer_aarch64
#define tcg_exec_init tcg_exec_init_aarch64
#define tb_cleanup tb_cleanup_aarch64
#define tb_flush tb_flush_aarch64
#define tb_phys_invalidate tb_phys_invalidate_aarch64
#define tb_gen_code tb_gen_code_aarch64
#define tb_exec_lock tb_exec_lock_aarch64
#define tb_exec_unlock tb_exec_unlock_aarch64
#define tb_invalidate_phys_page_range tb_invalidate_phys_page_range_aarch64
#define tb_invalidate_phys_range tb_invalidate_phys_range_aarch64
#define tb_invalidate_phys_page_fast tb_invalidate_phys_page_fast_aarch64
#define tb_check_watchpoint tb_check_watchpoint_aarch64
#define cpu_io_recompile cpu_io_recompile_aarch64
#define tb_flush_jmp_cache tb_flush_jmp_cache_aarch64
#define tcg_flush_softmmu_tlb tcg_flush_softmmu_tlb_aarch64
#define translator_loop_temp_check translator_loop_temp_check_aarch64
#define translator_loop translator_loop_aarch64
#define helper_atomic_cmpxchgo_le_mmu helper_atomic_cmpxchgo_le_mmu_aarch64
#define helper_atomic_cmpxchgo_be_mmu helper_atomic_cmpxchgo_be_mmu_aarch64
#define helper_atomic_ldo_le_mmu helper_atomic_ldo_le_mmu_aarch64
#define helper_atomic_ldo_be_mmu helper_atomic_ldo_be_mmu_aarch64
#define helper_atomic_sto_le_mmu helper_atomic_sto_le_mmu_aarch64
#define helper_atomic_sto_be_mmu helper_atomic_sto_be_mmu_aarch64
#define unassigned_mem_ops unassigned_mem_ops_aarch64
#define floatx80_infinity floatx80_infinity_aarch64
#define dup_const_func dup_const_func_aarch64
#define gen_helper_raise_exception gen_helper_raise_exception_aarch64
#define gen_helper_raise_interrupt gen_helper_raise_interrupt_aarch64
#define gen_helper_vfp_get_fpscr gen_helper_vfp_get_fpscr_aarch64
#define gen_helper_vfp_set_fpscr gen_helper_vfp_set_fpscr_aarch64
#define gen_helper_cpsr_read gen_helper_cpsr_read_aarch64
#define gen_helper_cpsr_write gen_helper_cpsr_write_aarch64
#define tlb_reset_dirty_by_vaddr tlb_reset_dirty_by_vaddr_aarch64
#define helper_stqcx_le_parallel helper_stqcx_le_parallel_aarch64
#define helper_stqcx_be_parallel helper_stqcx_be_parallel_aarch64
#define cpu_aarch64_init cpu_aarch64_init_aarch64
#define arm_cpu_exec_interrupt arm_cpu_exec_interrupt_aarch64
#define arm_cpu_update_virq arm_cpu_update_virq_aarch64
#define arm_cpu_update_vfiq arm_cpu_update_vfiq_aarch64
#define arm_cpu_initfn arm_cpu_initfn_aarch64
#define gt_cntfrq_period_ns gt_cntfrq_period_ns_aarch64
#define arm_cpu_post_init arm_cpu_post_init_aarch64
#define arm_cpu_realizefn arm_cpu_realizefn_aarch64
#define arm_cpu_class_init arm_cpu_class_init_aarch64
#define cpu_arm_init cpu_arm_init_aarch64
#define helper_crypto_aese helper_crypto_aese_aarch64
#define helper_crypto_aesmc helper_crypto_aesmc_aarch64
#define helper_crypto_sha1_3reg helper_crypto_sha1_3reg_aarch64
#define helper_crypto_sha1h helper_crypto_sha1h_aarch64
#define helper_crypto_sha1su1 helper_crypto_sha1su1_aarch64
#define helper_crypto_sha256h helper_crypto_sha256h_aarch64
#define helper_crypto_sha256h2 helper_crypto_sha256h2_aarch64
#define helper_crypto_sha256su0 helper_crypto_sha256su0_aarch64
#define helper_crypto_sha256su1 helper_crypto_sha256su1_aarch64
#define helper_crypto_sha512h helper_crypto_sha512h_aarch64
#define helper_crypto_sha512h2 helper_crypto_sha512h2_aarch64
#define helper_crypto_sha512su0 helper_crypto_sha512su0_aarch64
#define helper_crypto_sha512su1 helper_crypto_sha512su1_aarch64
#define helper_crypto_sm3partw1 helper_crypto_sm3partw1_aarch64
#define helper_crypto_sm3partw2 helper_crypto_sm3partw2_aarch64
#define helper_crypto_sm3tt helper_crypto_sm3tt_aarch64
#define helper_crypto_sm4e helper_crypto_sm4e_aarch64
#define helper_crypto_sm4ekey helper_crypto_sm4ekey_aarch64
#define helper_check_breakpoints helper_check_breakpoints_aarch64
#define arm_debug_check_watchpoint arm_debug_check_watchpoint_aarch64
#define arm_debug_excp_handler arm_debug_excp_handler_aarch64
#define arm_adjust_watchpoint_address arm_adjust_watchpoint_address_aarch64
#define helper_udiv64 helper_udiv64_aarch64
#define helper_sdiv64 helper_sdiv64_aarch64
#define helper_rbit64 helper_rbit64_aarch64
#define helper_msr_i_spsel helper_msr_i_spsel_aarch64
#define helper_msr_i_daifset helper_msr_i_daifset_aarch64
#define helper_msr_i_daifclear helper_msr_i_daifclear_aarch64
#define helper_vfp_cmph_a64 helper_vfp_cmph_a64_aarch64
#define helper_vfp_cmpeh_a64 helper_vfp_cmpeh_a64_aarch64
#define helper_vfp_cmps_a64 helper_vfp_cmps_a64_aarch64
#define helper_vfp_cmpes_a64 helper_vfp_cmpes_a64_aarch64
#define helper_vfp_cmpd_a64 helper_vfp_cmpd_a64_aarch64
#define helper_vfp_cmped_a64 helper_vfp_cmped_a64_aarch64
#define helper_vfp_mulxs helper_vfp_mulxs_aarch64
#define helper_vfp_mulxd helper_vfp_mulxd_aarch64
#define helper_simd_tbl helper_simd_tbl_aarch64
#define helper_neon_ceq_f64 helper_neon_ceq_f64_aarch64
#define helper_neon_cge_f64 helper_neon_cge_f64_aarch64
#define helper_neon_cgt_f64 helper_neon_cgt_f64_aarch64
#define helper_recpsf_f16 helper_recpsf_f16_aarch64
#define helper_recpsf_f32 helper_recpsf_f32_aarch64
#define helper_recpsf_f64 helper_recpsf_f64_aarch64
#define helper_rsqrtsf_f16 helper_rsqrtsf_f16_aarch64
#define helper_rsqrtsf_f32 helper_rsqrtsf_f32_aarch64
#define helper_rsqrtsf_f64 helper_rsqrtsf_f64_aarch64
#define helper_neon_addlp_s8 helper_neon_addlp_s8_aarch64
#define helper_neon_addlp_u8 helper_neon_addlp_u8_aarch64
#define helper_neon_addlp_s16 helper_neon_addlp_s16_aarch64
#define helper_neon_addlp_u16 helper_neon_addlp_u16_aarch64
#define helper_frecpx_f16 helper_frecpx_f16_aarch64
#define helper_frecpx_f32 helper_frecpx_f32_aarch64
#define helper_frecpx_f64 helper_frecpx_f64_aarch64
#define helper_fcvtx_f64_to_f32 helper_fcvtx_f64_to_f32_aarch64
#define helper_crc32_64 helper_crc32_64_aarch64
#define helper_crc32c_64 helper_crc32c_64_aarch64
#define helper_paired_cmpxchg64_le helper_paired_cmpxchg64_le_aarch64
#define helper_paired_cmpxchg64_le_parallel helper_paired_cmpxchg64_le_parallel_aarch64
#define helper_paired_cmpxchg64_be helper_paired_cmpxchg64_be_aarch64
#define helper_paired_cmpxchg64_be_parallel helper_paired_cmpxchg64_be_parallel_aarch64
#define helper_casp_le_parallel helper_casp_le_parallel_aarch64
#define helper_casp_be_parallel helper_casp_be_parallel_aarch64
#define helper_advsimd_addh helper_advsimd_addh_aarch64
#define helper_advsimd_subh helper_advsimd_subh_aarch64
#define helper_advsimd_mulh helper_advsimd_mulh_aarch64
#define helper_advsimd_divh helper_advsimd_divh_aarch64
#define helper_advsimd_minh helper_advsimd_minh_aarch64
#define helper_advsimd_maxh helper_advsimd_maxh_aarch64
#define helper_advsimd_minnumh helper_advsimd_minnumh_aarch64
#define helper_advsimd_maxnumh helper_advsimd_maxnumh_aarch64
#define helper_advsimd_add2h helper_advsimd_add2h_aarch64
#define helper_advsimd_sub2h helper_advsimd_sub2h_aarch64
#define helper_advsimd_mul2h helper_advsimd_mul2h_aarch64
#define helper_advsimd_div2h helper_advsimd_div2h_aarch64
#define helper_advsimd_min2h helper_advsimd_min2h_aarch64
#define helper_advsimd_max2h helper_advsimd_max2h_aarch64
#define helper_advsimd_minnum2h helper_advsimd_minnum2h_aarch64
#define helper_advsimd_maxnum2h helper_advsimd_maxnum2h_aarch64
#define helper_advsimd_mulxh helper_advsimd_mulxh_aarch64
#define helper_advsimd_mulx2h helper_advsimd_mulx2h_aarch64
#define helper_advsimd_muladdh helper_advsimd_muladdh_aarch64
#define helper_advsimd_muladd2h helper_advsimd_muladd2h_aarch64
#define helper_advsimd_ceq_f16 helper_advsimd_ceq_f16_aarch64
#define helper_advsimd_cge_f16 helper_advsimd_cge_f16_aarch64
#define helper_advsimd_cgt_f16 helper_advsimd_cgt_f16_aarch64
#define helper_advsimd_acge_f16 helper_advsimd_acge_f16_aarch64
#define helper_advsimd_acgt_f16 helper_advsimd_acgt_f16_aarch64
#define helper_advsimd_rinth_exact helper_advsimd_rinth_exact_aarch64
#define helper_advsimd_rinth helper_advsimd_rinth_aarch64
#define helper_advsimd_f16tosinth helper_advsimd_f16tosinth_aarch64
#define helper_advsimd_f16touinth helper_advsimd_f16touinth_aarch64
#define helper_exception_return helper_exception_return_aarch64
#define helper_sqrt_f16 helper_sqrt_f16_aarch64
#define helper_dc_zva helper_dc_zva_aarch64
#define read_raw_cp_reg read_raw_cp_reg_aarch64
#define pmu_init pmu_init_aarch64
#define pmu_op_start pmu_op_start_aarch64
#define pmu_op_finish pmu_op_finish_aarch64
#define pmu_pre_el_change pmu_pre_el_change_aarch64
#define pmu_post_el_change pmu_post_el_change_aarch64
#define arm_pmu_timer_cb arm_pmu_timer_cb_aarch64
#define arm_gt_ptimer_cb arm_gt_ptimer_cb_aarch64
#define arm_gt_vtimer_cb arm_gt_vtimer_cb_aarch64
#define arm_gt_htimer_cb arm_gt_htimer_cb_aarch64
#define arm_gt_stimer_cb arm_gt_stimer_cb_aarch64
#define arm_gt_hvtimer_cb arm_gt_hvtimer_cb_aarch64
#define arm_hcr_el2_eff arm_hcr_el2_eff_aarch64
#define sve_exception_el sve_exception_el_aarch64
#define sve_zcr_len_for_el sve_zcr_len_for_el_aarch64
#define hw_watchpoint_update hw_watchpoint_update_aarch64
#define hw_watchpoint_update_all hw_watchpoint_update_all_aarch64
#define hw_breakpoint_update hw_breakpoint_update_aarch64
#define hw_breakpoint_update_all hw_breakpoint_update_all_aarch64
#define register_cp_regs_for_features register_cp_regs_for_features_aarch64
#define define_one_arm_cp_reg_with_opaque define_one_arm_cp_reg_with_opaque_aarch64
#define define_arm_cp_regs_with_opaque define_arm_cp_regs_with_opaque_aarch64
#define modify_arm_cp_regs modify_arm_cp_regs_aarch64
#define get_arm_cp_reginfo get_arm_cp_reginfo_aarch64
#define arm_cp_write_ignore arm_cp_write_ignore_aarch64
#define arm_cp_read_zero arm_cp_read_zero_aarch64
#define arm_cp_reset_ignore arm_cp_reset_ignore_aarch64
#define cpsr_read cpsr_read_aarch64
#define cpsr_write cpsr_write_aarch64
#define helper_sxtb16 helper_sxtb16_aarch64
#define helper_uxtb16 helper_uxtb16_aarch64
#define helper_sdiv helper_sdiv_aarch64
#define helper_udiv helper_udiv_aarch64
#define helper_rbit helper_rbit_aarch64
#define arm_phys_excp_target_el arm_phys_excp_target_el_aarch64
#define aarch64_sync_32_to_64 aarch64_sync_32_to_64_aarch64
#define aarch64_sync_64_to_32 aarch64_sync_64_to_32_aarch64
#define arm_cpu_do_interrupt arm_cpu_do_interrupt_aarch64
#define arm_sctlr arm_sctlr_aarch64
#define arm_s1_regime_using_lpae_format arm_s1_regime_using_lpae_format_aarch64
#define aa64_va_parameters aa64_va_parameters_aarch64
#define v8m_security_lookup v8m_security_lookup_aarch64
#define pmsav8_mpu_lookup pmsav8_mpu_lookup_aarch64
#define get_phys_addr get_phys_addr_aarch64
#define arm_cpu_get_phys_page_attrs_debug arm_cpu_get_phys_page_attrs_debug_aarch64
#define helper_qadd16 helper_qadd16_aarch64
#define helper_qadd8 helper_qadd8_aarch64
#define helper_qsub16 helper_qsub16_aarch64
#define helper_qsub8 helper_qsub8_aarch64
#define helper_qsubaddx helper_qsubaddx_aarch64
#define helper_qaddsubx helper_qaddsubx_aarch64
#define helper_uqadd16 helper_uqadd16_aarch64
#define helper_uqadd8 helper_uqadd8_aarch64
#define helper_uqsub16 helper_uqsub16_aarch64
#define helper_uqsub8 helper_uqsub8_aarch64
#define helper_uqsubaddx helper_uqsubaddx_aarch64
#define helper_uqaddsubx helper_uqaddsubx_aarch64
#define helper_sadd16 helper_sadd16_aarch64
#define helper_sadd8 helper_sadd8_aarch64
#define helper_ssub16 helper_ssub16_aarch64
#define helper_ssub8 helper_ssub8_aarch64
#define helper_ssubaddx helper_ssubaddx_aarch64
#define helper_saddsubx helper_saddsubx_aarch64
#define helper_uadd16 helper_uadd16_aarch64
#define helper_uadd8 helper_uadd8_aarch64
#define helper_usub16 helper_usub16_aarch64
#define helper_usub8 helper_usub8_aarch64
#define helper_usubaddx helper_usubaddx_aarch64
#define helper_uaddsubx helper_uaddsubx_aarch64
#define helper_shadd16 helper_shadd16_aarch64
#define helper_shadd8 helper_shadd8_aarch64
#define helper_shsub16 helper_shsub16_aarch64
#define helper_shsub8 helper_shsub8_aarch64
#define helper_shsubaddx helper_shsubaddx_aarch64
#define helper_shaddsubx helper_shaddsubx_aarch64
#define helper_uhadd16 helper_uhadd16_aarch64
#define helper_uhadd8 helper_uhadd8_aarch64
#define helper_uhsub16 helper_uhsub16_aarch64
#define helper_uhsub8 helper_uhsub8_aarch64
#define helper_uhsubaddx helper_uhsubaddx_aarch64
#define helper_uhaddsubx helper_uhaddsubx_aarch64
#define helper_usad8 helper_usad8_aarch64
#define helper_sel_flags helper_sel_flags_aarch64
#define helper_crc32 helper_crc32_aarch64
#define helper_crc32c helper_crc32c_aarch64
#define fp_exception_el fp_exception_el_aarch64
#define arm_mmu_idx_to_el arm_mmu_idx_to_el_aarch64
#define arm_mmu_idx_el arm_mmu_idx_el_aarch64
#define arm_mmu_idx arm_mmu_idx_aarch64
#define arm_stage1_mmu_idx arm_stage1_mmu_idx_aarch64
#define arm_rebuild_hflags arm_rebuild_hflags_aarch64
#define helper_rebuild_hflags_m32_newel helper_rebuild_hflags_m32_newel_aarch64
#define helper_rebuild_hflags_m32 helper_rebuild_hflags_m32_aarch64
#define helper_rebuild_hflags_a32_newel helper_rebuild_hflags_a32_newel_aarch64
#define helper_rebuild_hflags_a32 helper_rebuild_hflags_a32_aarch64
#define helper_rebuild_hflags_a64 helper_rebuild_hflags_a64_aarch64
#define cpu_get_tb_cpu_state cpu_get_tb_cpu_state_aarch64
#define aarch64_sve_narrow_vq aarch64_sve_narrow_vq_aarch64
#define aarch64_sve_change_el aarch64_sve_change_el_aarch64
#define helper_iwmmxt_maddsq helper_iwmmxt_maddsq_aarch64
#define helper_iwmmxt_madduq helper_iwmmxt_madduq_aarch64
#define helper_iwmmxt_sadb helper_iwmmxt_sadb_aarch64
#define helper_iwmmxt_sadw helper_iwmmxt_sadw_aarch64
#define helper_iwmmxt_mulslw helper_iwmmxt_mulslw_aarch64
#define helper_iwmmxt_mulshw helper_iwmmxt_mulshw_aarch64
#define helper_iwmmxt_mululw helper_iwmmxt_mululw_aarch64
#define helper_iwmmxt_muluhw helper_iwmmxt_muluhw_aarch64
#define helper_iwmmxt_macsw helper_iwmmxt_macsw_aarch64
#define helper_iwmmxt_macuw helper_iwmmxt_macuw_aarch64
#define helper_iwmmxt_unpacklb helper_iwmmxt_unpacklb_aarch64
#define helper_iwmmxt_unpacklw helper_iwmmxt_unpacklw_aarch64
#define helper_iwmmxt_unpackll helper_iwmmxt_unpackll_aarch64
#define helper_iwmmxt_unpacklub helper_iwmmxt_unpacklub_aarch64
#define helper_iwmmxt_unpackluw helper_iwmmxt_unpackluw_aarch64
#define helper_iwmmxt_unpacklul helper_iwmmxt_unpacklul_aarch64
#define helper_iwmmxt_unpacklsb helper_iwmmxt_unpacklsb_aarch64
#define helper_iwmmxt_unpacklsw helper_iwmmxt_unpacklsw_aarch64
#define helper_iwmmxt_unpacklsl helper_iwmmxt_unpacklsl_aarch64
#define helper_iwmmxt_unpackhb helper_iwmmxt_unpackhb_aarch64
#define helper_iwmmxt_unpackhw helper_iwmmxt_unpackhw_aarch64
#define helper_iwmmxt_unpackhl helper_iwmmxt_unpackhl_aarch64
#define helper_iwmmxt_unpackhub helper_iwmmxt_unpackhub_aarch64
#define helper_iwmmxt_unpackhuw helper_iwmmxt_unpackhuw_aarch64
#define helper_iwmmxt_unpackhul helper_iwmmxt_unpackhul_aarch64
#define helper_iwmmxt_unpackhsb helper_iwmmxt_unpackhsb_aarch64
#define helper_iwmmxt_unpackhsw helper_iwmmxt_unpackhsw_aarch64
#define helper_iwmmxt_unpackhsl helper_iwmmxt_unpackhsl_aarch64
#define helper_iwmmxt_cmpeqb helper_iwmmxt_cmpeqb_aarch64
#define helper_iwmmxt_cmpeqw helper_iwmmxt_cmpeqw_aarch64
#define helper_iwmmxt_cmpeql helper_iwmmxt_cmpeql_aarch64
#define helper_iwmmxt_cmpgtsb helper_iwmmxt_cmpgtsb_aarch64
#define helper_iwmmxt_cmpgtsw helper_iwmmxt_cmpgtsw_aarch64
#define helper_iwmmxt_cmpgtsl helper_iwmmxt_cmpgtsl_aarch64
#define helper_iwmmxt_cmpgtub helper_iwmmxt_cmpgtub_aarch64
#define helper_iwmmxt_cmpgtuw helper_iwmmxt_cmpgtuw_aarch64
#define helper_iwmmxt_cmpgtul helper_iwmmxt_cmpgtul_aarch64
#define helper_iwmmxt_minsb helper_iwmmxt_minsb_aarch64
#define helper_iwmmxt_minsw helper_iwmmxt_minsw_aarch64
#define helper_iwmmxt_minsl helper_iwmmxt_minsl_aarch64
#define helper_iwmmxt_minub helper_iwmmxt_minub_aarch64
#define helper_iwmmxt_minuw helper_iwmmxt_minuw_aarch64
#define helper_iwmmxt_minul helper_iwmmxt_minul_aarch64
#define helper_iwmmxt_maxsb helper_iwmmxt_maxsb_aarch64
#define helper_iwmmxt_maxsw helper_iwmmxt_maxsw_aarch64
#define helper_iwmmxt_maxsl helper_iwmmxt_maxsl_aarch64
#define helper_iwmmxt_maxub helper_iwmmxt_maxub_aarch64
#define helper_iwmmxt_maxuw helper_iwmmxt_maxuw_aarch64
#define helper_iwmmxt_maxul helper_iwmmxt_maxul_aarch64
#define helper_iwmmxt_subnb helper_iwmmxt_subnb_aarch64
#define helper_iwmmxt_subnw helper_iwmmxt_subnw_aarch64
#define helper_iwmmxt_subnl helper_iwmmxt_subnl_aarch64
#define helper_iwmmxt_addnb helper_iwmmxt_addnb_aarch64
#define helper_iwmmxt_addnw helper_iwmmxt_addnw_aarch64
#define helper_iwmmxt_addnl helper_iwmmxt_addnl_aarch64
#define helper_iwmmxt_subub helper_iwmmxt_subub_aarch64
#define helper_iwmmxt_subuw helper_iwmmxt_subuw_aarch64
#define helper_iwmmxt_subul helper_iwmmxt_subul_aarch64
#define helper_iwmmxt_addub helper_iwmmxt_addub_aarch64
#define helper_iwmmxt_adduw helper_iwmmxt_adduw_aarch64
#define helper_iwmmxt_addul helper_iwmmxt_addul_aarch64
#define helper_iwmmxt_subsb helper_iwmmxt_subsb_aarch64
#define helper_iwmmxt_subsw helper_iwmmxt_subsw_aarch64
#define helper_iwmmxt_subsl helper_iwmmxt_subsl_aarch64
#define helper_iwmmxt_addsb helper_iwmmxt_addsb_aarch64
#define helper_iwmmxt_addsw helper_iwmmxt_addsw_aarch64
#define helper_iwmmxt_addsl helper_iwmmxt_addsl_aarch64
#define helper_iwmmxt_avgb0 helper_iwmmxt_avgb0_aarch64
#define helper_iwmmxt_avgb1 helper_iwmmxt_avgb1_aarch64
#define helper_iwmmxt_avgw0 helper_iwmmxt_avgw0_aarch64
#define helper_iwmmxt_avgw1 helper_iwmmxt_avgw1_aarch64
#define helper_iwmmxt_align helper_iwmmxt_align_aarch64
#define helper_iwmmxt_insr helper_iwmmxt_insr_aarch64
#define helper_iwmmxt_setpsr_nz helper_iwmmxt_setpsr_nz_aarch64
#define helper_iwmmxt_bcstb helper_iwmmxt_bcstb_aarch64
#define helper_iwmmxt_bcstw helper_iwmmxt_bcstw_aarch64
#define helper_iwmmxt_bcstl helper_iwmmxt_bcstl_aarch64
#define helper_iwmmxt_addcb helper_iwmmxt_addcb_aarch64
#define helper_iwmmxt_addcw helper_iwmmxt_addcw_aarch64
#define helper_iwmmxt_addcl helper_iwmmxt_addcl_aarch64
#define helper_iwmmxt_msbb helper_iwmmxt_msbb_aarch64
#define helper_iwmmxt_msbw helper_iwmmxt_msbw_aarch64
#define helper_iwmmxt_msbl helper_iwmmxt_msbl_aarch64
#define helper_iwmmxt_srlw helper_iwmmxt_srlw_aarch64
#define helper_iwmmxt_srll helper_iwmmxt_srll_aarch64
#define helper_iwmmxt_srlq helper_iwmmxt_srlq_aarch64
#define helper_iwmmxt_sllw helper_iwmmxt_sllw_aarch64
#define helper_iwmmxt_slll helper_iwmmxt_slll_aarch64
#define helper_iwmmxt_sllq helper_iwmmxt_sllq_aarch64
#define helper_iwmmxt_sraw helper_iwmmxt_sraw_aarch64
#define helper_iwmmxt_sral helper_iwmmxt_sral_aarch64
#define helper_iwmmxt_sraq helper_iwmmxt_sraq_aarch64
#define helper_iwmmxt_rorw helper_iwmmxt_rorw_aarch64
#define helper_iwmmxt_rorl helper_iwmmxt_rorl_aarch64
#define helper_iwmmxt_rorq helper_iwmmxt_rorq_aarch64
#define helper_iwmmxt_shufh helper_iwmmxt_shufh_aarch64
#define helper_iwmmxt_packuw helper_iwmmxt_packuw_aarch64
#define helper_iwmmxt_packul helper_iwmmxt_packul_aarch64
#define helper_iwmmxt_packuq helper_iwmmxt_packuq_aarch64
#define helper_iwmmxt_packsw helper_iwmmxt_packsw_aarch64
#define helper_iwmmxt_packsl helper_iwmmxt_packsl_aarch64
#define helper_iwmmxt_packsq helper_iwmmxt_packsq_aarch64
#define helper_iwmmxt_muladdsl helper_iwmmxt_muladdsl_aarch64
#define helper_iwmmxt_muladdsw helper_iwmmxt_muladdsw_aarch64
#define helper_iwmmxt_muladdswl helper_iwmmxt_muladdswl_aarch64
#define armv7m_nvic_set_pending armv7m_nvic_set_pending_aarch64
#define helper_v7m_preserve_fp_state helper_v7m_preserve_fp_state_aarch64
#define write_v7m_exception write_v7m_exception_aarch64
#define helper_v7m_bxns helper_v7m_bxns_aarch64
#define helper_v7m_blxns helper_v7m_blxns_aarch64
#define armv7m_nvic_neg_prio_requested armv7m_nvic_neg_prio_requested_aarch64
#define helper_v7m_vlstm helper_v7m_vlstm_aarch64
#define helper_v7m_vlldm helper_v7m_vlldm_aarch64
#define arm_v7m_cpu_do_interrupt arm_v7m_cpu_do_interrupt_aarch64
#define helper_v7m_mrs helper_v7m_mrs_aarch64
#define helper_v7m_msr helper_v7m_msr_aarch64
#define helper_v7m_tt helper_v7m_tt_aarch64
#define arm_v7m_mmu_idx_all arm_v7m_mmu_idx_all_aarch64
#define arm_v7m_mmu_idx_for_secstate_and_priv arm_v7m_mmu_idx_for_secstate_and_priv_aarch64
#define arm_v7m_mmu_idx_for_secstate arm_v7m_mmu_idx_for_secstate_aarch64
#define helper_neon_qadd_u8 helper_neon_qadd_u8_aarch64
#define helper_neon_qadd_u16 helper_neon_qadd_u16_aarch64
#define helper_neon_qadd_u32 helper_neon_qadd_u32_aarch64
#define helper_neon_qadd_u64 helper_neon_qadd_u64_aarch64
#define helper_neon_qadd_s8 helper_neon_qadd_s8_aarch64
#define helper_neon_qadd_s16 helper_neon_qadd_s16_aarch64
#define helper_neon_qadd_s32 helper_neon_qadd_s32_aarch64
#define helper_neon_qadd_s64 helper_neon_qadd_s64_aarch64
#define helper_neon_uqadd_s8 helper_neon_uqadd_s8_aarch64
#define helper_neon_uqadd_s16 helper_neon_uqadd_s16_aarch64
#define helper_neon_uqadd_s32 helper_neon_uqadd_s32_aarch64
#define helper_neon_uqadd_s64 helper_neon_uqadd_s64_aarch64
#define helper_neon_sqadd_u8 helper_neon_sqadd_u8_aarch64
#define helper_neon_sqadd_u16 helper_neon_sqadd_u16_aarch64
#define helper_neon_sqadd_u32 helper_neon_sqadd_u32_aarch64
#define helper_neon_sqadd_u64 helper_neon_sqadd_u64_aarch64
#define helper_neon_qsub_u8 helper_neon_qsub_u8_aarch64
#define helper_neon_qsub_u16 helper_neon_qsub_u16_aarch64
#define helper_neon_qsub_u32 helper_neon_qsub_u32_aarch64
#define helper_neon_qsub_u64 helper_neon_qsub_u64_aarch64
#define helper_neon_qsub_s8 helper_neon_qsub_s8_aarch64
#define helper_neon_qsub_s16 helper_neon_qsub_s16_aarch64
#define helper_neon_qsub_s32 helper_neon_qsub_s32_aarch64
#define helper_neon_qsub_s64 helper_neon_qsub_s64_aarch64
#define helper_neon_hadd_s8 helper_neon_hadd_s8_aarch64
#define helper_neon_hadd_u8 helper_neon_hadd_u8_aarch64
#define helper_neon_hadd_s16 helper_neon_hadd_s16_aarch64
#define helper_neon_hadd_u16 helper_neon_hadd_u16_aarch64
#define helper_neon_hadd_s32 helper_neon_hadd_s32_aarch64
#define helper_neon_hadd_u32 helper_neon_hadd_u32_aarch64
#define helper_neon_rhadd_s8 helper_neon_rhadd_s8_aarch64
#define helper_neon_rhadd_u8 helper_neon_rhadd_u8_aarch64
#define helper_neon_rhadd_s16 helper_neon_rhadd_s16_aarch64
#define helper_neon_rhadd_u16 helper_neon_rhadd_u16_aarch64
#define helper_neon_rhadd_s32 helper_neon_rhadd_s32_aarch64
#define helper_neon_rhadd_u32 helper_neon_rhadd_u32_aarch64
#define helper_neon_hsub_s8 helper_neon_hsub_s8_aarch64
#define helper_neon_hsub_u8 helper_neon_hsub_u8_aarch64
#define helper_neon_hsub_s16 helper_neon_hsub_s16_aarch64
#define helper_neon_hsub_u16 helper_neon_hsub_u16_aarch64
#define helper_neon_hsub_s32 helper_neon_hsub_s32_aarch64
#define helper_neon_hsub_u32 helper_neon_hsub_u32_aarch64
#define helper_neon_cgt_s8 helper_neon_cgt_s8_aarch64
#define helper_neon_cgt_u8 helper_neon_cgt_u8_aarch64
#define helper_neon_cgt_s16 helper_neon_cgt_s16_aarch64
#define helper_neon_cgt_u16 helper_neon_cgt_u16_aarch64
#define helper_neon_cgt_s32 helper_neon_cgt_s32_aarch64
#define helper_neon_cgt_u32 helper_neon_cgt_u32_aarch64
#define helper_neon_cge_s8 helper_neon_cge_s8_aarch64
#define helper_neon_cge_u8 helper_neon_cge_u8_aarch64
#define helper_neon_cge_s16 helper_neon_cge_s16_aarch64
#define helper_neon_cge_u16 helper_neon_cge_u16_aarch64
#define helper_neon_cge_s32 helper_neon_cge_s32_aarch64
#define helper_neon_cge_u32 helper_neon_cge_u32_aarch64
#define helper_neon_pmin_s8 helper_neon_pmin_s8_aarch64
#define helper_neon_pmin_u8 helper_neon_pmin_u8_aarch64
#define helper_neon_pmin_s16 helper_neon_pmin_s16_aarch64
#define helper_neon_pmin_u16 helper_neon_pmin_u16_aarch64
#define helper_neon_pmax_s8 helper_neon_pmax_s8_aarch64
#define helper_neon_pmax_u8 helper_neon_pmax_u8_aarch64
#define helper_neon_pmax_s16 helper_neon_pmax_s16_aarch64
#define helper_neon_pmax_u16 helper_neon_pmax_u16_aarch64
#define helper_neon_abd_s8 helper_neon_abd_s8_aarch64
#define helper_neon_abd_u8 helper_neon_abd_u8_aarch64
#define helper_neon_abd_s16 helper_neon_abd_s16_aarch64
#define helper_neon_abd_u16 helper_neon_abd_u16_aarch64
#define helper_neon_abd_s32 helper_neon_abd_s32_aarch64
#define helper_neon_abd_u32 helper_neon_abd_u32_aarch64
#define helper_neon_shl_u16 helper_neon_shl_u16_aarch64
#define helper_neon_shl_s16 helper_neon_shl_s16_aarch64
#define helper_neon_rshl_s8 helper_neon_rshl_s8_aarch64
#define helper_neon_rshl_s16 helper_neon_rshl_s16_aarch64
#define helper_neon_rshl_s32 helper_neon_rshl_s32_aarch64
#define helper_neon_rshl_s64 helper_neon_rshl_s64_aarch64
#define helper_neon_rshl_u8 helper_neon_rshl_u8_aarch64
#define helper_neon_rshl_u16 helper_neon_rshl_u16_aarch64
#define helper_neon_rshl_u32 helper_neon_rshl_u32_aarch64
#define helper_neon_rshl_u64 helper_neon_rshl_u64_aarch64
#define helper_neon_qshl_u8 helper_neon_qshl_u8_aarch64
#define helper_neon_qshl_u16 helper_neon_qshl_u16_aarch64
#define helper_neon_qshl_u32 helper_neon_qshl_u32_aarch64
#define helper_neon_qshl_u64 helper_neon_qshl_u64_aarch64
#define helper_neon_qshl_s8 helper_neon_qshl_s8_aarch64
#define helper_neon_qshl_s16 helper_neon_qshl_s16_aarch64
#define helper_neon_qshl_s32 helper_neon_qshl_s32_aarch64
#define helper_neon_qshl_s64 helper_neon_qshl_s64_aarch64
#define helper_neon_qshlu_s8 helper_neon_qshlu_s8_aarch64
#define helper_neon_qshlu_s16 helper_neon_qshlu_s16_aarch64
#define helper_neon_qshlu_s32 helper_neon_qshlu_s32_aarch64
#define helper_neon_qshlu_s64 helper_neon_qshlu_s64_aarch64
#define helper_neon_qrshl_u8 helper_neon_qrshl_u8_aarch64
#define helper_neon_qrshl_u16 helper_neon_qrshl_u16_aarch64
#define helper_neon_qrshl_u32 helper_neon_qrshl_u32_aarch64
#define helper_neon_qrshl_u64 helper_neon_qrshl_u64_aarch64
#define helper_neon_qrshl_s8 helper_neon_qrshl_s8_aarch64
#define helper_neon_qrshl_s16 helper_neon_qrshl_s16_aarch64
#define helper_neon_qrshl_s32 helper_neon_qrshl_s32_aarch64
#define helper_neon_qrshl_s64 helper_neon_qrshl_s64_aarch64
#define helper_neon_add_u8 helper_neon_add_u8_aarch64
#define helper_neon_add_u16 helper_neon_add_u16_aarch64
#define helper_neon_padd_u8 helper_neon_padd_u8_aarch64
#define helper_neon_padd_u16 helper_neon_padd_u16_aarch64
#define helper_neon_sub_u8 helper_neon_sub_u8_aarch64
#define helper_neon_sub_u16 helper_neon_sub_u16_aarch64
#define helper_neon_mul_u8 helper_neon_mul_u8_aarch64
#define helper_neon_mul_u16 helper_neon_mul_u16_aarch64
#define helper_neon_tst_u8 helper_neon_tst_u8_aarch64
#define helper_neon_tst_u16 helper_neon_tst_u16_aarch64
#define helper_neon_tst_u32 helper_neon_tst_u32_aarch64
#define helper_neon_ceq_u8 helper_neon_ceq_u8_aarch64
#define helper_neon_ceq_u16 helper_neon_ceq_u16_aarch64
#define helper_neon_ceq_u32 helper_neon_ceq_u32_aarch64
#define helper_neon_clz_u8 helper_neon_clz_u8_aarch64
#define helper_neon_clz_u16 helper_neon_clz_u16_aarch64
#define helper_neon_cls_s8 helper_neon_cls_s8_aarch64
#define helper_neon_cls_s16 helper_neon_cls_s16_aarch64
#define helper_neon_cls_s32 helper_neon_cls_s32_aarch64
#define helper_neon_cnt_u8 helper_neon_cnt_u8_aarch64
#define helper_neon_rbit_u8 helper_neon_rbit_u8_aarch64
#define helper_neon_qdmulh_s16 helper_neon_qdmulh_s16_aarch64
#define helper_neon_qrdmulh_s16 helper_neon_qrdmulh_s16_aarch64
#define helper_neon_qdmulh_s32 helper_neon_qdmulh_s32_aarch64
#define helper_neon_qrdmulh_s32 helper_neon_qrdmulh_s32_aarch64
#define helper_neon_narrow_u8 helper_neon_narrow_u8_aarch64
#define helper_neon_narrow_u16 helper_neon_narrow_u16_aarch64
#define helper_neon_narrow_high_u8 helper_neon_narrow_high_u8_aarch64
#define helper_neon_narrow_high_u16 helper_neon_narrow_high_u16_aarch64
#define helper_neon_narrow_round_high_u8 helper_neon_narrow_round_high_u8_aarch64
#define helper_neon_narrow_round_high_u16 helper_neon_narrow_round_high_u16_aarch64
#define helper_neon_unarrow_sat8 helper_neon_unarrow_sat8_aarch64
#define helper_neon_narrow_sat_u8 helper_neon_narrow_sat_u8_aarch64
#define helper_neon_narrow_sat_s8 helper_neon_narrow_sat_s8_aarch64
#define helper_neon_unarrow_sat16 helper_neon_unarrow_sat16_aarch64
#define helper_neon_narrow_sat_u16 helper_neon_narrow_sat_u16_aarch64
#define helper_neon_narrow_sat_s16 helper_neon_narrow_sat_s16_aarch64
#define helper_neon_unarrow_sat32 helper_neon_unarrow_sat32_aarch64
#define helper_neon_narrow_sat_u32 helper_neon_narrow_sat_u32_aarch64
#define helper_neon_narrow_sat_s32 helper_neon_narrow_sat_s32_aarch64
#define helper_neon_widen_u8 helper_neon_widen_u8_aarch64
#define helper_neon_widen_s8 helper_neon_widen_s8_aarch64
#define helper_neon_widen_u16 helper_neon_widen_u16_aarch64
#define helper_neon_widen_s16 helper_neon_widen_s16_aarch64
#define helper_neon_addl_u16 helper_neon_addl_u16_aarch64
#define helper_neon_addl_u32 helper_neon_addl_u32_aarch64
#define helper_neon_paddl_u16 helper_neon_paddl_u16_aarch64
#define helper_neon_paddl_u32 helper_neon_paddl_u32_aarch64
#define helper_neon_subl_u16 helper_neon_subl_u16_aarch64
#define helper_neon_subl_u32 helper_neon_subl_u32_aarch64
#define helper_neon_addl_saturate_s32 helper_neon_addl_saturate_s32_aarch64
#define helper_neon_addl_saturate_s64 helper_neon_addl_saturate_s64_aarch64
#define helper_neon_abdl_u16 helper_neon_abdl_u16_aarch64
#define helper_neon_abdl_s16 helper_neon_abdl_s16_aarch64
#define helper_neon_abdl_u32 helper_neon_abdl_u32_aarch64
#define helper_neon_abdl_s32 helper_neon_abdl_s32_aarch64
#define helper_neon_abdl_u64 helper_neon_abdl_u64_aarch64
#define helper_neon_abdl_s64 helper_neon_abdl_s64_aarch64
#define helper_neon_mull_u8 helper_neon_mull_u8_aarch64
#define helper_neon_mull_s8 helper_neon_mull_s8_aarch64
#define helper_neon_mull_u16 helper_neon_mull_u16_aarch64
#define helper_neon_mull_s16 helper_neon_mull_s16_aarch64
#define helper_neon_negl_u16 helper_neon_negl_u16_aarch64
#define helper_neon_negl_u32 helper_neon_negl_u32_aarch64
#define helper_neon_qabs_s8 helper_neon_qabs_s8_aarch64
#define helper_neon_qneg_s8 helper_neon_qneg_s8_aarch64
#define helper_neon_qabs_s16 helper_neon_qabs_s16_aarch64
#define helper_neon_qneg_s16 helper_neon_qneg_s16_aarch64
#define helper_neon_qabs_s32 helper_neon_qabs_s32_aarch64
#define helper_neon_qneg_s32 helper_neon_qneg_s32_aarch64
#define helper_neon_qabs_s64 helper_neon_qabs_s64_aarch64
#define helper_neon_qneg_s64 helper_neon_qneg_s64_aarch64
#define helper_neon_abd_f32 helper_neon_abd_f32_aarch64
#define helper_neon_ceq_f32 helper_neon_ceq_f32_aarch64
#define helper_neon_cge_f32 helper_neon_cge_f32_aarch64
#define helper_neon_cgt_f32 helper_neon_cgt_f32_aarch64
#define helper_neon_acge_f32 helper_neon_acge_f32_aarch64
#define helper_neon_acgt_f32 helper_neon_acgt_f32_aarch64
#define helper_neon_acge_f64 helper_neon_acge_f64_aarch64
#define helper_neon_acgt_f64 helper_neon_acgt_f64_aarch64
#define helper_neon_qunzip8 helper_neon_qunzip8_aarch64
#define helper_neon_qunzip16 helper_neon_qunzip16_aarch64
#define helper_neon_qunzip32 helper_neon_qunzip32_aarch64
#define helper_neon_unzip8 helper_neon_unzip8_aarch64
#define helper_neon_unzip16 helper_neon_unzip16_aarch64
#define helper_neon_qzip8 helper_neon_qzip8_aarch64
#define helper_neon_qzip16 helper_neon_qzip16_aarch64
#define helper_neon_qzip32 helper_neon_qzip32_aarch64
#define helper_neon_zip8 helper_neon_zip8_aarch64
#define helper_neon_zip16 helper_neon_zip16_aarch64
#define raise_exception raise_exception_aarch64
#define raise_exception_ra raise_exception_ra_aarch64
#define helper_neon_tbl helper_neon_tbl_aarch64
#define helper_v8m_stackcheck helper_v8m_stackcheck_aarch64
#define helper_add_setq helper_add_setq_aarch64
#define helper_add_saturate helper_add_saturate_aarch64
#define helper_sub_saturate helper_sub_saturate_aarch64
#define helper_add_usaturate helper_add_usaturate_aarch64
#define helper_sub_usaturate helper_sub_usaturate_aarch64
#define helper_ssat helper_ssat_aarch64
#define helper_ssat16 helper_ssat16_aarch64
#define helper_usat helper_usat_aarch64
#define helper_usat16 helper_usat16_aarch64
#define helper_setend helper_setend_aarch64
#define helper_wfi helper_wfi_aarch64
#define helper_wfe helper_wfe_aarch64
#define helper_yield helper_yield_aarch64
#define helper_exception_internal helper_exception_internal_aarch64
#define helper_exception_with_syndrome helper_exception_with_syndrome_aarch64
#define helper_exception_bkpt_insn helper_exception_bkpt_insn_aarch64
#define helper_cpsr_read helper_cpsr_read_aarch64
#define helper_cpsr_write helper_cpsr_write_aarch64
#define helper_cpsr_write_eret helper_cpsr_write_eret_aarch64
#define helper_get_user_reg helper_get_user_reg_aarch64
#define helper_set_user_reg helper_set_user_reg_aarch64
#define helper_set_r13_banked helper_set_r13_banked_aarch64
#define helper_get_r13_banked helper_get_r13_banked_aarch64
#define helper_msr_banked helper_msr_banked_aarch64
#define helper_mrs_banked helper_mrs_banked_aarch64
#define helper_access_check_cp_reg helper_access_check_cp_reg_aarch64
#define helper_set_cp_reg helper_set_cp_reg_aarch64
#define helper_get_cp_reg helper_get_cp_reg_aarch64
#define helper_set_cp_reg64 helper_set_cp_reg64_aarch64
#define helper_get_cp_reg64 helper_get_cp_reg64_aarch64
#define helper_pre_hvc helper_pre_hvc_aarch64
#define helper_pre_smc helper_pre_smc_aarch64
#define helper_shl_cc helper_shl_cc_aarch64
#define helper_shr_cc helper_shr_cc_aarch64
#define helper_sar_cc helper_sar_cc_aarch64
#define helper_ror_cc helper_ror_cc_aarch64
#define helper_pacia helper_pacia_aarch64
#define helper_pacib helper_pacib_aarch64
#define helper_pacda helper_pacda_aarch64
#define helper_pacdb helper_pacdb_aarch64
#define helper_pacga helper_pacga_aarch64
#define helper_autia helper_autia_aarch64
#define helper_autib helper_autib_aarch64
#define helper_autda helper_autda_aarch64
#define helper_autdb helper_autdb_aarch64
#define helper_xpaci helper_xpaci_aarch64
#define helper_xpacd helper_xpacd_aarch64
#define arm_is_psci_call arm_is_psci_call_aarch64
#define arm_handle_psci_call arm_handle_psci_call_aarch64
#define helper_sve_predtest1 helper_sve_predtest1_aarch64
#define helper_sve_predtest helper_sve_predtest_aarch64
#define helper_sve_and_pppp helper_sve_and_pppp_aarch64
#define helper_sve_bic_pppp helper_sve_bic_pppp_aarch64
#define helper_sve_eor_pppp helper_sve_eor_pppp_aarch64
#define helper_sve_sel_pppp helper_sve_sel_pppp_aarch64
#define helper_sve_orr_pppp helper_sve_orr_pppp_aarch64
#define helper_sve_orn_pppp helper_sve_orn_pppp_aarch64
#define helper_sve_nor_pppp helper_sve_nor_pppp_aarch64
#define helper_sve_nand_pppp helper_sve_nand_pppp_aarch64
#define helper_sve_and_zpzz_b helper_sve_and_zpzz_b_aarch64
#define helper_sve_and_zpzz_h helper_sve_and_zpzz_h_aarch64
#define helper_sve_and_zpzz_s helper_sve_and_zpzz_s_aarch64
#define helper_sve_and_zpzz_d helper_sve_and_zpzz_d_aarch64
#define helper_sve_orr_zpzz_b helper_sve_orr_zpzz_b_aarch64
#define helper_sve_orr_zpzz_h helper_sve_orr_zpzz_h_aarch64
#define helper_sve_orr_zpzz_s helper_sve_orr_zpzz_s_aarch64
#define helper_sve_orr_zpzz_d helper_sve_orr_zpzz_d_aarch64
#define helper_sve_eor_zpzz_b helper_sve_eor_zpzz_b_aarch64
#define helper_sve_eor_zpzz_h helper_sve_eor_zpzz_h_aarch64
#define helper_sve_eor_zpzz_s helper_sve_eor_zpzz_s_aarch64
#define helper_sve_eor_zpzz_d helper_sve_eor_zpzz_d_aarch64
#define helper_sve_bic_zpzz_b helper_sve_bic_zpzz_b_aarch64
#define helper_sve_bic_zpzz_h helper_sve_bic_zpzz_h_aarch64
#define helper_sve_bic_zpzz_s helper_sve_bic_zpzz_s_aarch64
#define helper_sve_bic_zpzz_d helper_sve_bic_zpzz_d_aarch64
#define helper_sve_add_zpzz_b helper_sve_add_zpzz_b_aarch64
#define helper_sve_add_zpzz_h helper_sve_add_zpzz_h_aarch64
#define helper_sve_add_zpzz_s helper_sve_add_zpzz_s_aarch64
#define helper_sve_add_zpzz_d helper_sve_add_zpzz_d_aarch64
#define helper_sve_sub_zpzz_b helper_sve_sub_zpzz_b_aarch64
#define helper_sve_sub_zpzz_h helper_sve_sub_zpzz_h_aarch64
#define helper_sve_sub_zpzz_s helper_sve_sub_zpzz_s_aarch64
#define helper_sve_sub_zpzz_d helper_sve_sub_zpzz_d_aarch64
#define helper_sve_smax_zpzz_b helper_sve_smax_zpzz_b_aarch64
#define helper_sve_smax_zpzz_h helper_sve_smax_zpzz_h_aarch64
#define helper_sve_smax_zpzz_s helper_sve_smax_zpzz_s_aarch64
#define helper_sve_smax_zpzz_d helper_sve_smax_zpzz_d_aarch64
#define helper_sve_umax_zpzz_b helper_sve_umax_zpzz_b_aarch64
#define helper_sve_umax_zpzz_h helper_sve_umax_zpzz_h_aarch64
#define helper_sve_umax_zpzz_s helper_sve_umax_zpzz_s_aarch64
#define helper_sve_umax_zpzz_d helper_sve_umax_zpzz_d_aarch64
#define helper_sve_smin_zpzz_b helper_sve_smin_zpzz_b_aarch64
#define helper_sve_smin_zpzz_h helper_sve_smin_zpzz_h_aarch64
#define helper_sve_smin_zpzz_s helper_sve_smin_zpzz_s_aarch64
#define helper_sve_smin_zpzz_d helper_sve_smin_zpzz_d_aarch64
#define helper_sve_umin_zpzz_b helper_sve_umin_zpzz_b_aarch64
#define helper_sve_umin_zpzz_h helper_sve_umin_zpzz_h_aarch64
#define helper_sve_umin_zpzz_s helper_sve_umin_zpzz_s_aarch64
#define helper_sve_umin_zpzz_d helper_sve_umin_zpzz_d_aarch64
#define helper_sve_sabd_zpzz_b helper_sve_sabd_zpzz_b_aarch64
#define helper_sve_sabd_zpzz_h helper_sve_sabd_zpzz_h_aarch64
#define helper_sve_sabd_zpzz_s helper_sve_sabd_zpzz_s_aarch64
#define helper_sve_sabd_zpzz_d helper_sve_sabd_zpzz_d_aarch64
#define helper_sve_uabd_zpzz_b helper_sve_uabd_zpzz_b_aarch64
#define helper_sve_uabd_zpzz_h helper_sve_uabd_zpzz_h_aarch64
#define helper_sve_uabd_zpzz_s helper_sve_uabd_zpzz_s_aarch64
#define helper_sve_uabd_zpzz_d helper_sve_uabd_zpzz_d_aarch64
#define helper_sve_mul_zpzz_b helper_sve_mul_zpzz_b_aarch64
#define helper_sve_mul_zpzz_h helper_sve_mul_zpzz_h_aarch64
#define helper_sve_mul_zpzz_s helper_sve_mul_zpzz_s_aarch64
#define helper_sve_mul_zpzz_d helper_sve_mul_zpzz_d_aarch64
#define helper_sve_smulh_zpzz_b helper_sve_smulh_zpzz_b_aarch64
#define helper_sve_smulh_zpzz_h helper_sve_smulh_zpzz_h_aarch64
#define helper_sve_smulh_zpzz_s helper_sve_smulh_zpzz_s_aarch64
#define helper_sve_smulh_zpzz_d helper_sve_smulh_zpzz_d_aarch64
#define helper_sve_umulh_zpzz_b helper_sve_umulh_zpzz_b_aarch64
#define helper_sve_umulh_zpzz_h helper_sve_umulh_zpzz_h_aarch64
#define helper_sve_umulh_zpzz_s helper_sve_umulh_zpzz_s_aarch64
#define helper_sve_umulh_zpzz_d helper_sve_umulh_zpzz_d_aarch64
#define helper_sve_sdiv_zpzz_s helper_sve_sdiv_zpzz_s_aarch64
#define helper_sve_sdiv_zpzz_d helper_sve_sdiv_zpzz_d_aarch64
#define helper_sve_udiv_zpzz_s helper_sve_udiv_zpzz_s_aarch64
#define helper_sve_udiv_zpzz_d helper_sve_udiv_zpzz_d_aarch64
#define helper_sve_asr_zpzz_b helper_sve_asr_zpzz_b_aarch64
#define helper_sve_lsr_zpzz_b helper_sve_lsr_zpzz_b_aarch64
#define helper_sve_lsl_zpzz_b helper_sve_lsl_zpzz_b_aarch64
#define helper_sve_asr_zpzz_h helper_sve_asr_zpzz_h_aarch64
#define helper_sve_lsr_zpzz_h helper_sve_lsr_zpzz_h_aarch64
#define helper_sve_lsl_zpzz_h helper_sve_lsl_zpzz_h_aarch64
#define helper_sve_asr_zpzz_s helper_sve_asr_zpzz_s_aarch64
#define helper_sve_lsr_zpzz_s helper_sve_lsr_zpzz_s_aarch64
#define helper_sve_lsl_zpzz_s helper_sve_lsl_zpzz_s_aarch64
#define helper_sve_asr_zpzz_d helper_sve_asr_zpzz_d_aarch64
#define helper_sve_lsr_zpzz_d helper_sve_lsr_zpzz_d_aarch64
#define helper_sve_lsl_zpzz_d helper_sve_lsl_zpzz_d_aarch64
#define helper_sve_asr_zpzw_b helper_sve_asr_zpzw_b_aarch64
#define helper_sve_lsr_zpzw_b helper_sve_lsr_zpzw_b_aarch64
#define helper_sve_lsl_zpzw_b helper_sve_lsl_zpzw_b_aarch64
#define helper_sve_asr_zpzw_h helper_sve_asr_zpzw_h_aarch64
#define helper_sve_lsr_zpzw_h helper_sve_lsr_zpzw_h_aarch64
#define helper_sve_lsl_zpzw_h helper_sve_lsl_zpzw_h_aarch64
#define helper_sve_asr_zpzw_s helper_sve_asr_zpzw_s_aarch64
#define helper_sve_lsr_zpzw_s helper_sve_lsr_zpzw_s_aarch64
#define helper_sve_lsl_zpzw_s helper_sve_lsl_zpzw_s_aarch64
#define helper_sve_cls_b helper_sve_cls_b_aarch64
#define helper_sve_cls_h helper_sve_cls_h_aarch64
#define helper_sve_cls_s helper_sve_cls_s_aarch64
#define helper_sve_cls_d helper_sve_cls_d_aarch64
#define helper_sve_clz_b helper_sve_clz_b_aarch64
#define helper_sve_clz_h helper_sve_clz_h_aarch64
#define helper_sve_clz_s helper_sve_clz_s_aarch64
#define helper_sve_clz_d helper_sve_clz_d_aarch64
#define helper_sve_cnt_zpz_b helper_sve_cnt_zpz_b_aarch64
#define helper_sve_cnt_zpz_h helper_sve_cnt_zpz_h_aarch64
#define helper_sve_cnt_zpz_s helper_sve_cnt_zpz_s_aarch64
#define helper_sve_cnt_zpz_d helper_sve_cnt_zpz_d_aarch64
#define helper_sve_cnot_b helper_sve_cnot_b_aarch64
#define helper_sve_cnot_h helper_sve_cnot_h_aarch64
#define helper_sve_cnot_s helper_sve_cnot_s_aarch64
#define helper_sve_cnot_d helper_sve_cnot_d_aarch64
#define helper_sve_fabs_h helper_sve_fabs_h_aarch64
#define helper_sve_fabs_s helper_sve_fabs_s_aarch64
#define helper_sve_fabs_d helper_sve_fabs_d_aarch64
#define helper_sve_fneg_h helper_sve_fneg_h_aarch64
#define helper_sve_fneg_s helper_sve_fneg_s_aarch64
#define helper_sve_fneg_d helper_sve_fneg_d_aarch64
#define helper_sve_not_zpz_b helper_sve_not_zpz_b_aarch64
#define helper_sve_not_zpz_h helper_sve_not_zpz_h_aarch64
#define helper_sve_not_zpz_s helper_sve_not_zpz_s_aarch64
#define helper_sve_not_zpz_d helper_sve_not_zpz_d_aarch64
#define helper_sve_sxtb_h helper_sve_sxtb_h_aarch64
#define helper_sve_sxtb_s helper_sve_sxtb_s_aarch64
#define helper_sve_sxth_s helper_sve_sxth_s_aarch64
#define helper_sve_sxtb_d helper_sve_sxtb_d_aarch64
#define helper_sve_sxth_d helper_sve_sxth_d_aarch64
#define helper_sve_sxtw_d helper_sve_sxtw_d_aarch64
#define helper_sve_uxtb_h helper_sve_uxtb_h_aarch64
#define helper_sve_uxtb_s helper_sve_uxtb_s_aarch64
#define helper_sve_uxth_s helper_sve_uxth_s_aarch64
#define helper_sve_uxtb_d helper_sve_uxtb_d_aarch64
#define helper_sve_uxth_d helper_sve_uxth_d_aarch64
#define helper_sve_uxtw_d helper_sve_uxtw_d_aarch64
#define helper_sve_abs_b helper_sve_abs_b_aarch64
#define helper_sve_abs_h helper_sve_abs_h_aarch64
#define helper_sve_abs_s helper_sve_abs_s_aarch64
#define helper_sve_abs_d helper_sve_abs_d_aarch64
#define helper_sve_neg_b helper_sve_neg_b_aarch64
#define helper_sve_neg_h helper_sve_neg_h_aarch64
#define helper_sve_neg_s helper_sve_neg_s_aarch64
#define helper_sve_neg_d helper_sve_neg_d_aarch64
#define helper_sve_revb_h helper_sve_revb_h_aarch64
#define helper_sve_revb_s helper_sve_revb_s_aarch64
#define helper_sve_revb_d helper_sve_revb_d_aarch64
#define helper_sve_revh_s helper_sve_revh_s_aarch64
#define helper_sve_revh_d helper_sve_revh_d_aarch64
#define helper_sve_revw_d helper_sve_revw_d_aarch64
#define helper_sve_rbit_b helper_sve_rbit_b_aarch64
#define helper_sve_rbit_h helper_sve_rbit_h_aarch64
#define helper_sve_rbit_s helper_sve_rbit_s_aarch64
#define helper_sve_rbit_d helper_sve_rbit_d_aarch64
#define helper_sve_asr_zzw_b helper_sve_asr_zzw_b_aarch64
#define helper_sve_lsr_zzw_b helper_sve_lsr_zzw_b_aarch64
#define helper_sve_lsl_zzw_b helper_sve_lsl_zzw_b_aarch64
#define helper_sve_asr_zzw_h helper_sve_asr_zzw_h_aarch64
#define helper_sve_lsr_zzw_h helper_sve_lsr_zzw_h_aarch64
#define helper_sve_lsl_zzw_h helper_sve_lsl_zzw_h_aarch64
#define helper_sve_asr_zzw_s helper_sve_asr_zzw_s_aarch64
#define helper_sve_lsr_zzw_s helper_sve_lsr_zzw_s_aarch64
#define helper_sve_lsl_zzw_s helper_sve_lsl_zzw_s_aarch64
#define helper_sve_orv_b helper_sve_orv_b_aarch64
#define helper_sve_orv_h helper_sve_orv_h_aarch64
#define helper_sve_orv_s helper_sve_orv_s_aarch64
#define helper_sve_orv_d helper_sve_orv_d_aarch64
#define helper_sve_eorv_b helper_sve_eorv_b_aarch64
#define helper_sve_eorv_h helper_sve_eorv_h_aarch64
#define helper_sve_eorv_s helper_sve_eorv_s_aarch64
#define helper_sve_eorv_d helper_sve_eorv_d_aarch64
#define helper_sve_andv_b helper_sve_andv_b_aarch64
#define helper_sve_andv_h helper_sve_andv_h_aarch64
#define helper_sve_andv_s helper_sve_andv_s_aarch64
#define helper_sve_andv_d helper_sve_andv_d_aarch64
#define helper_sve_saddv_b helper_sve_saddv_b_aarch64
#define helper_sve_saddv_h helper_sve_saddv_h_aarch64
#define helper_sve_saddv_s helper_sve_saddv_s_aarch64
#define helper_sve_uaddv_b helper_sve_uaddv_b_aarch64
#define helper_sve_uaddv_h helper_sve_uaddv_h_aarch64
#define helper_sve_uaddv_s helper_sve_uaddv_s_aarch64
#define helper_sve_uaddv_d helper_sve_uaddv_d_aarch64
#define helper_sve_smaxv_b helper_sve_smaxv_b_aarch64
#define helper_sve_smaxv_h helper_sve_smaxv_h_aarch64
#define helper_sve_smaxv_s helper_sve_smaxv_s_aarch64
#define helper_sve_smaxv_d helper_sve_smaxv_d_aarch64
#define helper_sve_umaxv_b helper_sve_umaxv_b_aarch64
#define helper_sve_umaxv_h helper_sve_umaxv_h_aarch64
#define helper_sve_umaxv_s helper_sve_umaxv_s_aarch64
#define helper_sve_umaxv_d helper_sve_umaxv_d_aarch64
#define helper_sve_sminv_b helper_sve_sminv_b_aarch64
#define helper_sve_sminv_h helper_sve_sminv_h_aarch64
#define helper_sve_sminv_s helper_sve_sminv_s_aarch64
#define helper_sve_sminv_d helper_sve_sminv_d_aarch64
#define helper_sve_uminv_b helper_sve_uminv_b_aarch64
#define helper_sve_uminv_h helper_sve_uminv_h_aarch64
#define helper_sve_uminv_s helper_sve_uminv_s_aarch64
#define helper_sve_uminv_d helper_sve_uminv_d_aarch64
#define helper_sve_subri_b helper_sve_subri_b_aarch64
#define helper_sve_subri_h helper_sve_subri_h_aarch64
#define helper_sve_subri_s helper_sve_subri_s_aarch64
#define helper_sve_subri_d helper_sve_subri_d_aarch64
#define helper_sve_smaxi_b helper_sve_smaxi_b_aarch64
#define helper_sve_smaxi_h helper_sve_smaxi_h_aarch64
#define helper_sve_smaxi_s helper_sve_smaxi_s_aarch64
#define helper_sve_smaxi_d helper_sve_smaxi_d_aarch64
#define helper_sve_smini_b helper_sve_smini_b_aarch64
#define helper_sve_smini_h helper_sve_smini_h_aarch64
#define helper_sve_smini_s helper_sve_smini_s_aarch64
#define helper_sve_smini_d helper_sve_smini_d_aarch64
#define helper_sve_umaxi_b helper_sve_umaxi_b_aarch64
#define helper_sve_umaxi_h helper_sve_umaxi_h_aarch64
#define helper_sve_umaxi_s helper_sve_umaxi_s_aarch64
#define helper_sve_umaxi_d helper_sve_umaxi_d_aarch64
#define helper_sve_umini_b helper_sve_umini_b_aarch64
#define helper_sve_umini_h helper_sve_umini_h_aarch64
#define helper_sve_umini_s helper_sve_umini_s_aarch64
#define helper_sve_umini_d helper_sve_umini_d_aarch64
#define helper_sve_pfirst helper_sve_pfirst_aarch64
#define helper_sve_pnext helper_sve_pnext_aarch64
#define helper_sve_clr_b helper_sve_clr_b_aarch64
#define helper_sve_clr_h helper_sve_clr_h_aarch64
#define helper_sve_clr_s helper_sve_clr_s_aarch64
#define helper_sve_clr_d helper_sve_clr_d_aarch64
#define helper_sve_movz_b helper_sve_movz_b_aarch64
#define helper_sve_movz_h helper_sve_movz_h_aarch64
#define helper_sve_movz_s helper_sve_movz_s_aarch64
#define helper_sve_movz_d helper_sve_movz_d_aarch64
#define helper_sve_asr_zpzi_b helper_sve_asr_zpzi_b_aarch64
#define helper_sve_asr_zpzi_h helper_sve_asr_zpzi_h_aarch64
#define helper_sve_asr_zpzi_s helper_sve_asr_zpzi_s_aarch64
#define helper_sve_asr_zpzi_d helper_sve_asr_zpzi_d_aarch64
#define helper_sve_lsr_zpzi_b helper_sve_lsr_zpzi_b_aarch64
#define helper_sve_lsr_zpzi_h helper_sve_lsr_zpzi_h_aarch64
#define helper_sve_lsr_zpzi_s helper_sve_lsr_zpzi_s_aarch64
#define helper_sve_lsr_zpzi_d helper_sve_lsr_zpzi_d_aarch64
#define helper_sve_lsl_zpzi_b helper_sve_lsl_zpzi_b_aarch64
#define helper_sve_lsl_zpzi_h helper_sve_lsl_zpzi_h_aarch64
#define helper_sve_lsl_zpzi_s helper_sve_lsl_zpzi_s_aarch64
#define helper_sve_lsl_zpzi_d helper_sve_lsl_zpzi_d_aarch64
#define helper_sve_asrd_b helper_sve_asrd_b_aarch64
#define helper_sve_asrd_h helper_sve_asrd_h_aarch64
#define helper_sve_asrd_s helper_sve_asrd_s_aarch64
#define helper_sve_asrd_d helper_sve_asrd_d_aarch64
#define helper_sve_mla_b helper_sve_mla_b_aarch64
#define helper_sve_mls_b helper_sve_mls_b_aarch64
#define helper_sve_mla_h helper_sve_mla_h_aarch64
#define helper_sve_mls_h helper_sve_mls_h_aarch64
#define helper_sve_mla_s helper_sve_mla_s_aarch64
#define helper_sve_mls_s helper_sve_mls_s_aarch64
#define helper_sve_mla_d helper_sve_mla_d_aarch64
#define helper_sve_mls_d helper_sve_mls_d_aarch64
#define helper_sve_index_b helper_sve_index_b_aarch64
#define helper_sve_index_h helper_sve_index_h_aarch64
#define helper_sve_index_s helper_sve_index_s_aarch64
#define helper_sve_index_d helper_sve_index_d_aarch64
#define helper_sve_adr_p32 helper_sve_adr_p32_aarch64
#define helper_sve_adr_p64 helper_sve_adr_p64_aarch64
#define helper_sve_adr_s32 helper_sve_adr_s32_aarch64
#define helper_sve_adr_u32 helper_sve_adr_u32_aarch64
#define helper_sve_fexpa_h helper_sve_fexpa_h_aarch64
#define helper_sve_fexpa_s helper_sve_fexpa_s_aarch64
#define helper_sve_fexpa_d helper_sve_fexpa_d_aarch64
#define helper_sve_ftssel_h helper_sve_ftssel_h_aarch64
#define helper_sve_ftssel_s helper_sve_ftssel_s_aarch64
#define helper_sve_ftssel_d helper_sve_ftssel_d_aarch64
#define helper_sve_sqaddi_b helper_sve_sqaddi_b_aarch64
#define helper_sve_sqaddi_h helper_sve_sqaddi_h_aarch64
#define helper_sve_sqaddi_s helper_sve_sqaddi_s_aarch64
#define helper_sve_sqaddi_d helper_sve_sqaddi_d_aarch64
#define helper_sve_uqaddi_b helper_sve_uqaddi_b_aarch64
#define helper_sve_uqaddi_h helper_sve_uqaddi_h_aarch64
#define helper_sve_uqaddi_s helper_sve_uqaddi_s_aarch64
#define helper_sve_uqaddi_d helper_sve_uqaddi_d_aarch64
#define helper_sve_uqsubi_d helper_sve_uqsubi_d_aarch64
#define helper_sve_cpy_m_b helper_sve_cpy_m_b_aarch64
#define helper_sve_cpy_m_h helper_sve_cpy_m_h_aarch64
#define helper_sve_cpy_m_s helper_sve_cpy_m_s_aarch64
#define helper_sve_cpy_m_d helper_sve_cpy_m_d_aarch64
#define helper_sve_cpy_z_b helper_sve_cpy_z_b_aarch64
#define helper_sve_cpy_z_h helper_sve_cpy_z_h_aarch64
#define helper_sve_cpy_z_s helper_sve_cpy_z_s_aarch64
#define helper_sve_cpy_z_d helper_sve_cpy_z_d_aarch64
#define helper_sve_ext helper_sve_ext_aarch64
#define helper_sve_insr_b helper_sve_insr_b_aarch64
#define helper_sve_insr_h helper_sve_insr_h_aarch64
#define helper_sve_insr_s helper_sve_insr_s_aarch64
#define helper_sve_insr_d helper_sve_insr_d_aarch64
#define helper_sve_rev_b helper_sve_rev_b_aarch64
#define helper_sve_rev_h helper_sve_rev_h_aarch64
#define helper_sve_rev_s helper_sve_rev_s_aarch64
#define helper_sve_rev_d helper_sve_rev_d_aarch64
#define helper_sve_tbl_b helper_sve_tbl_b_aarch64
#define helper_sve_tbl_h helper_sve_tbl_h_aarch64
#define helper_sve_tbl_s helper_sve_tbl_s_aarch64
#define helper_sve_tbl_d helper_sve_tbl_d_aarch64
#define helper_sve_sunpk_h helper_sve_sunpk_h_aarch64
#define helper_sve_sunpk_s helper_sve_sunpk_s_aarch64
#define helper_sve_sunpk_d helper_sve_sunpk_d_aarch64
#define helper_sve_uunpk_h helper_sve_uunpk_h_aarch64
#define helper_sve_uunpk_s helper_sve_uunpk_s_aarch64
#define helper_sve_uunpk_d helper_sve_uunpk_d_aarch64
#define helper_sve_zip_p helper_sve_zip_p_aarch64
#define helper_sve_uzp_p helper_sve_uzp_p_aarch64
#define helper_sve_trn_p helper_sve_trn_p_aarch64
#define helper_sve_rev_p helper_sve_rev_p_aarch64
#define helper_sve_punpk_p helper_sve_punpk_p_aarch64
#define helper_sve_zip_b helper_sve_zip_b_aarch64
#define helper_sve_zip_h helper_sve_zip_h_aarch64
#define helper_sve_zip_s helper_sve_zip_s_aarch64
#define helper_sve_zip_d helper_sve_zip_d_aarch64
#define helper_sve_uzp_b helper_sve_uzp_b_aarch64
#define helper_sve_uzp_h helper_sve_uzp_h_aarch64
#define helper_sve_uzp_s helper_sve_uzp_s_aarch64
#define helper_sve_uzp_d helper_sve_uzp_d_aarch64
#define helper_sve_trn_b helper_sve_trn_b_aarch64
#define helper_sve_trn_h helper_sve_trn_h_aarch64
#define helper_sve_trn_s helper_sve_trn_s_aarch64
#define helper_sve_trn_d helper_sve_trn_d_aarch64
#define helper_sve_compact_s helper_sve_compact_s_aarch64
#define helper_sve_compact_d helper_sve_compact_d_aarch64
#define helper_sve_last_active_element helper_sve_last_active_element_aarch64
#define helper_sve_splice helper_sve_splice_aarch64
#define helper_sve_sel_zpzz_b helper_sve_sel_zpzz_b_aarch64
#define helper_sve_sel_zpzz_h helper_sve_sel_zpzz_h_aarch64
#define helper_sve_sel_zpzz_s helper_sve_sel_zpzz_s_aarch64
#define helper_sve_sel_zpzz_d helper_sve_sel_zpzz_d_aarch64
#define helper_sve_cmpeq_ppzz_b helper_sve_cmpeq_ppzz_b_aarch64
#define helper_sve_cmpeq_ppzz_h helper_sve_cmpeq_ppzz_h_aarch64
#define helper_sve_cmpeq_ppzz_s helper_sve_cmpeq_ppzz_s_aarch64
#define helper_sve_cmpeq_ppzz_d helper_sve_cmpeq_ppzz_d_aarch64
#define helper_sve_cmpne_ppzz_b helper_sve_cmpne_ppzz_b_aarch64
#define helper_sve_cmpne_ppzz_h helper_sve_cmpne_ppzz_h_aarch64
#define helper_sve_cmpne_ppzz_s helper_sve_cmpne_ppzz_s_aarch64
#define helper_sve_cmpne_ppzz_d helper_sve_cmpne_ppzz_d_aarch64
#define helper_sve_cmpgt_ppzz_b helper_sve_cmpgt_ppzz_b_aarch64
#define helper_sve_cmpgt_ppzz_h helper_sve_cmpgt_ppzz_h_aarch64
#define helper_sve_cmpgt_ppzz_s helper_sve_cmpgt_ppzz_s_aarch64
#define helper_sve_cmpgt_ppzz_d helper_sve_cmpgt_ppzz_d_aarch64
#define helper_sve_cmpge_ppzz_b helper_sve_cmpge_ppzz_b_aarch64
#define helper_sve_cmpge_ppzz_h helper_sve_cmpge_ppzz_h_aarch64
#define helper_sve_cmpge_ppzz_s helper_sve_cmpge_ppzz_s_aarch64
#define helper_sve_cmpge_ppzz_d helper_sve_cmpge_ppzz_d_aarch64
#define helper_sve_cmphi_ppzz_b helper_sve_cmphi_ppzz_b_aarch64
#define helper_sve_cmphi_ppzz_h helper_sve_cmphi_ppzz_h_aarch64
#define helper_sve_cmphi_ppzz_s helper_sve_cmphi_ppzz_s_aarch64
#define helper_sve_cmphi_ppzz_d helper_sve_cmphi_ppzz_d_aarch64
#define helper_sve_cmphs_ppzz_b helper_sve_cmphs_ppzz_b_aarch64
#define helper_sve_cmphs_ppzz_h helper_sve_cmphs_ppzz_h_aarch64
#define helper_sve_cmphs_ppzz_s helper_sve_cmphs_ppzz_s_aarch64
#define helper_sve_cmphs_ppzz_d helper_sve_cmphs_ppzz_d_aarch64
#define helper_sve_cmpeq_ppzw_b helper_sve_cmpeq_ppzw_b_aarch64
#define helper_sve_cmpeq_ppzw_h helper_sve_cmpeq_ppzw_h_aarch64
#define helper_sve_cmpeq_ppzw_s helper_sve_cmpeq_ppzw_s_aarch64
#define helper_sve_cmpne_ppzw_b helper_sve_cmpne_ppzw_b_aarch64
#define helper_sve_cmpne_ppzw_h helper_sve_cmpne_ppzw_h_aarch64
#define helper_sve_cmpne_ppzw_s helper_sve_cmpne_ppzw_s_aarch64
#define helper_sve_cmpgt_ppzw_b helper_sve_cmpgt_ppzw_b_aarch64
#define helper_sve_cmpgt_ppzw_h helper_sve_cmpgt_ppzw_h_aarch64
#define helper_sve_cmpgt_ppzw_s helper_sve_cmpgt_ppzw_s_aarch64
#define helper_sve_cmpge_ppzw_b helper_sve_cmpge_ppzw_b_aarch64
#define helper_sve_cmpge_ppzw_h helper_sve_cmpge_ppzw_h_aarch64
#define helper_sve_cmpge_ppzw_s helper_sve_cmpge_ppzw_s_aarch64
#define helper_sve_cmphi_ppzw_b helper_sve_cmphi_ppzw_b_aarch64
#define helper_sve_cmphi_ppzw_h helper_sve_cmphi_ppzw_h_aarch64
#define helper_sve_cmphi_ppzw_s helper_sve_cmphi_ppzw_s_aarch64
#define helper_sve_cmphs_ppzw_b helper_sve_cmphs_ppzw_b_aarch64
#define helper_sve_cmphs_ppzw_h helper_sve_cmphs_ppzw_h_aarch64
#define helper_sve_cmphs_ppzw_s helper_sve_cmphs_ppzw_s_aarch64
#define helper_sve_cmplt_ppzw_b helper_sve_cmplt_ppzw_b_aarch64
#define helper_sve_cmplt_ppzw_h helper_sve_cmplt_ppzw_h_aarch64
#define helper_sve_cmplt_ppzw_s helper_sve_cmplt_ppzw_s_aarch64
#define helper_sve_cmple_ppzw_b helper_sve_cmple_ppzw_b_aarch64
#define helper_sve_cmple_ppzw_h helper_sve_cmple_ppzw_h_aarch64
#define helper_sve_cmple_ppzw_s helper_sve_cmple_ppzw_s_aarch64
#define helper_sve_cmplo_ppzw_b helper_sve_cmplo_ppzw_b_aarch64
#define helper_sve_cmplo_ppzw_h helper_sve_cmplo_ppzw_h_aarch64
#define helper_sve_cmplo_ppzw_s helper_sve_cmplo_ppzw_s_aarch64
#define helper_sve_cmpls_ppzw_b helper_sve_cmpls_ppzw_b_aarch64
#define helper_sve_cmpls_ppzw_h helper_sve_cmpls_ppzw_h_aarch64
#define helper_sve_cmpls_ppzw_s helper_sve_cmpls_ppzw_s_aarch64
#define helper_sve_cmpeq_ppzi_b helper_sve_cmpeq_ppzi_b_aarch64
#define helper_sve_cmpeq_ppzi_h helper_sve_cmpeq_ppzi_h_aarch64
#define helper_sve_cmpeq_ppzi_s helper_sve_cmpeq_ppzi_s_aarch64
#define helper_sve_cmpeq_ppzi_d helper_sve_cmpeq_ppzi_d_aarch64
#define helper_sve_cmpne_ppzi_b helper_sve_cmpne_ppzi_b_aarch64
#define helper_sve_cmpne_ppzi_h helper_sve_cmpne_ppzi_h_aarch64
#define helper_sve_cmpne_ppzi_s helper_sve_cmpne_ppzi_s_aarch64
#define helper_sve_cmpne_ppzi_d helper_sve_cmpne_ppzi_d_aarch64
#define helper_sve_cmpgt_ppzi_b helper_sve_cmpgt_ppzi_b_aarch64
#define helper_sve_cmpgt_ppzi_h helper_sve_cmpgt_ppzi_h_aarch64
#define helper_sve_cmpgt_ppzi_s helper_sve_cmpgt_ppzi_s_aarch64
#define helper_sve_cmpgt_ppzi_d helper_sve_cmpgt_ppzi_d_aarch64
#define helper_sve_cmpge_ppzi_b helper_sve_cmpge_ppzi_b_aarch64
#define helper_sve_cmpge_ppzi_h helper_sve_cmpge_ppzi_h_aarch64
#define helper_sve_cmpge_ppzi_s helper_sve_cmpge_ppzi_s_aarch64
#define helper_sve_cmpge_ppzi_d helper_sve_cmpge_ppzi_d_aarch64
#define helper_sve_cmphi_ppzi_b helper_sve_cmphi_ppzi_b_aarch64
#define helper_sve_cmphi_ppzi_h helper_sve_cmphi_ppzi_h_aarch64
#define helper_sve_cmphi_ppzi_s helper_sve_cmphi_ppzi_s_aarch64
#define helper_sve_cmphi_ppzi_d helper_sve_cmphi_ppzi_d_aarch64
#define helper_sve_cmphs_ppzi_b helper_sve_cmphs_ppzi_b_aarch64
#define helper_sve_cmphs_ppzi_h helper_sve_cmphs_ppzi_h_aarch64
#define helper_sve_cmphs_ppzi_s helper_sve_cmphs_ppzi_s_aarch64
#define helper_sve_cmphs_ppzi_d helper_sve_cmphs_ppzi_d_aarch64
#define helper_sve_cmplt_ppzi_b helper_sve_cmplt_ppzi_b_aarch64
#define helper_sve_cmplt_ppzi_h helper_sve_cmplt_ppzi_h_aarch64
#define helper_sve_cmplt_ppzi_s helper_sve_cmplt_ppzi_s_aarch64
#define helper_sve_cmplt_ppzi_d helper_sve_cmplt_ppzi_d_aarch64
#define helper_sve_cmple_ppzi_b helper_sve_cmple_ppzi_b_aarch64
#define helper_sve_cmple_ppzi_h helper_sve_cmple_ppzi_h_aarch64
#define helper_sve_cmple_ppzi_s helper_sve_cmple_ppzi_s_aarch64
#define helper_sve_cmple_ppzi_d helper_sve_cmple_ppzi_d_aarch64
#define helper_sve_cmplo_ppzi_b helper_sve_cmplo_ppzi_b_aarch64
#define helper_sve_cmplo_ppzi_h helper_sve_cmplo_ppzi_h_aarch64
#define helper_sve_cmplo_ppzi_s helper_sve_cmplo_ppzi_s_aarch64
#define helper_sve_cmplo_ppzi_d helper_sve_cmplo_ppzi_d_aarch64
#define helper_sve_cmpls_ppzi_b helper_sve_cmpls_ppzi_b_aarch64
#define helper_sve_cmpls_ppzi_h helper_sve_cmpls_ppzi_h_aarch64
#define helper_sve_cmpls_ppzi_s helper_sve_cmpls_ppzi_s_aarch64
#define helper_sve_cmpls_ppzi_d helper_sve_cmpls_ppzi_d_aarch64
#define helper_sve_brkpa helper_sve_brkpa_aarch64
#define helper_sve_brkpas helper_sve_brkpas_aarch64
#define helper_sve_brkpb helper_sve_brkpb_aarch64
#define helper_sve_brkpbs helper_sve_brkpbs_aarch64
#define helper_sve_brka_z helper_sve_brka_z_aarch64
#define helper_sve_brkas_z helper_sve_brkas_z_aarch64
#define helper_sve_brkb_z helper_sve_brkb_z_aarch64
#define helper_sve_brkbs_z helper_sve_brkbs_z_aarch64
#define helper_sve_brka_m helper_sve_brka_m_aarch64
#define helper_sve_brkas_m helper_sve_brkas_m_aarch64
#define helper_sve_brkb_m helper_sve_brkb_m_aarch64
#define helper_sve_brkbs_m helper_sve_brkbs_m_aarch64
#define helper_sve_brkn helper_sve_brkn_aarch64
#define helper_sve_brkns helper_sve_brkns_aarch64
#define helper_sve_cntp helper_sve_cntp_aarch64
#define helper_sve_while helper_sve_while_aarch64
#define helper_sve_faddv_h helper_sve_faddv_h_aarch64
#define helper_sve_faddv_s helper_sve_faddv_s_aarch64
#define helper_sve_faddv_d helper_sve_faddv_d_aarch64
#define helper_sve_fminnmv_h helper_sve_fminnmv_h_aarch64
#define helper_sve_fminnmv_s helper_sve_fminnmv_s_aarch64
#define helper_sve_fminnmv_d helper_sve_fminnmv_d_aarch64
#define helper_sve_fmaxnmv_h helper_sve_fmaxnmv_h_aarch64
#define helper_sve_fmaxnmv_s helper_sve_fmaxnmv_s_aarch64
#define helper_sve_fmaxnmv_d helper_sve_fmaxnmv_d_aarch64
#define helper_sve_fminv_h helper_sve_fminv_h_aarch64
#define helper_sve_fminv_s helper_sve_fminv_s_aarch64
#define helper_sve_fminv_d helper_sve_fminv_d_aarch64
#define helper_sve_fmaxv_h helper_sve_fmaxv_h_aarch64
#define helper_sve_fmaxv_s helper_sve_fmaxv_s_aarch64
#define helper_sve_fmaxv_d helper_sve_fmaxv_d_aarch64
#define helper_sve_fadda_h helper_sve_fadda_h_aarch64
#define helper_sve_fadda_s helper_sve_fadda_s_aarch64
#define helper_sve_fadda_d helper_sve_fadda_d_aarch64
#define helper_sve_fadd_h helper_sve_fadd_h_aarch64
#define helper_sve_fadd_s helper_sve_fadd_s_aarch64
#define helper_sve_fadd_d helper_sve_fadd_d_aarch64
#define helper_sve_fsub_h helper_sve_fsub_h_aarch64
#define helper_sve_fsub_s helper_sve_fsub_s_aarch64
#define helper_sve_fsub_d helper_sve_fsub_d_aarch64
#define helper_sve_fmul_h helper_sve_fmul_h_aarch64
#define helper_sve_fmul_s helper_sve_fmul_s_aarch64
#define helper_sve_fmul_d helper_sve_fmul_d_aarch64
#define helper_sve_fdiv_h helper_sve_fdiv_h_aarch64
#define helper_sve_fdiv_s helper_sve_fdiv_s_aarch64
#define helper_sve_fdiv_d helper_sve_fdiv_d_aarch64
#define helper_sve_fmin_h helper_sve_fmin_h_aarch64
#define helper_sve_fmin_s helper_sve_fmin_s_aarch64
#define helper_sve_fmin_d helper_sve_fmin_d_aarch64
#define helper_sve_fmax_h helper_sve_fmax_h_aarch64
#define helper_sve_fmax_s helper_sve_fmax_s_aarch64
#define helper_sve_fmax_d helper_sve_fmax_d_aarch64
#define helper_sve_fminnum_h helper_sve_fminnum_h_aarch64
#define helper_sve_fminnum_s helper_sve_fminnum_s_aarch64
#define helper_sve_fminnum_d helper_sve_fminnum_d_aarch64
#define helper_sve_fmaxnum_h helper_sve_fmaxnum_h_aarch64
#define helper_sve_fmaxnum_s helper_sve_fmaxnum_s_aarch64
#define helper_sve_fmaxnum_d helper_sve_fmaxnum_d_aarch64
#define helper_sve_fabd_h helper_sve_fabd_h_aarch64
#define helper_sve_fabd_s helper_sve_fabd_s_aarch64
#define helper_sve_fabd_d helper_sve_fabd_d_aarch64
#define helper_sve_fscalbn_h helper_sve_fscalbn_h_aarch64
#define helper_sve_fscalbn_s helper_sve_fscalbn_s_aarch64
#define helper_sve_fscalbn_d helper_sve_fscalbn_d_aarch64
#define helper_sve_fmulx_h helper_sve_fmulx_h_aarch64
#define helper_sve_fmulx_s helper_sve_fmulx_s_aarch64
#define helper_sve_fmulx_d helper_sve_fmulx_d_aarch64
#define helper_sve_fadds_h helper_sve_fadds_h_aarch64
#define helper_sve_fadds_s helper_sve_fadds_s_aarch64
#define helper_sve_fadds_d helper_sve_fadds_d_aarch64
#define helper_sve_fsubs_h helper_sve_fsubs_h_aarch64
#define helper_sve_fsubs_s helper_sve_fsubs_s_aarch64
#define helper_sve_fsubs_d helper_sve_fsubs_d_aarch64
#define helper_sve_fmuls_h helper_sve_fmuls_h_aarch64
#define helper_sve_fmuls_s helper_sve_fmuls_s_aarch64
#define helper_sve_fmuls_d helper_sve_fmuls_d_aarch64
#define helper_sve_fsubrs_h helper_sve_fsubrs_h_aarch64
#define helper_sve_fsubrs_s helper_sve_fsubrs_s_aarch64
#define helper_sve_fsubrs_d helper_sve_fsubrs_d_aarch64
#define helper_sve_fmaxnms_h helper_sve_fmaxnms_h_aarch64
#define helper_sve_fmaxnms_s helper_sve_fmaxnms_s_aarch64
#define helper_sve_fmaxnms_d helper_sve_fmaxnms_d_aarch64
#define helper_sve_fminnms_h helper_sve_fminnms_h_aarch64
#define helper_sve_fminnms_s helper_sve_fminnms_s_aarch64
#define helper_sve_fminnms_d helper_sve_fminnms_d_aarch64
#define helper_sve_fmaxs_h helper_sve_fmaxs_h_aarch64
#define helper_sve_fmaxs_s helper_sve_fmaxs_s_aarch64
#define helper_sve_fmaxs_d helper_sve_fmaxs_d_aarch64
#define helper_sve_fmins_h helper_sve_fmins_h_aarch64
#define helper_sve_fmins_s helper_sve_fmins_s_aarch64
#define helper_sve_fmins_d helper_sve_fmins_d_aarch64
#define helper_sve_fcvt_sh helper_sve_fcvt_sh_aarch64
#define helper_sve_fcvt_hs helper_sve_fcvt_hs_aarch64
#define helper_sve_fcvt_dh helper_sve_fcvt_dh_aarch64
#define helper_sve_fcvt_hd helper_sve_fcvt_hd_aarch64
#define helper_sve_fcvt_ds helper_sve_fcvt_ds_aarch64
#define helper_sve_fcvt_sd helper_sve_fcvt_sd_aarch64
#define helper_sve_fcvtzs_hh helper_sve_fcvtzs_hh_aarch64
#define helper_sve_fcvtzs_hs helper_sve_fcvtzs_hs_aarch64
#define helper_sve_fcvtzs_ss helper_sve_fcvtzs_ss_aarch64
#define helper_sve_fcvtzs_hd helper_sve_fcvtzs_hd_aarch64
#define helper_sve_fcvtzs_sd helper_sve_fcvtzs_sd_aarch64
#define helper_sve_fcvtzs_ds helper_sve_fcvtzs_ds_aarch64
#define helper_sve_fcvtzs_dd helper_sve_fcvtzs_dd_aarch64
#define helper_sve_fcvtzu_hh helper_sve_fcvtzu_hh_aarch64
#define helper_sve_fcvtzu_hs helper_sve_fcvtzu_hs_aarch64
#define helper_sve_fcvtzu_ss helper_sve_fcvtzu_ss_aarch64
#define helper_sve_fcvtzu_hd helper_sve_fcvtzu_hd_aarch64
#define helper_sve_fcvtzu_sd helper_sve_fcvtzu_sd_aarch64
#define helper_sve_fcvtzu_ds helper_sve_fcvtzu_ds_aarch64
#define helper_sve_fcvtzu_dd helper_sve_fcvtzu_dd_aarch64
#define helper_sve_frint_h helper_sve_frint_h_aarch64
#define helper_sve_frint_s helper_sve_frint_s_aarch64
#define helper_sve_frint_d helper_sve_frint_d_aarch64
#define helper_sve_frintx_h helper_sve_frintx_h_aarch64
#define helper_sve_frintx_s helper_sve_frintx_s_aarch64
#define helper_sve_frintx_d helper_sve_frintx_d_aarch64
#define helper_sve_frecpx_h helper_sve_frecpx_h_aarch64
#define helper_sve_frecpx_s helper_sve_frecpx_s_aarch64
#define helper_sve_frecpx_d helper_sve_frecpx_d_aarch64
#define helper_sve_fsqrt_h helper_sve_fsqrt_h_aarch64
#define helper_sve_fsqrt_s helper_sve_fsqrt_s_aarch64
#define helper_sve_fsqrt_d helper_sve_fsqrt_d_aarch64
#define helper_sve_scvt_hh helper_sve_scvt_hh_aarch64
#define helper_sve_scvt_sh helper_sve_scvt_sh_aarch64
#define helper_sve_scvt_ss helper_sve_scvt_ss_aarch64
#define helper_sve_scvt_sd helper_sve_scvt_sd_aarch64
#define helper_sve_scvt_dh helper_sve_scvt_dh_aarch64
#define helper_sve_scvt_ds helper_sve_scvt_ds_aarch64
#define helper_sve_scvt_dd helper_sve_scvt_dd_aarch64
#define helper_sve_ucvt_hh helper_sve_ucvt_hh_aarch64
#define helper_sve_ucvt_sh helper_sve_ucvt_sh_aarch64
#define helper_sve_ucvt_ss helper_sve_ucvt_ss_aarch64
#define helper_sve_ucvt_sd helper_sve_ucvt_sd_aarch64
#define helper_sve_ucvt_dh helper_sve_ucvt_dh_aarch64
#define helper_sve_ucvt_ds helper_sve_ucvt_ds_aarch64
#define helper_sve_ucvt_dd helper_sve_ucvt_dd_aarch64
#define helper_sve_fmla_zpzzz_h helper_sve_fmla_zpzzz_h_aarch64
#define helper_sve_fmls_zpzzz_h helper_sve_fmls_zpzzz_h_aarch64
#define helper_sve_fnmla_zpzzz_h helper_sve_fnmla_zpzzz_h_aarch64
#define helper_sve_fnmls_zpzzz_h helper_sve_fnmls_zpzzz_h_aarch64
#define helper_sve_fmla_zpzzz_s helper_sve_fmla_zpzzz_s_aarch64
#define helper_sve_fmls_zpzzz_s helper_sve_fmls_zpzzz_s_aarch64
#define helper_sve_fnmla_zpzzz_s helper_sve_fnmla_zpzzz_s_aarch64
#define helper_sve_fnmls_zpzzz_s helper_sve_fnmls_zpzzz_s_aarch64
#define helper_sve_fmla_zpzzz_d helper_sve_fmla_zpzzz_d_aarch64
#define helper_sve_fmls_zpzzz_d helper_sve_fmls_zpzzz_d_aarch64
#define helper_sve_fnmla_zpzzz_d helper_sve_fnmla_zpzzz_d_aarch64
#define helper_sve_fnmls_zpzzz_d helper_sve_fnmls_zpzzz_d_aarch64
#define helper_sve_fcmge_h helper_sve_fcmge_h_aarch64
#define helper_sve_fcmge_s helper_sve_fcmge_s_aarch64
#define helper_sve_fcmge_d helper_sve_fcmge_d_aarch64
#define helper_sve_fcmgt_h helper_sve_fcmgt_h_aarch64
#define helper_sve_fcmgt_s helper_sve_fcmgt_s_aarch64
#define helper_sve_fcmgt_d helper_sve_fcmgt_d_aarch64
#define helper_sve_fcmeq_h helper_sve_fcmeq_h_aarch64
#define helper_sve_fcmeq_s helper_sve_fcmeq_s_aarch64
#define helper_sve_fcmeq_d helper_sve_fcmeq_d_aarch64
#define helper_sve_fcmne_h helper_sve_fcmne_h_aarch64
#define helper_sve_fcmne_s helper_sve_fcmne_s_aarch64
#define helper_sve_fcmne_d helper_sve_fcmne_d_aarch64
#define helper_sve_fcmuo_h helper_sve_fcmuo_h_aarch64
#define helper_sve_fcmuo_s helper_sve_fcmuo_s_aarch64
#define helper_sve_fcmuo_d helper_sve_fcmuo_d_aarch64
#define helper_sve_facge_h helper_sve_facge_h_aarch64
#define helper_sve_facge_s helper_sve_facge_s_aarch64
#define helper_sve_facge_d helper_sve_facge_d_aarch64
#define helper_sve_facgt_h helper_sve_facgt_h_aarch64
#define helper_sve_facgt_s helper_sve_facgt_s_aarch64
#define helper_sve_facgt_d helper_sve_facgt_d_aarch64
#define helper_sve_fcmge0_h helper_sve_fcmge0_h_aarch64
#define helper_sve_fcmge0_s helper_sve_fcmge0_s_aarch64
#define helper_sve_fcmge0_d helper_sve_fcmge0_d_aarch64
#define helper_sve_fcmgt0_h helper_sve_fcmgt0_h_aarch64
#define helper_sve_fcmgt0_s helper_sve_fcmgt0_s_aarch64
#define helper_sve_fcmgt0_d helper_sve_fcmgt0_d_aarch64
#define helper_sve_fcmle0_h helper_sve_fcmle0_h_aarch64
#define helper_sve_fcmle0_s helper_sve_fcmle0_s_aarch64
#define helper_sve_fcmle0_d helper_sve_fcmle0_d_aarch64
#define helper_sve_fcmlt0_h helper_sve_fcmlt0_h_aarch64
#define helper_sve_fcmlt0_s helper_sve_fcmlt0_s_aarch64
#define helper_sve_fcmlt0_d helper_sve_fcmlt0_d_aarch64
#define helper_sve_fcmeq0_h helper_sve_fcmeq0_h_aarch64
#define helper_sve_fcmeq0_s helper_sve_fcmeq0_s_aarch64
#define helper_sve_fcmeq0_d helper_sve_fcmeq0_d_aarch64
#define helper_sve_fcmne0_h helper_sve_fcmne0_h_aarch64
#define helper_sve_fcmne0_s helper_sve_fcmne0_s_aarch64
#define helper_sve_fcmne0_d helper_sve_fcmne0_d_aarch64
#define helper_sve_ftmad_h helper_sve_ftmad_h_aarch64
#define helper_sve_ftmad_s helper_sve_ftmad_s_aarch64
#define helper_sve_ftmad_d helper_sve_ftmad_d_aarch64
#define helper_sve_fcadd_h helper_sve_fcadd_h_aarch64
#define helper_sve_fcadd_s helper_sve_fcadd_s_aarch64
#define helper_sve_fcadd_d helper_sve_fcadd_d_aarch64
#define helper_sve_fcmla_zpzzz_h helper_sve_fcmla_zpzzz_h_aarch64
#define helper_sve_fcmla_zpzzz_s helper_sve_fcmla_zpzzz_s_aarch64
#define helper_sve_fcmla_zpzzz_d helper_sve_fcmla_zpzzz_d_aarch64
#define helper_sve_ld1bb_r helper_sve_ld1bb_r_aarch64
#define helper_sve_ld1bhu_r helper_sve_ld1bhu_r_aarch64
#define helper_sve_ld1bhs_r helper_sve_ld1bhs_r_aarch64
#define helper_sve_ld1bsu_r helper_sve_ld1bsu_r_aarch64
#define helper_sve_ld1bss_r helper_sve_ld1bss_r_aarch64
#define helper_sve_ld1bdu_r helper_sve_ld1bdu_r_aarch64
#define helper_sve_ld1bds_r helper_sve_ld1bds_r_aarch64
#define helper_sve_ld1hh_le_r helper_sve_ld1hh_le_r_aarch64
#define helper_sve_ld1hh_be_r helper_sve_ld1hh_be_r_aarch64
#define helper_sve_ld1hsu_le_r helper_sve_ld1hsu_le_r_aarch64
#define helper_sve_ld1hsu_be_r helper_sve_ld1hsu_be_r_aarch64
#define helper_sve_ld1hss_le_r helper_sve_ld1hss_le_r_aarch64
#define helper_sve_ld1hss_be_r helper_sve_ld1hss_be_r_aarch64
#define helper_sve_ld1hdu_le_r helper_sve_ld1hdu_le_r_aarch64
#define helper_sve_ld1hdu_be_r helper_sve_ld1hdu_be_r_aarch64
#define helper_sve_ld1hds_le_r helper_sve_ld1hds_le_r_aarch64
#define helper_sve_ld1hds_be_r helper_sve_ld1hds_be_r_aarch64
#define helper_sve_ld1ss_le_r helper_sve_ld1ss_le_r_aarch64
#define helper_sve_ld1ss_be_r helper_sve_ld1ss_be_r_aarch64
#define helper_sve_ld1sdu_le_r helper_sve_ld1sdu_le_r_aarch64
#define helper_sve_ld1sdu_be_r helper_sve_ld1sdu_be_r_aarch64
#define helper_sve_ld1sds_le_r helper_sve_ld1sds_le_r_aarch64
#define helper_sve_ld1sds_be_r helper_sve_ld1sds_be_r_aarch64
#define helper_sve_ld1dd_le_r helper_sve_ld1dd_le_r_aarch64
#define helper_sve_ld1dd_be_r helper_sve_ld1dd_be_r_aarch64
#define helper_sve_ld2bb_r helper_sve_ld2bb_r_aarch64
#define helper_sve_ld3bb_r helper_sve_ld3bb_r_aarch64
#define helper_sve_ld4bb_r helper_sve_ld4bb_r_aarch64
#define helper_sve_ld2hh_le_r helper_sve_ld2hh_le_r_aarch64
#define helper_sve_ld2hh_be_r helper_sve_ld2hh_be_r_aarch64
#define helper_sve_ld3hh_le_r helper_sve_ld3hh_le_r_aarch64
#define helper_sve_ld3hh_be_r helper_sve_ld3hh_be_r_aarch64
#define helper_sve_ld4hh_le_r helper_sve_ld4hh_le_r_aarch64
#define helper_sve_ld4hh_be_r helper_sve_ld4hh_be_r_aarch64
#define helper_sve_ld2ss_le_r helper_sve_ld2ss_le_r_aarch64
#define helper_sve_ld2ss_be_r helper_sve_ld2ss_be_r_aarch64
#define helper_sve_ld3ss_le_r helper_sve_ld3ss_le_r_aarch64
#define helper_sve_ld3ss_be_r helper_sve_ld3ss_be_r_aarch64
#define helper_sve_ld4ss_le_r helper_sve_ld4ss_le_r_aarch64
#define helper_sve_ld4ss_be_r helper_sve_ld4ss_be_r_aarch64
#define helper_sve_ld2dd_le_r helper_sve_ld2dd_le_r_aarch64
#define helper_sve_ld2dd_be_r helper_sve_ld2dd_be_r_aarch64
#define helper_sve_ld3dd_le_r helper_sve_ld3dd_le_r_aarch64
#define helper_sve_ld3dd_be_r helper_sve_ld3dd_be_r_aarch64
#define helper_sve_ld4dd_le_r helper_sve_ld4dd_le_r_aarch64
#define helper_sve_ld4dd_be_r helper_sve_ld4dd_be_r_aarch64
#define helper_sve_ldff1bb_r helper_sve_ldff1bb_r_aarch64
#define helper_sve_ldnf1bb_r helper_sve_ldnf1bb_r_aarch64
#define helper_sve_ldff1bhu_r helper_sve_ldff1bhu_r_aarch64
#define helper_sve_ldnf1bhu_r helper_sve_ldnf1bhu_r_aarch64
#define helper_sve_ldff1bhs_r helper_sve_ldff1bhs_r_aarch64
#define helper_sve_ldnf1bhs_r helper_sve_ldnf1bhs_r_aarch64
#define helper_sve_ldff1bsu_r helper_sve_ldff1bsu_r_aarch64
#define helper_sve_ldnf1bsu_r helper_sve_ldnf1bsu_r_aarch64
#define helper_sve_ldff1bss_r helper_sve_ldff1bss_r_aarch64
#define helper_sve_ldnf1bss_r helper_sve_ldnf1bss_r_aarch64
#define helper_sve_ldff1bdu_r helper_sve_ldff1bdu_r_aarch64
#define helper_sve_ldnf1bdu_r helper_sve_ldnf1bdu_r_aarch64
#define helper_sve_ldff1bds_r helper_sve_ldff1bds_r_aarch64
#define helper_sve_ldnf1bds_r helper_sve_ldnf1bds_r_aarch64
#define helper_sve_ldff1hh_le_r helper_sve_ldff1hh_le_r_aarch64
#define helper_sve_ldnf1hh_le_r helper_sve_ldnf1hh_le_r_aarch64
#define helper_sve_ldff1hh_be_r helper_sve_ldff1hh_be_r_aarch64
#define helper_sve_ldnf1hh_be_r helper_sve_ldnf1hh_be_r_aarch64
#define helper_sve_ldff1hsu_le_r helper_sve_ldff1hsu_le_r_aarch64
#define helper_sve_ldnf1hsu_le_r helper_sve_ldnf1hsu_le_r_aarch64
#define helper_sve_ldff1hsu_be_r helper_sve_ldff1hsu_be_r_aarch64
#define helper_sve_ldnf1hsu_be_r helper_sve_ldnf1hsu_be_r_aarch64
#define helper_sve_ldff1hss_le_r helper_sve_ldff1hss_le_r_aarch64
#define helper_sve_ldnf1hss_le_r helper_sve_ldnf1hss_le_r_aarch64
#define helper_sve_ldff1hss_be_r helper_sve_ldff1hss_be_r_aarch64
#define helper_sve_ldnf1hss_be_r helper_sve_ldnf1hss_be_r_aarch64
#define helper_sve_ldff1hdu_le_r helper_sve_ldff1hdu_le_r_aarch64
#define helper_sve_ldnf1hdu_le_r helper_sve_ldnf1hdu_le_r_aarch64
#define helper_sve_ldff1hdu_be_r helper_sve_ldff1hdu_be_r_aarch64
#define helper_sve_ldnf1hdu_be_r helper_sve_ldnf1hdu_be_r_aarch64
#define helper_sve_ldff1hds_le_r helper_sve_ldff1hds_le_r_aarch64
#define helper_sve_ldnf1hds_le_r helper_sve_ldnf1hds_le_r_aarch64
#define helper_sve_ldff1hds_be_r helper_sve_ldff1hds_be_r_aarch64
#define helper_sve_ldnf1hds_be_r helper_sve_ldnf1hds_be_r_aarch64
#define helper_sve_ldff1ss_le_r helper_sve_ldff1ss_le_r_aarch64
#define helper_sve_ldnf1ss_le_r helper_sve_ldnf1ss_le_r_aarch64
#define helper_sve_ldff1ss_be_r helper_sve_ldff1ss_be_r_aarch64
#define helper_sve_ldnf1ss_be_r helper_sve_ldnf1ss_be_r_aarch64
#define helper_sve_ldff1sdu_le_r helper_sve_ldff1sdu_le_r_aarch64
#define helper_sve_ldnf1sdu_le_r helper_sve_ldnf1sdu_le_r_aarch64
#define helper_sve_ldff1sdu_be_r helper_sve_ldff1sdu_be_r_aarch64
#define helper_sve_ldnf1sdu_be_r helper_sve_ldnf1sdu_be_r_aarch64
#define helper_sve_ldff1sds_le_r helper_sve_ldff1sds_le_r_aarch64
#define helper_sve_ldnf1sds_le_r helper_sve_ldnf1sds_le_r_aarch64
#define helper_sve_ldff1sds_be_r helper_sve_ldff1sds_be_r_aarch64
#define helper_sve_ldnf1sds_be_r helper_sve_ldnf1sds_be_r_aarch64
#define helper_sve_ldff1dd_le_r helper_sve_ldff1dd_le_r_aarch64
#define helper_sve_ldnf1dd_le_r helper_sve_ldnf1dd_le_r_aarch64
#define helper_sve_ldff1dd_be_r helper_sve_ldff1dd_be_r_aarch64
#define helper_sve_ldnf1dd_be_r helper_sve_ldnf1dd_be_r_aarch64
#define helper_sve_st1bb_r helper_sve_st1bb_r_aarch64
#define helper_sve_st1bh_r helper_sve_st1bh_r_aarch64
#define helper_sve_st1bs_r helper_sve_st1bs_r_aarch64
#define helper_sve_st1bd_r helper_sve_st1bd_r_aarch64
#define helper_sve_st2bb_r helper_sve_st2bb_r_aarch64
#define helper_sve_st3bb_r helper_sve_st3bb_r_aarch64
#define helper_sve_st4bb_r helper_sve_st4bb_r_aarch64
#define helper_sve_st1hh_le_r helper_sve_st1hh_le_r_aarch64
#define helper_sve_st1hh_be_r helper_sve_st1hh_be_r_aarch64
#define helper_sve_st1hs_le_r helper_sve_st1hs_le_r_aarch64
#define helper_sve_st1hs_be_r helper_sve_st1hs_be_r_aarch64
#define helper_sve_st1hd_le_r helper_sve_st1hd_le_r_aarch64
#define helper_sve_st1hd_be_r helper_sve_st1hd_be_r_aarch64
#define helper_sve_st2hh_le_r helper_sve_st2hh_le_r_aarch64
#define helper_sve_st2hh_be_r helper_sve_st2hh_be_r_aarch64
#define helper_sve_st3hh_le_r helper_sve_st3hh_le_r_aarch64
#define helper_sve_st3hh_be_r helper_sve_st3hh_be_r_aarch64
#define helper_sve_st4hh_le_r helper_sve_st4hh_le_r_aarch64
#define helper_sve_st4hh_be_r helper_sve_st4hh_be_r_aarch64
#define helper_sve_st1ss_le_r helper_sve_st1ss_le_r_aarch64
#define helper_sve_st1ss_be_r helper_sve_st1ss_be_r_aarch64
#define helper_sve_st1sd_le_r helper_sve_st1sd_le_r_aarch64
#define helper_sve_st1sd_be_r helper_sve_st1sd_be_r_aarch64
#define helper_sve_st2ss_le_r helper_sve_st2ss_le_r_aarch64
#define helper_sve_st2ss_be_r helper_sve_st2ss_be_r_aarch64
#define helper_sve_st3ss_le_r helper_sve_st3ss_le_r_aarch64
#define helper_sve_st3ss_be_r helper_sve_st3ss_be_r_aarch64
#define helper_sve_st4ss_le_r helper_sve_st4ss_le_r_aarch64
#define helper_sve_st4ss_be_r helper_sve_st4ss_be_r_aarch64
#define helper_sve_st1dd_le_r helper_sve_st1dd_le_r_aarch64
#define helper_sve_st1dd_be_r helper_sve_st1dd_be_r_aarch64
#define helper_sve_st2dd_le_r helper_sve_st2dd_le_r_aarch64
#define helper_sve_st2dd_be_r helper_sve_st2dd_be_r_aarch64
#define helper_sve_st3dd_le_r helper_sve_st3dd_le_r_aarch64
#define helper_sve_st3dd_be_r helper_sve_st3dd_be_r_aarch64
#define helper_sve_st4dd_le_r helper_sve_st4dd_le_r_aarch64
#define helper_sve_st4dd_be_r helper_sve_st4dd_be_r_aarch64
#define helper_sve_ldbsu_zsu helper_sve_ldbsu_zsu_aarch64
#define helper_sve_ldbsu_zss helper_sve_ldbsu_zss_aarch64
#define helper_sve_ldbdu_zsu helper_sve_ldbdu_zsu_aarch64
#define helper_sve_ldbdu_zss helper_sve_ldbdu_zss_aarch64
#define helper_sve_ldbdu_zd helper_sve_ldbdu_zd_aarch64
#define helper_sve_ldbss_zsu helper_sve_ldbss_zsu_aarch64
#define helper_sve_ldbss_zss helper_sve_ldbss_zss_aarch64
#define helper_sve_ldbds_zsu helper_sve_ldbds_zsu_aarch64
#define helper_sve_ldbds_zss helper_sve_ldbds_zss_aarch64
#define helper_sve_ldbds_zd helper_sve_ldbds_zd_aarch64
#define helper_sve_ldhsu_le_zsu helper_sve_ldhsu_le_zsu_aarch64
#define helper_sve_ldhsu_le_zss helper_sve_ldhsu_le_zss_aarch64
#define helper_sve_ldhdu_le_zsu helper_sve_ldhdu_le_zsu_aarch64
#define helper_sve_ldhdu_le_zss helper_sve_ldhdu_le_zss_aarch64
#define helper_sve_ldhdu_le_zd helper_sve_ldhdu_le_zd_aarch64
#define helper_sve_ldhsu_be_zsu helper_sve_ldhsu_be_zsu_aarch64
#define helper_sve_ldhsu_be_zss helper_sve_ldhsu_be_zss_aarch64
#define helper_sve_ldhdu_be_zsu helper_sve_ldhdu_be_zsu_aarch64
#define helper_sve_ldhdu_be_zss helper_sve_ldhdu_be_zss_aarch64
#define helper_sve_ldhdu_be_zd helper_sve_ldhdu_be_zd_aarch64
#define helper_sve_ldhss_le_zsu helper_sve_ldhss_le_zsu_aarch64
#define helper_sve_ldhss_le_zss helper_sve_ldhss_le_zss_aarch64
#define helper_sve_ldhds_le_zsu helper_sve_ldhds_le_zsu_aarch64
#define helper_sve_ldhds_le_zss helper_sve_ldhds_le_zss_aarch64
#define helper_sve_ldhds_le_zd helper_sve_ldhds_le_zd_aarch64
#define helper_sve_ldhss_be_zsu helper_sve_ldhss_be_zsu_aarch64
#define helper_sve_ldhss_be_zss helper_sve_ldhss_be_zss_aarch64
#define helper_sve_ldhds_be_zsu helper_sve_ldhds_be_zsu_aarch64
#define helper_sve_ldhds_be_zss helper_sve_ldhds_be_zss_aarch64
#define helper_sve_ldhds_be_zd helper_sve_ldhds_be_zd_aarch64
#define helper_sve_ldss_le_zsu helper_sve_ldss_le_zsu_aarch64
#define helper_sve_ldss_le_zss helper_sve_ldss_le_zss_aarch64
#define helper_sve_ldsdu_le_zsu helper_sve_ldsdu_le_zsu_aarch64
#define helper_sve_ldsdu_le_zss helper_sve_ldsdu_le_zss_aarch64
#define helper_sve_ldsdu_le_zd helper_sve_ldsdu_le_zd_aarch64
#define helper_sve_ldss_be_zsu helper_sve_ldss_be_zsu_aarch64
#define helper_sve_ldss_be_zss helper_sve_ldss_be_zss_aarch64
#define helper_sve_ldsdu_be_zsu helper_sve_ldsdu_be_zsu_aarch64
#define helper_sve_ldsdu_be_zss helper_sve_ldsdu_be_zss_aarch64
#define helper_sve_ldsdu_be_zd helper_sve_ldsdu_be_zd_aarch64
#define helper_sve_ldsds_le_zsu helper_sve_ldsds_le_zsu_aarch64
#define helper_sve_ldsds_le_zss helper_sve_ldsds_le_zss_aarch64
#define helper_sve_ldsds_le_zd helper_sve_ldsds_le_zd_aarch64
#define helper_sve_ldsds_be_zsu helper_sve_ldsds_be_zsu_aarch64
#define helper_sve_ldsds_be_zss helper_sve_ldsds_be_zss_aarch64
#define helper_sve_ldsds_be_zd helper_sve_ldsds_be_zd_aarch64
#define helper_sve_lddd_le_zsu helper_sve_lddd_le_zsu_aarch64
#define helper_sve_lddd_le_zss helper_sve_lddd_le_zss_aarch64
#define helper_sve_lddd_le_zd helper_sve_lddd_le_zd_aarch64
#define helper_sve_lddd_be_zsu helper_sve_lddd_be_zsu_aarch64
#define helper_sve_lddd_be_zss helper_sve_lddd_be_zss_aarch64
#define helper_sve_lddd_be_zd helper_sve_lddd_be_zd_aarch64
#define helper_sve_ldffbsu_zsu helper_sve_ldffbsu_zsu_aarch64
#define helper_sve_ldffbsu_zss helper_sve_ldffbsu_zss_aarch64
#define helper_sve_ldffbdu_zsu helper_sve_ldffbdu_zsu_aarch64
#define helper_sve_ldffbdu_zss helper_sve_ldffbdu_zss_aarch64
#define helper_sve_ldffbdu_zd helper_sve_ldffbdu_zd_aarch64
#define helper_sve_ldffbss_zsu helper_sve_ldffbss_zsu_aarch64
#define helper_sve_ldffbss_zss helper_sve_ldffbss_zss_aarch64
#define helper_sve_ldffbds_zsu helper_sve_ldffbds_zsu_aarch64
#define helper_sve_ldffbds_zss helper_sve_ldffbds_zss_aarch64
#define helper_sve_ldffbds_zd helper_sve_ldffbds_zd_aarch64
#define helper_sve_ldffhsu_le_zsu helper_sve_ldffhsu_le_zsu_aarch64
#define helper_sve_ldffhsu_le_zss helper_sve_ldffhsu_le_zss_aarch64
#define helper_sve_ldffhdu_le_zsu helper_sve_ldffhdu_le_zsu_aarch64
#define helper_sve_ldffhdu_le_zss helper_sve_ldffhdu_le_zss_aarch64
#define helper_sve_ldffhdu_le_zd helper_sve_ldffhdu_le_zd_aarch64
#define helper_sve_ldffhsu_be_zsu helper_sve_ldffhsu_be_zsu_aarch64
#define helper_sve_ldffhsu_be_zss helper_sve_ldffhsu_be_zss_aarch64
#define helper_sve_ldffhdu_be_zsu helper_sve_ldffhdu_be_zsu_aarch64
#define helper_sve_ldffhdu_be_zss helper_sve_ldffhdu_be_zss_aarch64
#define helper_sve_ldffhdu_be_zd helper_sve_ldffhdu_be_zd_aarch64
#define helper_sve_ldffhss_le_zsu helper_sve_ldffhss_le_zsu_aarch64
#define helper_sve_ldffhss_le_zss helper_sve_ldffhss_le_zss_aarch64
#define helper_sve_ldffhds_le_zsu helper_sve_ldffhds_le_zsu_aarch64
#define helper_sve_ldffhds_le_zss helper_sve_ldffhds_le_zss_aarch64
#define helper_sve_ldffhds_le_zd helper_sve_ldffhds_le_zd_aarch64
#define helper_sve_ldffhss_be_zsu helper_sve_ldffhss_be_zsu_aarch64
#define helper_sve_ldffhss_be_zss helper_sve_ldffhss_be_zss_aarch64
#define helper_sve_ldffhds_be_zsu helper_sve_ldffhds_be_zsu_aarch64
#define helper_sve_ldffhds_be_zss helper_sve_ldffhds_be_zss_aarch64
#define helper_sve_ldffhds_be_zd helper_sve_ldffhds_be_zd_aarch64
#define helper_sve_ldffss_le_zsu helper_sve_ldffss_le_zsu_aarch64
#define helper_sve_ldffss_le_zss helper_sve_ldffss_le_zss_aarch64
#define helper_sve_ldffsdu_le_zsu helper_sve_ldffsdu_le_zsu_aarch64
#define helper_sve_ldffsdu_le_zss helper_sve_ldffsdu_le_zss_aarch64
#define helper_sve_ldffsdu_le_zd helper_sve_ldffsdu_le_zd_aarch64
#define helper_sve_ldffss_be_zsu helper_sve_ldffss_be_zsu_aarch64
#define helper_sve_ldffss_be_zss helper_sve_ldffss_be_zss_aarch64
#define helper_sve_ldffsdu_be_zsu helper_sve_ldffsdu_be_zsu_aarch64
#define helper_sve_ldffsdu_be_zss helper_sve_ldffsdu_be_zss_aarch64
#define helper_sve_ldffsdu_be_zd helper_sve_ldffsdu_be_zd_aarch64
#define helper_sve_ldffsds_le_zsu helper_sve_ldffsds_le_zsu_aarch64
#define helper_sve_ldffsds_le_zss helper_sve_ldffsds_le_zss_aarch64
#define helper_sve_ldffsds_le_zd helper_sve_ldffsds_le_zd_aarch64
#define helper_sve_ldffsds_be_zsu helper_sve_ldffsds_be_zsu_aarch64
#define helper_sve_ldffsds_be_zss helper_sve_ldffsds_be_zss_aarch64
#define helper_sve_ldffsds_be_zd helper_sve_ldffsds_be_zd_aarch64
#define helper_sve_ldffdd_le_zsu helper_sve_ldffdd_le_zsu_aarch64
#define helper_sve_ldffdd_le_zss helper_sve_ldffdd_le_zss_aarch64
#define helper_sve_ldffdd_le_zd helper_sve_ldffdd_le_zd_aarch64
#define helper_sve_ldffdd_be_zsu helper_sve_ldffdd_be_zsu_aarch64
#define helper_sve_ldffdd_be_zss helper_sve_ldffdd_be_zss_aarch64
#define helper_sve_ldffdd_be_zd helper_sve_ldffdd_be_zd_aarch64
#define helper_sve_stbs_zsu helper_sve_stbs_zsu_aarch64
#define helper_sve_sths_le_zsu helper_sve_sths_le_zsu_aarch64
#define helper_sve_sths_be_zsu helper_sve_sths_be_zsu_aarch64
#define helper_sve_stss_le_zsu helper_sve_stss_le_zsu_aarch64
#define helper_sve_stss_be_zsu helper_sve_stss_be_zsu_aarch64
#define helper_sve_stbs_zss helper_sve_stbs_zss_aarch64
#define helper_sve_sths_le_zss helper_sve_sths_le_zss_aarch64
#define helper_sve_sths_be_zss helper_sve_sths_be_zss_aarch64
#define helper_sve_stss_le_zss helper_sve_stss_le_zss_aarch64
#define helper_sve_stss_be_zss helper_sve_stss_be_zss_aarch64
#define helper_sve_stbd_zsu helper_sve_stbd_zsu_aarch64
#define helper_sve_sthd_le_zsu helper_sve_sthd_le_zsu_aarch64
#define helper_sve_sthd_be_zsu helper_sve_sthd_be_zsu_aarch64
#define helper_sve_stsd_le_zsu helper_sve_stsd_le_zsu_aarch64
#define helper_sve_stsd_be_zsu helper_sve_stsd_be_zsu_aarch64
#define helper_sve_stdd_le_zsu helper_sve_stdd_le_zsu_aarch64
#define helper_sve_stdd_be_zsu helper_sve_stdd_be_zsu_aarch64
#define helper_sve_stbd_zss helper_sve_stbd_zss_aarch64
#define helper_sve_sthd_le_zss helper_sve_sthd_le_zss_aarch64
#define helper_sve_sthd_be_zss helper_sve_sthd_be_zss_aarch64
#define helper_sve_stsd_le_zss helper_sve_stsd_le_zss_aarch64
#define helper_sve_stsd_be_zss helper_sve_stsd_be_zss_aarch64
#define helper_sve_stdd_le_zss helper_sve_stdd_le_zss_aarch64
#define helper_sve_stdd_be_zss helper_sve_stdd_be_zss_aarch64
#define helper_sve_stbd_zd helper_sve_stbd_zd_aarch64
#define helper_sve_sthd_le_zd helper_sve_sthd_le_zd_aarch64
#define helper_sve_sthd_be_zd helper_sve_sthd_be_zd_aarch64
#define helper_sve_stsd_le_zd helper_sve_stsd_le_zd_aarch64
#define helper_sve_stsd_be_zd helper_sve_stsd_be_zd_aarch64
#define helper_sve_stdd_le_zd helper_sve_stdd_le_zd_aarch64
#define helper_sve_stdd_be_zd helper_sve_stdd_be_zd_aarch64
#define arm_cpu_do_unaligned_access arm_cpu_do_unaligned_access_aarch64
#define arm_cpu_do_transaction_failed arm_cpu_do_transaction_failed_aarch64
#define arm_cpu_tlb_fill arm_cpu_tlb_fill_aarch64
#define a64_translate_init a64_translate_init_aarch64
#define gen_a64_set_pc_im gen_a64_set_pc_im_aarch64
#define unallocated_encoding unallocated_encoding_aarch64
#define new_tmp_a64 new_tmp_a64_aarch64
#define new_tmp_a64_zero new_tmp_a64_zero_aarch64
#define cpu_reg cpu_reg_aarch64
#define cpu_reg_sp cpu_reg_sp_aarch64
#define read_cpu_reg read_cpu_reg_aarch64
#define read_cpu_reg_sp read_cpu_reg_sp_aarch64
#define write_fp_dreg write_fp_dreg_aarch64
#define get_fpstatus_ptr get_fpstatus_ptr_aarch64
#define sve_access_check sve_access_check_aarch64
#define logic_imm_decode_wmask logic_imm_decode_wmask_aarch64
#define arm_translate_init arm_translate_init_aarch64
#define arm_test_cc arm_test_cc_aarch64
#define arm_free_cc arm_free_cc_aarch64
#define arm_jump_cc arm_jump_cc_aarch64
#define arm_gen_test_cc arm_gen_test_cc_aarch64
#define vfp_expand_imm vfp_expand_imm_aarch64
#define gen_cmtst_i64 gen_cmtst_i64_aarch64
#define gen_ushl_i32 gen_ushl_i32_aarch64
#define gen_ushl_i64 gen_ushl_i64_aarch64
#define gen_sshl_i32 gen_sshl_i32_aarch64
#define gen_sshl_i64 gen_sshl_i64_aarch64
#define gen_intermediate_code gen_intermediate_code_aarch64
#define restore_state_to_opc restore_state_to_opc_aarch64
#define disas_sve disas_sve_aarch64
#define helper_neon_qrdmlah_s16 helper_neon_qrdmlah_s16_aarch64
#define helper_gvec_qrdmlah_s16 helper_gvec_qrdmlah_s16_aarch64
#define helper_neon_qrdmlsh_s16 helper_neon_qrdmlsh_s16_aarch64
#define helper_gvec_qrdmlsh_s16 helper_gvec_qrdmlsh_s16_aarch64
#define helper_neon_qrdmlah_s32 helper_neon_qrdmlah_s32_aarch64
#define helper_gvec_qrdmlah_s32 helper_gvec_qrdmlah_s32_aarch64
#define helper_neon_qrdmlsh_s32 helper_neon_qrdmlsh_s32_aarch64
#define helper_gvec_qrdmlsh_s32 helper_gvec_qrdmlsh_s32_aarch64
#define helper_gvec_sdot_b helper_gvec_sdot_b_aarch64
#define helper_gvec_udot_b helper_gvec_udot_b_aarch64
#define helper_gvec_sdot_h helper_gvec_sdot_h_aarch64
#define helper_gvec_udot_h helper_gvec_udot_h_aarch64
#define helper_gvec_sdot_idx_b helper_gvec_sdot_idx_b_aarch64
#define helper_gvec_udot_idx_b helper_gvec_udot_idx_b_aarch64
#define helper_gvec_sdot_idx_h helper_gvec_sdot_idx_h_aarch64
#define helper_gvec_udot_idx_h helper_gvec_udot_idx_h_aarch64
#define helper_gvec_fcaddh helper_gvec_fcaddh_aarch64
#define helper_gvec_fcadds helper_gvec_fcadds_aarch64
#define helper_gvec_fcaddd helper_gvec_fcaddd_aarch64
#define helper_gvec_fcmlah helper_gvec_fcmlah_aarch64
#define helper_gvec_fcmlah_idx helper_gvec_fcmlah_idx_aarch64
#define helper_gvec_fcmlas helper_gvec_fcmlas_aarch64
#define helper_gvec_fcmlas_idx helper_gvec_fcmlas_idx_aarch64
#define helper_gvec_fcmlad helper_gvec_fcmlad_aarch64
#define helper_gvec_frecpe_h helper_gvec_frecpe_h_aarch64
#define helper_gvec_frecpe_s helper_gvec_frecpe_s_aarch64
#define helper_gvec_frecpe_d helper_gvec_frecpe_d_aarch64
#define helper_gvec_frsqrte_h helper_gvec_frsqrte_h_aarch64
#define helper_gvec_frsqrte_s helper_gvec_frsqrte_s_aarch64
#define helper_gvec_frsqrte_d helper_gvec_frsqrte_d_aarch64
#define helper_gvec_fadd_h helper_gvec_fadd_h_aarch64
#define helper_gvec_fadd_s helper_gvec_fadd_s_aarch64
#define helper_gvec_fadd_d helper_gvec_fadd_d_aarch64
#define helper_gvec_fsub_h helper_gvec_fsub_h_aarch64
#define helper_gvec_fsub_s helper_gvec_fsub_s_aarch64
#define helper_gvec_fsub_d helper_gvec_fsub_d_aarch64
#define helper_gvec_fmul_h helper_gvec_fmul_h_aarch64
#define helper_gvec_fmul_s helper_gvec_fmul_s_aarch64
#define helper_gvec_fmul_d helper_gvec_fmul_d_aarch64
#define helper_gvec_ftsmul_h helper_gvec_ftsmul_h_aarch64
#define helper_gvec_ftsmul_s helper_gvec_ftsmul_s_aarch64
#define helper_gvec_ftsmul_d helper_gvec_ftsmul_d_aarch64
#define helper_gvec_recps_h helper_gvec_recps_h_aarch64
#define helper_gvec_recps_s helper_gvec_recps_s_aarch64
#define helper_gvec_recps_d helper_gvec_recps_d_aarch64
#define helper_gvec_rsqrts_h helper_gvec_rsqrts_h_aarch64
#define helper_gvec_rsqrts_s helper_gvec_rsqrts_s_aarch64
#define helper_gvec_rsqrts_d helper_gvec_rsqrts_d_aarch64
#define helper_gvec_fmul_idx_h helper_gvec_fmul_idx_h_aarch64
#define helper_gvec_fmul_idx_s helper_gvec_fmul_idx_s_aarch64
#define helper_gvec_fmul_idx_d helper_gvec_fmul_idx_d_aarch64
#define helper_gvec_fmla_idx_h helper_gvec_fmla_idx_h_aarch64
#define helper_gvec_fmla_idx_s helper_gvec_fmla_idx_s_aarch64
#define helper_gvec_fmla_idx_d helper_gvec_fmla_idx_d_aarch64
#define helper_gvec_uqadd_b helper_gvec_uqadd_b_aarch64
#define helper_gvec_uqadd_h helper_gvec_uqadd_h_aarch64
#define helper_gvec_uqadd_s helper_gvec_uqadd_s_aarch64
#define helper_gvec_sqadd_b helper_gvec_sqadd_b_aarch64
#define helper_gvec_sqadd_h helper_gvec_sqadd_h_aarch64
#define helper_gvec_sqadd_s helper_gvec_sqadd_s_aarch64
#define helper_gvec_uqsub_b helper_gvec_uqsub_b_aarch64
#define helper_gvec_uqsub_h helper_gvec_uqsub_h_aarch64
#define helper_gvec_uqsub_s helper_gvec_uqsub_s_aarch64
#define helper_gvec_sqsub_b helper_gvec_sqsub_b_aarch64
#define helper_gvec_sqsub_h helper_gvec_sqsub_h_aarch64
#define helper_gvec_sqsub_s helper_gvec_sqsub_s_aarch64
#define helper_gvec_uqadd_d helper_gvec_uqadd_d_aarch64
#define helper_gvec_uqsub_d helper_gvec_uqsub_d_aarch64
#define helper_gvec_sqadd_d helper_gvec_sqadd_d_aarch64
#define helper_gvec_sqsub_d helper_gvec_sqsub_d_aarch64
#define helper_gvec_fmlal_a32 helper_gvec_fmlal_a32_aarch64
#define helper_gvec_fmlal_a64 helper_gvec_fmlal_a64_aarch64
#define helper_gvec_fmlal_idx_a32 helper_gvec_fmlal_idx_a32_aarch64
#define helper_gvec_fmlal_idx_a64 helper_gvec_fmlal_idx_a64_aarch64
#define helper_gvec_sshl_b helper_gvec_sshl_b_aarch64
#define helper_gvec_sshl_h helper_gvec_sshl_h_aarch64
#define helper_gvec_ushl_b helper_gvec_ushl_b_aarch64
#define helper_gvec_ushl_h helper_gvec_ushl_h_aarch64
#define helper_gvec_pmul_b helper_gvec_pmul_b_aarch64
#define helper_gvec_pmull_q helper_gvec_pmull_q_aarch64
#define helper_neon_pmull_h helper_neon_pmull_h_aarch64
#define helper_sve2_pmull_h helper_sve2_pmull_h_aarch64
#define helper_vfp_get_fpscr helper_vfp_get_fpscr_aarch64
#define vfp_get_fpscr vfp_get_fpscr_aarch64
#define helper_vfp_set_fpscr helper_vfp_set_fpscr_aarch64
#define vfp_set_fpscr vfp_set_fpscr_aarch64
#define helper_vfp_adds helper_vfp_adds_aarch64
#define helper_vfp_addd helper_vfp_addd_aarch64
#define helper_vfp_subs helper_vfp_subs_aarch64
#define helper_vfp_subd helper_vfp_subd_aarch64
#define helper_vfp_muls helper_vfp_muls_aarch64
#define helper_vfp_muld helper_vfp_muld_aarch64
#define helper_vfp_divs helper_vfp_divs_aarch64
#define helper_vfp_divd helper_vfp_divd_aarch64
#define helper_vfp_mins helper_vfp_mins_aarch64
#define helper_vfp_mind helper_vfp_mind_aarch64
#define helper_vfp_maxs helper_vfp_maxs_aarch64
#define helper_vfp_maxd helper_vfp_maxd_aarch64
#define helper_vfp_minnums helper_vfp_minnums_aarch64
#define helper_vfp_minnumd helper_vfp_minnumd_aarch64
#define helper_vfp_maxnums helper_vfp_maxnums_aarch64
#define helper_vfp_maxnumd helper_vfp_maxnumd_aarch64
#define helper_vfp_negs helper_vfp_negs_aarch64
#define helper_vfp_negd helper_vfp_negd_aarch64
#define helper_vfp_abss helper_vfp_abss_aarch64
#define helper_vfp_absd helper_vfp_absd_aarch64
#define helper_vfp_sqrts helper_vfp_sqrts_aarch64
#define helper_vfp_sqrtd helper_vfp_sqrtd_aarch64
#define helper_vfp_cmps helper_vfp_cmps_aarch64
#define helper_vfp_cmpes helper_vfp_cmpes_aarch64
#define helper_vfp_cmpd helper_vfp_cmpd_aarch64
#define helper_vfp_cmped helper_vfp_cmped_aarch64
#define helper_vfp_sitoh helper_vfp_sitoh_aarch64
#define helper_vfp_tosih helper_vfp_tosih_aarch64
#define helper_vfp_tosizh helper_vfp_tosizh_aarch64
#define helper_vfp_sitos helper_vfp_sitos_aarch64
#define helper_vfp_tosis helper_vfp_tosis_aarch64
#define helper_vfp_tosizs helper_vfp_tosizs_aarch64
#define helper_vfp_sitod helper_vfp_sitod_aarch64
#define helper_vfp_tosid helper_vfp_tosid_aarch64
#define helper_vfp_tosizd helper_vfp_tosizd_aarch64
#define helper_vfp_uitoh helper_vfp_uitoh_aarch64
#define helper_vfp_touih helper_vfp_touih_aarch64
#define helper_vfp_touizh helper_vfp_touizh_aarch64
#define helper_vfp_uitos helper_vfp_uitos_aarch64
#define helper_vfp_touis helper_vfp_touis_aarch64
#define helper_vfp_touizs helper_vfp_touizs_aarch64
#define helper_vfp_uitod helper_vfp_uitod_aarch64
#define helper_vfp_touid helper_vfp_touid_aarch64
#define helper_vfp_touizd helper_vfp_touizd_aarch64
#define helper_vfp_fcvtds helper_vfp_fcvtds_aarch64
#define helper_vfp_fcvtsd helper_vfp_fcvtsd_aarch64
#define helper_vfp_shtod helper_vfp_shtod_aarch64
#define helper_vfp_toshd_round_to_zero helper_vfp_toshd_round_to_zero_aarch64
#define helper_vfp_toshd helper_vfp_toshd_aarch64
#define helper_vfp_sltod helper_vfp_sltod_aarch64
#define helper_vfp_tosld_round_to_zero helper_vfp_tosld_round_to_zero_aarch64
#define helper_vfp_tosld helper_vfp_tosld_aarch64
#define helper_vfp_sqtod helper_vfp_sqtod_aarch64
#define helper_vfp_tosqd helper_vfp_tosqd_aarch64
#define helper_vfp_uhtod helper_vfp_uhtod_aarch64
#define helper_vfp_touhd_round_to_zero helper_vfp_touhd_round_to_zero_aarch64
#define helper_vfp_touhd helper_vfp_touhd_aarch64
#define helper_vfp_ultod helper_vfp_ultod_aarch64
#define helper_vfp_tould_round_to_zero helper_vfp_tould_round_to_zero_aarch64
#define helper_vfp_tould helper_vfp_tould_aarch64
#define helper_vfp_uqtod helper_vfp_uqtod_aarch64
#define helper_vfp_touqd helper_vfp_touqd_aarch64
#define helper_vfp_shtos helper_vfp_shtos_aarch64
#define helper_vfp_toshs_round_to_zero helper_vfp_toshs_round_to_zero_aarch64
#define helper_vfp_toshs helper_vfp_toshs_aarch64
#define helper_vfp_sltos helper_vfp_sltos_aarch64
#define helper_vfp_tosls_round_to_zero helper_vfp_tosls_round_to_zero_aarch64
#define helper_vfp_tosls helper_vfp_tosls_aarch64
#define helper_vfp_sqtos helper_vfp_sqtos_aarch64
#define helper_vfp_tosqs helper_vfp_tosqs_aarch64
#define helper_vfp_uhtos helper_vfp_uhtos_aarch64
#define helper_vfp_touhs_round_to_zero helper_vfp_touhs_round_to_zero_aarch64
#define helper_vfp_touhs helper_vfp_touhs_aarch64
#define helper_vfp_ultos helper_vfp_ultos_aarch64
#define helper_vfp_touls_round_to_zero helper_vfp_touls_round_to_zero_aarch64
#define helper_vfp_touls helper_vfp_touls_aarch64
#define helper_vfp_uqtos helper_vfp_uqtos_aarch64
#define helper_vfp_touqs helper_vfp_touqs_aarch64
#define helper_vfp_sltoh helper_vfp_sltoh_aarch64
#define helper_vfp_ultoh helper_vfp_ultoh_aarch64
#define helper_vfp_sqtoh helper_vfp_sqtoh_aarch64
#define helper_vfp_uqtoh helper_vfp_uqtoh_aarch64
#define helper_vfp_toshh helper_vfp_toshh_aarch64
#define helper_vfp_touhh helper_vfp_touhh_aarch64
#define helper_vfp_toslh helper_vfp_toslh_aarch64
#define helper_vfp_toulh helper_vfp_toulh_aarch64
#define helper_vfp_tosqh helper_vfp_tosqh_aarch64
#define helper_vfp_touqh helper_vfp_touqh_aarch64
#define helper_set_rmode helper_set_rmode_aarch64
#define helper_set_neon_rmode helper_set_neon_rmode_aarch64
#define helper_vfp_fcvt_f16_to_f32 helper_vfp_fcvt_f16_to_f32_aarch64
#define helper_vfp_fcvt_f32_to_f16 helper_vfp_fcvt_f32_to_f16_aarch64
#define helper_vfp_fcvt_f16_to_f64 helper_vfp_fcvt_f16_to_f64_aarch64
#define helper_vfp_fcvt_f64_to_f16 helper_vfp_fcvt_f64_to_f16_aarch64
#define helper_recps_f32 helper_recps_f32_aarch64
#define helper_rsqrts_f32 helper_rsqrts_f32_aarch64
#define helper_recpe_f16 helper_recpe_f16_aarch64
#define helper_recpe_f32 helper_recpe_f32_aarch64
#define helper_recpe_f64 helper_recpe_f64_aarch64
#define helper_rsqrte_f16 helper_rsqrte_f16_aarch64
#define helper_rsqrte_f32 helper_rsqrte_f32_aarch64
#define helper_rsqrte_f64 helper_rsqrte_f64_aarch64
#define helper_recpe_u32 helper_recpe_u32_aarch64
#define helper_rsqrte_u32 helper_rsqrte_u32_aarch64
#define helper_vfp_muladds helper_vfp_muladds_aarch64
#define helper_vfp_muladdd helper_vfp_muladdd_aarch64
#define helper_rints_exact helper_rints_exact_aarch64
#define helper_rintd_exact helper_rintd_exact_aarch64
#define helper_rints helper_rints_aarch64
#define helper_rintd helper_rintd_aarch64
#define arm_rmode_to_sf arm_rmode_to_sf_aarch64
#define helper_fjcvtzs helper_fjcvtzs_aarch64
#define helper_vjcvt helper_vjcvt_aarch64
#define helper_frint32_s helper_frint32_s_aarch64
#define helper_frint64_s helper_frint64_s_aarch64
#define helper_frint32_d helper_frint32_d_aarch64
#define helper_frint64_d helper_frint64_d_aarch64
#define helper_check_hcr_el2_trap helper_check_hcr_el2_trap_aarch64
#define mla_op mla_op_aarch64
#define mls_op mls_op_aarch64
#define sshl_op sshl_op_aarch64
#define ushl_op ushl_op_aarch64
#define uqsub_op uqsub_op_aarch64
#define sqsub_op sqsub_op_aarch64
#define uqadd_op uqadd_op_aarch64
#define sqadd_op sqadd_op_aarch64
#define sli_op sli_op_aarch64
#define cmtst_op cmtst_op_aarch64
#define sri_op sri_op_aarch64
#define usra_op usra_op_aarch64
#define ssra_op ssra_op_aarch64
#define aarch64_translator_ops aarch64_translator_ops_aarch64
#define pred_esz_masks pred_esz_masks_aarch64
#define helper_uc_hooksys64 helper_uc_hooksys64_aarch64
#endif
